/**
 * The EndurancePotion class represents a potion that can be consumed by the kobold,
 * which increases its endurance stat.
 */
function EndurancePotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Endurance Potion";
    var itemDescription = "A small, bowl-shaped glass vial. Orange liquid sloshes within. The label on the side says that it'll make you more resillient.";
    var baseValue = 50;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                            The orange fluid within smells like soup.
                            Tomato soup, to be more precise.
                            It entices an unnatural hunger from within you.
                            Like you [b]need[/b] to eat something [b]right now[/b].
                        [/p]
                        [p]
                            Feeling like you're about to starve, your mind can not fathom the thought of [b]not[/b] devouring the potion before you.
                            You lower the vial to your slightly parted lips, before tipping it backwards, 
                            along with your head, letting the contents flood into your mouth.
                        [/p]
                        [p]
                            The thick, viscous liquid tastes like broth.
                            Impossibly large chunks form in your mouth.
                            You try to chew them, but they're [b]tough[/b] and [b]stringy[/b], like year-old meat.
                            Your first instinct is to spit the potion out, yet the intense [b]need[/b] to fill your stomach with food surpasses your natural reflexes.
                        [/p]
                        [p]
                            You slowly wrestle lump after lump of the meat-like substance down your throat, one at a time.
                            They barely fit down your esophagus.
                            You nearly choke on a piece, yet the very [b]instant[/b] the thought of spitting the stuff out crosses your mind,
                            the slab lodged down your throat miraculously finds its way to your stomach.
                            Like it knows.
                            Like it's playing with you.
                        [/p]
                        [p]
                            You painstakingly down the thick, chunky soup-like goop until you can take no more.
                            With the bottle emptied, you finally spit out the last few meat-hunks left in your muzzle.
                            To your surprise, the fluid that escapes your lips is [b]not[/b] filled with chunks,
                            instead resembling the orange liquid the bottle initially contained.
                            Were you [i]imagining[/i] those pieces of meat?
                            Was it all in your head?
                        [/p]
                        [p]
                            You decide not to ponder the situation any further.
                            Besides, a potion that can affect your mind is undoubtebly strong enough to improve your body.
                            Indeed, your scales feel just a little more [b]tough[/b], more [b]solid[/b], less [i]sensitive[/i] and [b]weak[/b].
                            In fact, your entire body feels like it could wither a lot more punishment without faltering.
                        [/p]
                        [p]
                            [b]You have gained 1 endurance.[/b]
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as tough as you're ever going to get. You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.ENDURANCE_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var end = global.kobold.stats.get(StatsEnum.ENDURANCE);
        var maxed = (end >= global.kobold.stats.statMax);
        if (maxed) {
            global.ui.showFullscreenPopup(buildMaxContents());
            return false;
        }
        global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
        global.ui.showFullscreenPopup(buildPopupContents());
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
