/**
 * The LuckPotion class represents a potion that can be consumed by the kobold,
 * which increases its luck stat.
 */
function LuckPotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Luck Potion";
    var itemDescription = "A small glass vial shaped like a clover. Neon-green liquid sloshes within. The label on the side says that it'll improve your luck.";
    var baseValue = 50;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                            The bright green fluid within smells [b]sugary[/b] and [b]sweet[/b].
                            Like honey, but far less viscous.
                        [/p]
                        [p]
                            You fear this stuff's going to [b]rot[/b] your teeth.
                            Still, enticed by the sweet taste, you lower the vial to your slightly parted lips, before tipping it backwards, 
                            along with your head, letting the contents flood into your mouth.
                        [/p]
                        [p]
                            The liquid tastes just as sweet as it smelled,
                            like sugary water with a curious aftertaste.
                            As you glug down two whole mouthfuls of the sweet fluid,
                            it is this [i]aftertaste[/i] that begins to dominate your mouth.
                            A strong, salty flavor that heavily contrasts with the initial saccharine taste,
                            to the point where it nearly makes you [b]retch[/b].
                        [/p]
                        [p]
                            You can barely keep your stomach's contents as your entire mouth dries up.
                            It is as though an entire mountain of salt is being crammed down your face.
                            Luckily, the sensation passes as quickly as it emerged.
                            Moisture returns to your mouth, and the overly-intense flavor fades.
                        [/p]
                        [p]
                            A single question emerges in your mind: [b]why[/b]?
                            Was the potion a fake?
                            Did you get tricked?
                            Conned?
                            Or is there some deeper meaning to all of this?
                            Was it showing you the huge world of difference between having [i]good[/i] luck and having [i]bad[/i] luck?
                            If so, you really do hope the potion [b]worked[/b].
                        [/p]
                        [p]
                            [b]You have gained 1 luck.[/b] [sneak]Or have you?[/sneak]
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as lucky as you're ever going to get.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.LUCK_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var lck = global.kobold.stats.get(StatsEnum.LUCK);
        var maxed = (lck >= global.kobold.stats.statMax);
        if (maxed) {
            global.ui.showFullscreenPopup(buildMaxContents());
            return false;
        }
        global.kobold.stats.increaseStat(StatsEnum.LUCK, 1);
        global.ui.showFullscreenPopup(buildPopupContents());
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
