/**
 * A menu button.
 * @param {GenericMenuButton} gen Generic map button for base functionality. 
 */
function SettingsMenuButton(gen) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = "settingsmenubutton";
    var selected = false;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Returns the subtitle of this button.
     * @returns {string} The subtitle of this button.
     */
    function getSubtitle() {
        return "Settings";
    }

    /**
     * Returns the instructional content of this button.
     * @returns {string} The instructional content of this button.
     */
    function getContent() {
        var content = ` The settings page contains a bunch of options which may or may not alter your Kobold Adventure experience.
                        It is highly recommended to check out the settings page at least once.
                        If you want to make sure you're up to date with all the latest fancy knobs and buttons,
                        it might pay off to check the settings once every update.
                        Click the settings button again to open the settings in a new tab.`;
        return global.parser.parse(content);
    }

    /**
     * Returns the URL to route to when this button is clicked twice.
     * @returns {string} The URL to route to when this button is clicked twice.
     */
    function getUrl() {
        return "./settings/index.html";
    }

    /**
     * Stops event propagation.
     * @param {event} event The event to stop propagation of.
     */
    function stopProp(event) {
        event.stopPropagation();
    }

    /**
     * Opens a new tab with the button's specified URL.
     * @param {event} event The click event.
     */
    function clickedTwice(event) {
        that.unset();
        gen.open(getUrl());
    }

    /**
     * Onclick function.
     * @param {event} event The click event.
     */
    function clicked(event) {
        if (selected) {
            clickedTwice(event);
        } else {
            gen.set(id, getSubtitle(), getContent());
            selected = true;
        }
        stopProp(event);
    }

    /*
     * Registers listeners for this button.
     */
    function registerListeners() {
        $("#" + id).click(clicked);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the button.
     */
    this.init = function () {
        registerListeners();
    };

    /**
     * Unsets the button.
     */
    this.unset = function () {
        if (!selected) {
            return;
        }
        selected = false;
        gen.unset(id);
    };
}
