/**
 * Name section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementGlare(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementNameChoice.GLARE;
    var reqController = ctrl.name;
    var subController = ctrl.postName;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementMouth(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var begged = !global.kobold.history.shared.enslavement.captureFucked;
        var enjoyed = global.kobold.history.shared.enslavement.captureEnjoyed;
        var toReturn = `[p]
                            You may be his [i]slave[/i], but that doesn't mean you have to do what he says.
                            Well, okay, [i]maybe[/i] it does, but you're still not doing it!
                            What does he need your name for anyway?
                            To [b]engrave[/b] on your [b]collar[/b]?!
                            Screw that!
                            You're not telling him [b]anything[/b].
                            He can go to [b]hell[/b] for all you care!
                        [/p]
                        [p]
                            Your resolve bolstered, you glare up at the chubby human,
                            returning his hateful gaze with equal amounts of disdain.
                            Your muzzle remains tightly sealed, not a single sound escaping your lips.
                            The man is visibly growing annoyed.
                            He voices his anger in the form of a low-pitched growl.
                            You could almost mistake him for the wolf like this, if it weren't for his far less athletic physique.
                            "[color=brown]Don't you know how to talk, you miserable [b]mutt[/b]?![/color]"
                        [/p]
                        [p]
                            "[color=gblue]${male ? `He` : `She`} speaks our language alright.
                            You should have heard'em ${enjoyed ? `begging for more` : `${begged ? `begging for mercy` : `screaming for help`}`} earlier.[/color]"
                            the canine butts in.
                            "[color=brown]So instead of being dumb, the lizard's just being uppity.
                            Good.
                            Disobedience can be fixed.
                            Stupidity, however, can not.
                            If I had my way, I'd [b]beat[/b] some sense into it, but bruised merchandise doesn't sell.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
