/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodInsult(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.INSULT;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodInsult;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.insulted = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to have his men [b]violate[/b] you all he'd like.
                            At least that way, you won't have to be his [b]personal[/b] fucktoy.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said that thing about the [i]dog[/i],
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            You answer Fenrir's gaze with a determined glare of your own.
                            Anger wells up inside of you.
                            You aren't backing down.
                            Not this time.
                            What gives [b]him[/b] the right to push you around?!
                            You take in a deep breath, raise your voice, and let loose an angry [b]tirade[/b] of insults.
                            He's a filthy [b]slaver[/b].
                            A pathetic [b]loser[/b] that couldn't carve out an honest life for himself,
                            and is now stuck [b]bullying[/b] innocent kobolds like yourself!
                            You know you're not [i]really[/i] innocent, but it seemed like an [i]apt[/i] choice of words.
                        [/p]
                        [p]
                            Furthermore, he's [b]wrong[/b] about nobody wanting to buy you.
                            You're a [b]good[/b] kobold, and there'll surely be [b]dozens[/b] of people lining up to get a [b]chance[/b] at owning you!
                            You'll [b]never[/b] be [b]his[/b] slave!
                            Heck, you'll never be [b]anyone[/b]'s slave!
                            You're going to escape the first chance you get, and there's [b]nothing[/b] Fenrir can do to stop you.
                            And if the wolf so much as lays a hand on you, you'll tell the caravan master,
                            and the human'll yank the [b]big bitch[/b] that the bandit is back into submission in [b]no time[/b]!
                        [/p]
                        [p]
                            You find yourself panting slightly, your angry tantrum having left you out of breath.
                            The look on the canine's face transitions rapidly from disbelief, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin, probably trying to hide his true feelings.
                            "[color=gblue]You could have just said [i]no[/i].
                            This was a one time offer, and a good one at that.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.
                            And you better start watching your mouth.
                            [b]Or else[/b].[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
