/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsThrow(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new ForestWoodsThrowContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Fearing for your life in more than one way, you hop to your feet atop the tree branch,
                            balancing your way over to the beehive as fast as you can.
                            At first, you intend to grab it and throw it down,
                            yet you really don't want to put that swarming ball of sting-happy buzzers anywhere [b]near[/b] your face.
                            Thinking swiftly and acting even quicker, you prompty [b]kick[/b] the dense ball of honeycomb and wax,
                            its binding to the tree loudly cracking and breaking.
                        [/p]
                        [p]
                            No longer attached to the tree, the beehive plummets to the ground,
                            your powerful kick sending it flying in the direction of the two guards and their [i]pet[/i].
                            Once the nest hits the ground, it cracks open, an entire [b]swarm[/b] of angry bees flying out,
                            assaulting the wolf, the human and the dog.
                            After the initial surprise, the group bolts away as fast as they can to escape the [b]barrage[/b] of painful stings,
                            the feral canine leading the way.
                        [/p]
                        [p]
                            Some of the bees, however, managed to escape their nest [i]before[/i] you kicked it.
                            Despite your best efforts, you yourself get stung more than a few times,
                            although you manage to protect your face and other [i]more sensitive[/i] parts by wildly flailing your arms about to swat the insects away.
                            As your pursuers run into the depths of the forest, concern for their own well-being trumping the hunt for a runaway kobold,
                            you decide it's time to leave [b]before[/b] the rest of the lingering swarm takes an interest in you.
                        [/p]
                        [p]
                            You skillfully hop down a few branches before leaping to the ground below,
                            dropping into an athletic roll to lessen the impact of the heighty jump,
                            the soft forest ground acting as a cushion to soften the blow even more.
                            Scrambling to your feet, you sprint away in the opposite direction the party chasing after you went,
                            running away from the bees while avoiding incidentally bumping into your pursuers still.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.preContinue.continued() ? "disabled" : "";
        var isSelected = ctrl.preContinue.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.preContinue.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.tree.get() !== ForestWoodsTreeChoice.THROW) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.treeThrow.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.tree.get() !== ForestWoodsTreeChoice.THROW) {
            return;
        }

        next.registerListeners();

        if (ctrl.preContinue.continued()) {
            return;
        }

        registerNextListener();
    };
}
