/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellBegFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.helpBegFail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You say it's a good thing the boys found you when they did.
                            You were about to give up hope before they showed up!
                            You, uh, fell down here and you can't seem to get out on your own.
                            You ask them if they could, pretty please, perhaps toss down a rope attached to something so you can climb out of here,
                            or maybe go get one of their parents to help you out or something?
                        [/p]
                        [p]
                            You get the feeling the boys weren't exactly paying attention to your desperate pleading,
                            or maybe they're just not taking you very serious.
                            Althroughout your [i]begging for help[/i], you could hear them utter snickers and sneers, giggles and chortles,
                            like they were joking around instead of listening to you.
                            "[color=red]Hey![/color]" finally comes a response, after a moment of silence.
                            "[color=red]When kobolds are left in the water for too long, do they turn into fish?[/color]"
                        [/p]
                        [p]
                            More laughter.
                            They sound like they're having the time of their lives picking on you,
                            maybe because nothing interesting [i]ever[/i] happens around these parts.
                            Once they're done teasing you, surely, they'll come to your aid, right?
                            They wouldn't just leave you here, would they?
                        [/p]
                        [p]
                            Desperation growing at the back of your head, you decide to play along with the boys' little [i]game[/i].
                            You reply that, no, you don't turn into a fish, but you might become a scary crocodile if they don't let you out soon!
                            "[color=blue]A crocodile?[/color]" answers the third child, in a satirical tone.
                            "[color=blue]A kobold like you is more likely to turn into an [i]alley-gay-whore[/i]![/color]"
                        [/p]
                        [p]
                            The audacity!
                            Where does a young boy even pick up such vulgar words?!
                            All three begin to cackle loudly, laughing their asses off at the third boy's joke.
                            Stupid inbred farmer hicks not raising their kids right.
                            The laughter goes on for the better half of a minute.
                            You're starting to lose your patience with these kids.
                        [/p]
                        [p]
                            The laughter slowly dies down.
                            All three of the kids' heads turn towards the same direction.
                            "[color=red]We're being careful, mom![/color]"
                            You overhear one of the boys replying to who you can only imagine to be his mother.
                            "[color=red]Fiiiine! Let's go.[/color]"
                        [/p]
                        [p]
                            Without even giving you a proper goodbye,
                            and more importantly: without telling this [i]mother[/i] figure about the [b]kobold trapped in the well[/b],
                            the boys hop off of the edge of the well, and disappear from sight.
                            You shout for them to come back, to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Calling for help clearly won't get you anywhere.
                            If the children of the hamlet won't help you, then you have little hope for the adults.
                        [/p]
                        ${global.ui.condFail(`Charisma below 6`)}
                        [p]
                            Halfway through conceiving an intricate escape plan concerning your tail and a star-shaped rock of some kind,
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
