/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellBegSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.helpBegSucceed;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.escapedRope = true;
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You say it's a good thing the boys found you when they did.
                            You were about to give up hope before they showed up!
                            You, uh, fell down here and you can't seem to get out on your own.
                            You ask them if they could, pretty please, perhaps toss down a rope attached to something so you can climb out of here,
                            or maybe go get one of their parents to help you out or something?
                        [/p]
                        [p]
                            You get the feeling the boys weren't exactly paying attention to your desperate pleading,
                            or maybe they're just not taking you very serious.
                            Althroughout your [i]begging for help[/i], you could hear them utter snickers and sneers, giggles and chortles,
                            like they were joking around instead of listening to you.
                            "[color=red]Hey![/color]" finally comes a response, after a moment of silence.
                            "[color=red]When kobolds are left in the water for too long, do they turn into fish?[/color]"
                        [/p]
                        [p]
                            More laughter.
                            They sound like they're having the time of their lives picking on you,
                            maybe because nothing interesting [i]ever[/i] happens around these parts.
                            Once they're done teasing you, surely, they'll come to your aid, right?
                            They wouldn't just leave you here, would they?
                        [/p]
                        [p]
                            Desperation growing at the back of your head, you decide to play along with the boys' little [i]game[/i].
                            You reply that, no, you don't turn into a fish, but you might become a scary crocodile if they don't let you out soon!
                            "[color=blue]A crocodile?[/color]" answers the third child, in a satirical tone.
                            "[color=blue]A kobold like you is more likely to turn into an [i]alley-gay-whore[/i]![/color]"
                        [/p]
                        [p]
                            The audacity!
                            Where does a young boy even pick up such vulgar words?!
                            All three begin to cackle loudly, laughing their asses off at the third boy's joke.
                            Stupid inbred farmer hicks not raising their kids right.
                            The laughter goes on for the better half of a minute.
                            You're starting to lose your patience with these kids.
                        [/p]
                        [p]
                            The laughter slowly dies down.
                            All three of the kids' heads turn towards the same direction.
                            "[color=red]We're being careful, mom![/color]"
                            You overhear one of the boys replying to who you can only imagine to be his mother.
                            "[color=red]Fiiiine! Let's go.[/color]"
                        [/p]
                        [p]
                            Without even giving you a proper goodbye,
                            and more importantly: without telling this [i]mother[/i] figure about the [b]kobold trapped in the well[/b],
                            the boys hop off of the edge of the well, and disappear from sight.
                            You shout for them to come back, to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Calling for help clearly won't get you anywhere.
                            If the children of the hamlet won't help you, then you have little hope for the adults.
                        [/p]
                        [p]
                            Suddenly, a rope falls into the water, right next to you.
                            Wait, what?
                            A rope?
                            Where did that come from?!
                            You look upwards, but you see nobody there.
                            How weird.
                            You give the cord a tug.
                            It seems to be secured to something.
                            That means you can use it to climb out!
                            Someone just [b]saved[/b] you!
                        [/p]
                        ${global.ui.condSucc(`Charisma greater than 5`)}
                        [p]
                            Maybe one of the kids [b]did[/b] care, or perhaps a random passerby decided to help you out.
                            Regardless, you don't have much time to think things over. 
                            If you wait too long, something [i]bad[/i] might happen to [b]ruin[/b] your one and only hope of getting out of here.
                            Something bad [b]always[/b] happens.
                        [/p]
                        [p]
                            But not this time.
                            You're not going to take any chances sitting here pondering just [i]who[/i] it was that came to your rescue.
                            You'll see for yourself when you get out of the well.
                            You immediately grab the rope, and begin to shimmy upwards, towards your freedom.
                        [/p]
                        [p]
                            While the climb is exhausting, at least the rope makes it somewhat bearable.
                            You press your feet against the wall, and vertically walk to safety, pulling yourself upwards one step at a time.
                            A few minutes later, you find yourself at the very top, and after climbing over the small above-ground portion of the well,
                            your feet plop down on steady ground once more.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have escaped the well!
                                [/b]
                            [/c]
                        [/p]
                        [p]
                            After dropping to your knees and only [i]barely[/i] preventing yourself from kissing the dirt out of sheer joy,
                            you stand up and look for your oh-so kind benefactor.
                            However, there is nobody to be found.
                            The hamlet looks as deserted as it did the moment you entered it.
                        [/p]
                        [p]
                            You are left with more questions than answers.
                            Who saved you?
                            Was it one of the kids?
                            A farmer?
                            A random, compassionate guard passing by the area?
                            You're glad you got out, but you'd at least like to [b]thank[/b] whoever helped you.
                            Alas, it seems your [i]sympathizer[/i] wishes to remain anonymous.
                            A shame.
                        [/p]
                        [p]
                            With mixed feelings, you decide you've stuck around the hamlet for too long already.
                            It's time to get moving.
                            If you hurry, you might still make it to Varanar before nightfall.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
