/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWater(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellArrivalChoice.WATER;
    var reqController = ctrl.arrival;

    var toFail = new HamletWellWaterFail(ctrl, firstNext, secondNext, thirdNext);
    var toSuccess = new HamletWellWaterSucceed(ctrl, firstNext, secondNext, thirdNext);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.strength() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.imageBackground.hide();
        global.ui.applyTheme("hamlet_well");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}
