/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveObserve(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveFightChoice.OBSERVE;
    var reqController = ctrl.fight;
    var changeController = false;

    var continueId = arguments.callee.name + "ButtonOne";

    var idsToRemove = [
        "UndergroundCaveObserve",
        "UndergroundCaveFight",
        "UndergroundCaveResistSucceed",
        "UndergroundCaveResist",
        "UndergroundCaveStare",
        "UndergroundCaveAvert",
        "UndergroundCaveSurface"
    ];

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var petri = ctrl.stare.get();
        var toReturn = `[p]
                            You need to be well-aware of the slippery lizard's actions.
                            One wrong move, and you could very well end up injured or even [b]dead[/b].
                            Before committing to actual combat, you decide to [i]study[/i] the basilisk first.
                            If you know how it moves, you'll be better able to avoid its blows.
                            At least in theory.
                        [/p]
                        [p]
                            You keep some distance between the creature and you, taking a step back whenever it tries to close the gap.
                            While slow in general, you note that it can burst into short, speedy sprints.
                            You don't allow it close enough to test out your theory, but you imagine its attacks must be somewhat similar:
                            slow in general, with some lightning-fast shots mixed in.
                            While the former will probably [b]not[/b] be a major threat, it is latter that you fear the most.
                            A simple flick of its tail, for instance, could push you off balance, after which you'll be easy prey for the beast.
                        [/p]
                        [p]
                            While observing the basilisk, you find your sight drifting towards its eyes over and over again.
                            The creature's bright irises dance and twirl, like a smidgen of milk in a bowl of soup that's being constantly stirred.
                            It's [b]intriguing[/b].
                            [b]Hypnotizing[/b].
                            The entire cave feels like a pitch-black [b]void[/b] with the eyes at its very center.
                            While you know you shouldn't, you can't help [b]but[/b] gaze into the abyss.
                            Before long, you find yourself [i]lost[/i] in the alluring, mind-emptying void that is the creature's stare${petri ? ` yet again` : ``}.
                        [/p]`;

        if (petri) {
            toReturn += `
                        [p]
                            This time, instead of taking several minutes, you find yourself starting to petrify within [b]seconds[/b].
                            Feeling threatened, the basilisk must have upped its game.
                            Your mind [b]screams[/b] for you to look away, but your body fails to heed the mental beckoning,
                            your panicking thoughts drowned out by [b]emptiness[/b], brought about by the mere sight of the emerald eyes in front of you.
                            Instead of averting your gaze, you keep blankly staring as a rock-like texture overtakes your extremities.
                            Your limbs petrify, and before you know it, you are frozen in place for a second time.
                        [/p]`;
        } else {
            toReturn += ` 
                        [p]
                            Within seconds, you can start to feel your limbs stiffen, your scales rapidly turning to stone.
                            Your mind [b]screams[/b] for you to look away, but your body fails to heed the mental beckoning,
                            your panicking thoughts drowned out by [b]emptiness[/b], brought about by the mere sight of the emerald eyes in front of you.
                            Instead of averting your gaze, you keep blankly staring as a rock-like texture overtakes your extremities.
                            Your limbs petrify, and before you know it, you are frozen in place.
                        [/p]`;
        }

        toReturn += `   [p]
                            But you aren't out of your trance yet.
                            Even though the entire exterior of your body has already turned to stone, you simply keep staring.
                            You feel the petrification dig [b]deeper[/b], your very flesh becoming cold, hard rock.
                            The basilisk's eyes prove [i]comforting[/i], dulling your aching mind while your very bones fossilize.
                        [/p]
                        [p]
                            Right before the intrusive blight reaches your vital organs, the basilisk suddenly breaks eyecontact, and surges forwards, towards you.
                            No longer having the sweet, hypnotizing, relieving comfort of staring into its eyes, you find yourself [b]panicking[/b].
                            You can barely [b]breathe[/b], your rock-hard chest keeping your lungs permanently compressed.
                            Your heart has a hard time pumping, almost completely encased in stone.
                            Many of your veins have slipped shut.
                            Whatever feeling you still had in your hands and your feet soon fades, blood circulation entirely cut off.
                        [/p]
                        [p]
                            Luckily, your agony is short-lived.
                            The monster viciously [b]rakes[/b] at one of your petrified legs,
                            its incredibly sharp and powerful claws [b]easily[/b] tearing through the hard, yet brittle rock,
                            ripping out an entire chunk of stone, completely [b]severing[/b] your foot from the rest of your body.
                        [/p]
                        [p]
                            You feel no pain, yet your mind is flooded with [b]terror[/b].
                            An intense [b]fear[/b] of death washes over you, which only intesifies as you realize you [b]aren't[/b] [i]stable[/i] anymore.
                            With one foot no longer supporting you, and no way to readjust the other, your body slowly starts to topple to the side.
                            You feel sick to your stomach, not even able to utter a scream as you tumble to the ground, your fate sealed.
                            The last thing you hear, before losing consciousness, 
                            is the sound of your own body [b]shattering[/b] against the cavern floor,
                            breaking into a million pieces.
                        [/p]
                        [p]
                            As the debris of your stone-turned body settles down,
                            the basilisk immediately begins picking through it for the tender,
                            juicy innards that were trapped within the stone shell.
                            It's not every day that the beast could have such a feast.
                            While the organs are succulent,
                            the few small morsels of unpetrified flesh that the monster can find, sate it the most.
                            No wonder humans butcher kobolds.
                            Their meat really [b]is[/b] a delicacy, to feral and anthro alike.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    Rock end.
                                [/b]
                            [/c]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" style="margin-left: auto; position: relative; float: right;" id="${continueId}">`;
        choice += `&lt;&lt Revert`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400, function () {
            var main = $("#main");
            main.scrollTop(main[0].scrollHeight - main.height() - 5); // Fix scrolling
        });
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.misc.unsetAll();
            ctrl.fight.unset();
            ctrl.resistSucceed.undo();
            ctrl.resistSucceed.unset();
            ctrl.stare.undo();
            ctrl.stare.unset();
            ctrl.avert.undo();
            ctrl.avert.unset();
            ctrl.surface.undo();
            ctrl.surface.unset();
            for (var i = 0; i < idsToRemove.length; i++) {
                $("#" + idsToRemove[i]).remove();
            }
            loadNextPart(ctrl.fragments.surface);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        registerContinueListener();
    };
}
