/**
 * Reflect section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveReflectionLeaveContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = ctrl.reflectLeaveContinue;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You run alongside the water as best you can,
                            scared the basilisk might chase after you still.
                            You nearly fall down, only barely managing to retain your balance, and decide to lower your pace to a brisk march instead.
                            A few minutes of expeditious walking later, daylight comes into sight.
                            As you expected: the water was a stale branch of the river!
                            Climbing out of the cave, you sit your butt down on the riverside dirt, and take a breather.
                            You feel like you've earned one.
                        [/p]
                        [p]
                            You find yourself close to the road to Varanar.
                            In fact, you believe you passed this very place earlier, when heading for the hamlet.
                            You never knew there was a cave here, but then again,
                            you've never really bothered to scour the edge of the river for points of interest.
                        [/p]
                        [p]
                            You've defied death more than once today.
                            You should consider yourself lucky to be alive.
                            The trip into the well was a harrowing experience.
                            You nearly got crushed, almost drowned, and after all of that, you managed to subdue a basilisk.
                            Or at least you [i]prevented[/i] it from [b]killing you[/b].
                        [/p]
                        [p]
                            You've gained a few awesome stories to tell once you've grown old and wise.
                            Stories like the ones Seki used to tell you when you were little.
                            You went through all that trouble to get your mind off of him, and here you are reminiscing once more.
                            You just can't help yourself from clinging to times long gone.
                            Things were so much simpler back then.
                            You miss those days.
                        [/p]
                        [p]
                            The sun is slowly starting to set.
                            You drag yourself to your feet.
                            It's time to go.
                            Varanar isn't [i]that[/i] far off.
                            If your legs don't give out from underneath you, you might still make it there before nightfall.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
