/**
 * Arrival section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorNoGold(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeParlorEntranceChoice.NOGOLD;
    var reqController = false; // Set manually
    var subController = ctrl.secondOffer;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = ctrl.fragments.secondDecline;
    var secondNext = ctrl.fragments.noGoldAccept;

    var firstChoice = ctrl.secondChoice.DECLINE;
    var secondChoice = ctrl.secondChoice.ACCEPT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var barterSuccess = global.kobold.history.shared.varanar.dayThree.afternoon.parlorBargainSuccess;
        var barterAttempted = reqController === ctrl.bargain;
        var couldHaveBoughtIfBarterSucceeded = barterAttempted && ctrl.misc.gold() > 19;
        var toReturn = `[p]
                            Sadly,
                            ${barterSuccess ? `even [i]with[/i] the price halved, you still can not afford a massage.
                            ` : couldHaveBoughtIfBarterSucceeded ? `because Tychus refuses to halve the price, you can not afford a massage.
                            ` : barterAttempted ? `even [i]if[/i] Tychus had halved the price, you still would not have been able to afford a massage.
                            ` : `you can't really [i]afford[/i] a massage.`}
                            ${barterAttempted ? `Once more, you` : `You`} look up at Tychus with a devestated look on your face,
                            putting on your best [i]puppy eyes[/i], your [i]cutesy[/i] look complete with a trembling mouth and watering eyes.
                            You were [b]really[/b] looking forward to a massage, but you can't have one because you don't have enough money!
                            You almost burst out into tears, your sadness half-acted, and partially based in reality.
                        [/p]
                        [p]
                            The human sighs.
                            At first, he resolutely looks away, but as you continue to stare up at him looking like a scolded child denied a treat,
                            he slowly turns to face you once more.
                            Another sigh.
                            ${barterAttempted ? `` : `He rolls his eyes.`}
                            "[color=purple]${barterSuccess ? `Why even barter me down to half if you still can't pay? Dumb kobold. ` : ``}Fine.
                            You get a [b]freebie[/b].
                            Just this [b]once[/b].
                            You'll be back for more anyway, after you feel how [b]amazing[/b] a massage can be.[/color]"
                        [/p]
                        [p]
                            Wait, what?
                            [b]Really[/b]?
                            That was [b]easy[/b].
                            [b]Too[/b] easy, in fact.
                            You wonder if there are [i]ulterior motives[/i] at play here.
                            But, while you [i]are[/i] wary of [b]any[/b] gifts handed to you by a human,
                            you actually [b]do[/b] kind of want a massage.
                            You are left conflicted.
                            What should you do?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`Something's fishy here. You think it's time for you to leave.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`Well, if it's free, then you don't see why not!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        reqController = ctrl.entrance;
        if (reqController.get() === AfternoonThreeParlorEntranceChoice.BARTER) {
            reqController = ctrl.bargain;
        }

        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}
