/**
 * End section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorFightLoot(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.fight;
    var changeController = ctrl.fightLoot;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After a minute of indulging in the rare feeling of [b]pride[/b],
                            your mind settles down from the adrenaline rush that fueled your combat prowess.
                            You did it!
                            You beat the insane man that picked a fight with you because you declined a massage!
                            You've done a favor to the city, and no doubt to the kobolds he was [i]employing[/i].
                        [/p]
                        [p]
                            Then again, the [i]law[/i] might not see it that way.
                            You just [b]assaulted[/b] and perhaps even [b]killed[/b] a human.
                            He was a prick, and he totally deserved what happened to him, but he has rights, and you don't.
                            While you would love to stay and spread the good news to your peers,
                            someone might have [b]heard[/b] the struggle that took place.
                        [/p]
                        [p]
                            It'd be best if you took whatever you can and got the hell out of here [i]before[/i] anyone comes to investigate.
                            You bolt around the room, investigating a few points of interest, swiftly and superficially searching some cupboards and racks.
                            A tiny haul.
                            A bit of ${global.kobold.inventory.createItemWithTooltip(new aPlusLotion())} and some coins.
                            Not a lot, but more than nothing!
                            With your loot in hand, you bolt out of the door, and make yourself scarce from the slums.
                            A few minutes later, you find yourself in the mercantile district.
                            You're fairly certain nobody saw you leave the massage parlor, and you don't think anyone followed you, so you must be in the clear!
                        [/p]
                        [p]
                            You did a [b]good[/b] thing today.
                            Well, about as good as killing someone can be.
                            Anyway, the sun is slowly starting to set.
                            The afternoon is turning into a dark and cold winter evening.
                            It's time to figure out where you're going to sleep.
                            Maybe you can [b]smite[/b] some more [b]evildoers[/b] tomorrow!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
