/**
 * End section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorFreeRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeParlorKillFreeChoice.REFUSE;
    var reqController = ctrl.killFree;
    var changeController = ctrl.killFreeRefuse;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You kindly decline her inappropriate advances,
                            thinking that perhaps she was [i]trained[/i] to offer such services,
                            and agreeing would be kind of [i]taking advantage[/i] of Red.
                            She shrugs.
                            "[color=bred]Well, I don't have much else to offer my [i]gratitude[/i] with.
                            Are you sure you don't want to...?[/color]"
                            You resolutely shake your head no.
                            The kobold sighs.
                        [/p]
                        [p]
                            "[color=bred]Fine, but you'd best get going.
                            Before Green goes [b]mental[/b] and starts attacking you or something.[/color]"
                            Given how the male kobold hasn't calmed down one bit, you don't doubt that that is a [b]very[/b] real possibility.
                            Receiving not so much as a [i]thank you[/i],
                            you walk towards the front door, and exit the building.
                            You're confident those three'll do fine without you.
                            They just need a while to recover.
                            They'll be back to their old selves in no-time.
                            And if they're not, Red seemed clever enough to keep them out of trouble.
                        [/p]
                        [p]
                            Closing the door behind you, you are left with mixed feelings.
                            The way those three reacted to seeing their dead master, perhaps they would have been better off [i]not[/i] being rescued?
                            Maybe they [b]liked[/b] it there.
                            Did you end up doing something bad instead of something good?
                            If being a knight involves complex situations like these, maybe you're better off remaining a thief.
                        [/p]
                        [p]
                            Oh well, at least you got to [b]smite[/b] an [b]evildoer[/b].
                            But now, you'd better get out of here.
                            [b]Before[/b] Varanar's guards get involved in this entire ordeal.
                            You walk towards the mercantile district.
                            The sun is slowly starting to set.
                            The afternoon is turning into a dark and cold winter evening.
                            It's time to figure out where you're going to sleep.
                            Maybe tomorrow, you can find some more [b]grateful[/b] kobolds to free.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
