/**
 * Masseuse section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorMasseuseTrapFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preFail;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.masseuseFail;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            She hasn't noticed you yet.
                            That gives you the element of surprise.
                            If you play your cards right, you might be able to knock her out [i]before[/i] she can alarm Tychus.
                            Hm, your best course of action would be to lure her towards you, away from the human.
                            Since she'll be coming to you, it might be wise to place a [b]trap[/b].
                        [/p]
                        [p]
                            You grab some of the rope you were tied down with,
                            and re-string it in front of the door, around ankle-height.
                            If Orange comes through here, she'll trip over the wire, and that's when you'll get her good!
                            Your trap in place, you quietly close the door once more.
                            Then, you set your plan in motion, by loudly [b]knocking[/b] on the table,
                            pretending to have recently woken up.
                        [/p]
                        ${global.ui.condFail(`Intelligence below 6`)}
                        [p]
                            A few moments later, the door opens, but not fully.
                            In a fit of stupidity, you tied the rope to the door itself, blocking it, preventing it from opening all the way.
                            Orange, alerted to your trap, easily steps over the cord you strung.
                            You kind of hadn't planned for this.
                            Dumbstruck, you find nothing better to do than to wave hello to your masseuse.
                        [/p]
                        [p]
                            She doesn't seem to happy to see you.
                            In fact, she punches you straight in the face, knocking you down on your ass.
                            Her punch is quickly followed by a kick to your face,
                            and instead of falling for your trap, the masseuse knocks you out cold.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
