/**
 * Shop section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreShop(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preStore;
    var subController = ctrl.store;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreFinishSelector(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Noticing you haven't left yet, the dragon rolls his eyes.
                            "[color=yellow]There's a bargain bin in the corner, filled with things even [i]you[/i] might be able to afford.[/color]"
                            The merchant points towards a rusty bucket filled with a bunch of junk and some less-than-incredible items.
                            "[color=yellow]Either buy something, or kindly [b]get out[/b].[/color]"
                        [/p]
                        [p][sneak]
                            You are in a safe zone.
                            You can use items from your inventory here.
                            You are in a store.
                            You can sell items from your inventory here.
                            You may buy items from the list below.
                            Keep in mind that all purchases are final.
                            Worn equipment can not be sold.
                            Buying equipment will discard your previous attire.
                        [/sneak][/p]`;
        toReturn += ctrl.store.getGenerator().build();
        toReturn += `[p][sneak]
                            Remember that you can not drink potions or eat food outside of safe zones.
                            You might want to use some of the items you've purchased before continuing.
                        [/sneak][/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            ctrl.store.getGenerator().disable();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
        ctrl.store.getGenerator().registerListeners();
    };
}
