/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoCrudeLose(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    var idsToRemove = [
        "NightTwoCrudeLose",
        "NightTwoCrudeFight",
        "NightTwoCrudeRude",
        "NightTwoCrude",
        "NightTwoConfront",
        "NightTwoRunIn",
        "NightTwoStage"
    ];

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var toReturn = `[p]
                            No.
                            You aren't going to let them do this.
                            You can't and you [b]won't[/b] get [b]anywhere[/b] near that filthy human's disgusting rear, let alone pressing your lips against it!
                            [b]Over your dead body.[/b]
                            They may be stronger than you, they may outnumber you, they may have you in an arm-grip,
                            but all of that just means they [b]won't[/b] be [i]expecting[/i] you to go on the offensive.
                        [/p]
                        [p]
                            They think they have you scared shitless, that you're just another kobold for them to [b]bully[/b] and [b]abuse[/b],
                            that you won't put up a fight simply because this is [b]their[/b] town.
                            But you aren't any ordinary run-of-the-mill lizard.
                            The other members of your kind may be content being thieves, or bandits or prostitutes or beggars, but not [b]you[/b].
                            You may be a thief right now, but you [b]aspire[/b] to be a [b]knight[/b].
                            And knights don't back down in the face of adversity.
                            They charge head-forward into danger.
                            Just like you're about to do.
                        [/p]`;

        if (weapon) {
            toReturn += `[p]
                            While one of your arms is being restrained, you reach for your ${global.kobold.inventory.createItemWithTooltip(weapon)} with the other.
                            With your head being forced ever-closer to the drunkard's butt, you decide to strike before your snout brushes against his body hair.
                            Swiftly and silently, you [b]surge[/b] your weapon forwards, intent on striking the oaf's rear,
                            yet before your strike manages to connect, your free arm is grabbed and painfully twisted, much like the other.
                            With a pained yelp, you drop your ${global.kobold.inventory.createItemWithTooltip(weapon)} to the ground,
                            where it is quickly picked up by one of the humans, who promptly [b]bashes[/b] you on the head with it.
                        [/p]`;
        } else {
            toReturn += `[p]
                            While one of your arms is being restrained, you lash out with the other, intent on striking the oaf's rear,
                            yet before your strike manages to connect, your free arm is grabbed and painfully twisted, much like the other.
                            You let out a pained yelp.
                            Your attempted aggression is soon punished, one of the humans brutally [b]bashing[/b] the top of your head with his balled up hand.
                        [/p]`;
        }

        toReturn += `   ${global.ui.condFail(weapon ? `${global.kobold.inventory.createItemWithTooltip(weapon, true)} offence below 4` : `No weapon`)}
                        [p]
                            Your vision fades to black.
                            You lose consciousness.
                            You dream about a ceremony.
                            One in your honor.
                            You are in a castle.
                            There's princes and princesses, barons and dukes, royals from all corners of the world.
                            You are kneeling.
                            The Dragon King himself puts a gilded blade atop your shoulder.
                            Then suddenly, the dream turns into a nightmare, the castle replaced by a terrible, all-consuming void that sucks you into its core.
                            Once the void has consumed all, you are left with nothing, not even yourself.
                            The nightmare ends, and so do you.
                            In the real world, the men kicked you to death for passing out instead of doing their bidding.
                            Luckily, you were not awake to witness the horrible pain inflicted upon you.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    Nightmare ending.
                                [/b]
                            [/c]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" style="margin-left: auto; position: relative; float: right;" id="${continueId}">`;
        choice += `&lt;&lt Revert`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400, function () {
            var main = $("#main");
            main.scrollTop(main[0].scrollHeight - main.height() - 5); // Fix scrolling
        });
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.misc.unsetAll();
            ctrl.rude.undo();
            ctrl.rude.unset();
            ctrl.lewdCrude.undo();
            ctrl.lewdCrude.unset();
            ctrl.runin.unset();
            ctrl.stage.unset();
            for (var i = 0; i < idsToRemove.length; i++) {
                $("#" + idsToRemove[i]).remove();
            }
            loadNextPart(new NightTwoStage(ctrl));
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        global.ui.applyTheme("varanar_morning");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        registerContinueListener();
    };
}
