/**
 * Confrontation section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoLewdStruggleContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You are absolutely [b]disgusted[/b].
                            Sickened, not only by what you were made to do, but by yourself, and by society as a whole.
                            [b]Nobody[/b] should be forced to do something so [b]foul[/b] and [b]revolting[/b] just to settle some stupid drunken quarrel.
                            You cry for what seems like an eternity, stuck in between wanting to throw up, and not being able to.
                            The ground is as cold as the hearts of the humans that humiliated you.
                        [/p]
                        [p]
                            The sun slowly rises above the building-rooftops, and as you feel its first warming rays shine atop your back,
                            you pick yourself off the ground, along with the broken pieces of your shattered self-image.
                            While staying on the ground until you [b]die[/b] sounds like a good plan right now,
                            you decide it'd be best if you made your way back to the city square.
                            You won't be getting any sleep tonight.
                            At least you learned a valuable lesson: humans are [b]not[/b] nice people.
                            They [b]hate[/b] your kind, and you shouldn't trust them any further than you can throw them,
                            which isn't very far at all.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.lewdStruggle.continued()) {
            return "";
        }

        global.ui.applyTheme("varanar_morning");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.endChange.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.lewdStruggle.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
