

// SCENE VaranarSoupKitchen

// scenes\Varanar\DayThree\VaranarSoupKitchen\fail\VaranarSoupKitchenHalfApple.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenHalfApple(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = ctrl.halfApple;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Denied your meal, and kicked back out onto the cold streets, you decide to go back to your [i]original[/i] plan.
                            You scrounge the town square, crawling through the dirt looking for anything left to eat.
                            Almost [b]everything[/b] has been picked clean already, probably by [i]other kobolds[/i].
                            Right as you were about to give up hope completely, you find a single half-eaten apple concealed underneath a dropped handkerchief.
                        [/p]
                        [p]
                            You pick up the day-old, half-eaten fruit.
                            No worms, no bird-pecking marks, a bit of grime, but you wipe most of it off using the handkerchief.
                            Better than nothing, and you've had [b]far[/b] worse to eat in the past.
                            You feel like you [b]need[/b] to eat something, or you'll pass out.
                            Here goes nothing.
                        [/p]
                        [p]
                            You take a first bite into the apple.
                            It's still quite [i]hard[/i], having retained much of its its firmness overnight due to the sub-zero temperatures out.
                            While the taste of [i]dirt[/i] is [b]very[/b] prevalent, underneath lies a satisfying, rather sweet treat.
                            Savoring the delightful flavor, you gobble down the rest of your unsanitary snack.
                            While not much, your midday meal gives you the energy boost you needed to keep on truckin'.
                        [/p]
                        [p]
                            Your hunger [i]somewhat[/i] sated, you decide to try your luck elsewhere.
                            Perhaps the grand avenue will hold some interesting sights to see.
                            Everything was already closed last night, but you're certain there'll be at least one store worth browsing.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\fail\VaranarSoupKitchenHalfApple.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatNoMention.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatNoMention(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatOfferChoice.DONOT;
    var reqController = ctrl.offer;
    var changeController = ctrl.noMention;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You lie and say the previous owner [i]gave it[/i] to you because she felt [b]bad[/b] for keeping kobolds as slaves.
                            You were actually on your way there to [b]free[/b] your enslaved kin, but hunger stopped you dead in your tracks.
                            And so you ended up here.
                        [/p]
                        [p]
                            You can tell that the sheep isn't buying you bullshit.
                            But part of him [b]wants[/b] to believe.
                            He closes his eyes, and his inquisitive gaze turns into a grateful smile.
                            "[color=ppink][i]Kuhbold[/i], ah cannae thank ye enough.
                            A home in the Hamlet is perfect, since that's where ah get all mah food from to begin with.[/color]"
                            He puts the bag with his wedding ring in it around his neck once more.
                        [/p]
                        [p]
                            "[color=ppink]Mah waif's work can continue.
                            Maybe, just maybe, the people of the world can someday truly go without hunger.
                            And if that day ever comes, you'll know you helped make it happen, [i]kuhbold[/i].[/color]"
                            The caprine rises from his seat, signalling for you to get to your feet as well.
                            The two of you walk to the door.
                        [/p]
                        [p]
                            "[color=ppink]You've done me a real favor today, ${male ? `lad` : `lass`}.
                            If ye ever ever need something, [b]anything[/b] at all, ye know where me.
                            For now, I'm going to go pack me things.
                            I'll take care of yer friends real good, don't you worry![/color]"
                            The two of you say goodbye.
                            Your chubby host opens the door for you,
                            and you stride back out into the coldness of the streets of Varanar, your heart heavy with mixed feelings.
                        [/p]
                        [p]
                            On one end, it feels good knowing that someone will look after those [i]enslaved[/i] kobolds Cassidy was keeping.
                            On the other end of the stick, you [i]kind of[/i] failed to tell him about the [b]dead body[/b] in the barn.
                            Who knows what the sheep'll do when he finds out you've handed him a dead person's home?
                            Come to think of it, you didn't even catch his name.
                            Oh well, you're certain things'll work out for the best.
                        [/p]
                        [p]
                            Your conscience somewhat cleared, your spirits lifted and your ego slightly boosted,
                            you set off for Varanar's grand evenue.
                            Last night, all the stores were closed,
                            but most of them should be open around now.
                            Time to see some sights!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatNoMention.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatMention.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatMention(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatOfferChoice.MENTION;
    var reqController = ctrl.offer;
    var changeController = ctrl.mention;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.gaveHouseMentioned = true;
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You look away and mention that you [i]might[/i] have had a [i]disagreement[/i] with the previous owner.
                            And, well, as far as you know, the psycho bitch's dead body is still around there somewhere.
                            The sheep glares at you, shaking his head.
                            You say you really didn't mean to kill her, 
                            but she had you [b]trapped[/b] on this [b]table[/b] and she wanted to all kinds of [b]bad things[/b] to you and--
                            "[color=ppink]Hush, [i]kuhbold[/i].[/color]" interrupts the caprine.
                            "[color=ppink]The less ah know 'bout this, the better.[/color]"
                        [/p]
                        [p]
                            The man sighs loudly, putting the bag with his wedding ring in it around his neck once more.
                            "[color=ppink]Listen here.
                            I'll take the house, I'll get rid of the body, and I'll feed yer friend.[/color]"
                            You try to mention that they aren't actually your [i]friends[/i],
                            but the sheep loudly clears his throat to indicate that you've said enough already.
                        [/p]
                        [p]
                            "[color=ppink]I'm doin' this only because me waif would have wanted it.
                            Ah thank ye for the house, but ye must understand that ah cannae approve of what ye did to obtain it yerself.
                            The guards'd have mah head if they knew ah was talkin' to ah [b]murderin'[/b] [i]kuhbold[/i].
                            Not turning ye in makes me an [i]accessory[/i], but I'll risk it for the sake of me waif's dream of a world without 'unger.[/color]"
                        [/p]
                        [p]
                            The fat man rises from his chair.
                            "[color=ppink]Thank ye once again.
                            This doesn't make up for what you've done,
                            but it at least puts ye on the path of redemption.
                            Don't go 'round 'killin' anyone else now, ye hear?
                            There's hope left for us all.
                            Even [b]murderers[/b] like you.[/color]"
                        [/p]
                        [p]
                            The sheep signals for you to rise to your feet.
                            The two of you walk to the front door.
                            "[color=ppink]I'm going upstairs to pack me things.
                            You've done a good deed today.
                            Let's keep the corpse between you and me, okay?[/color]"
                            You give the man a small nod.
                            "[color=ppink]Good ${male ? `lad` : `lass`}.
                            Off you go now.
                            Come visit some time, will ye?[/color]"
                        [/p]
                        [p]
                            Before you even have a chance to respond, the caprine opens the door,
                            and practically [b]pushes[/b] you out of the building, into the coldness of the streets.
                            You turn around to say goodbye, but he rudely slams the door in your face.
                            Ungrateful bastard.
                            Then again, he might just have been a little [i]shocked[/i] to know the person he took in and fed was a [b]murderer[/b].
                        [/p]
                        [p]
                            Oh well.
                            At least it feels good knowing that someone will look after those [i]enslaved[/i] kobolds Cassidy was keeping.
                            You believe you did a good thing, helping out the owner of the soup kitchen.
                            Come to think of it, you didn't even catch his name.
                            Oh well, he seemed like a reliable enough guy.
                            And hey, he managed to feed [b]you[/b], right?
                        [/p]
                        [p]
                            Your conscience clear, your spirits lifted and your ego slightly boosted,
                            you set off for Varanar's grand evenue.
                            Last night, all the stores were closed,
                            but most of them should be open around now.
                            Time to see some sights!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatMention.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatOffer.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatChoice.OFFER;
    var reqController = ctrl.eat;
    var subController = ctrl.offer;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenEatMention(ctrl);
    var secondNext = new VaranarSoupKitchenEatNoMention(ctrl);

    var firstChoice = VaranarSoupKitchenEatOfferChoice.MENTION;
    var secondChoice = VaranarSoupKitchenEatOfferChoice.DONOT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.gaveHouse = true;
        var toReturn = `[p]
                            At first, you can't really think of a way to console the man.
                            Then, suddenly, something comes to mind.
                            You're carrying a thing that might help.
                            A key.
                            ${global.kobold.inventory.createItemWithTooltip(new CassidyHouseKey())}.
                            You produce the small, metal object and slide it over the surface of the table towards the caprine.
                        [/p]
                        [p]
                            "[color=ppink]What's this?[/color]"
                            he asks, curiously picking your gift up from the table.
                            You explain that it's a [i]key[/i].
                            "[color=ppink]Ah know what ah key is, ye smartass.
                            What's it for?[/color]"
                            A house in the hamlet outside of town, you reply.
                            A [i]mansion[/i], more like.
                            The man eyes you suspiciously.
                            "[color=ppink]And what's that got tah do with me?[/color]"
                        [/p]
                        [p]
                            You explain that you don't really [b]need[/b] a mansion.
                            You have a shack in the woods, and you're content with that.
                            You could [b]give him[/b] the house, and he could continue his business there, if he'd like.
                            On one [i]condition[/i], that is.
                            There's a bunch of kobolds trapped in a barn attached to the house.
                            If he promises to free them and feed them, then by all means, he can have the place.
                        [/p]
                        [p]
                            You notice a twinkle of [i]hope[/i] flare up in the sheep's eyes.
                            Still, he remains wary.
                            "[color=ppink]And how'd [b]you[/b] get this [i]mansion[/i]?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Mention</button>`;

        var tooltip = global.parser.parse(`Mention there [i]might[/i] be a dead vixen present.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Do not</button>`;

        var tooltip = global.parser.parse(`He'll find out about Cassidy's corpse eventually. [i]If[/i] it's still there.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenEatOfferChoice = {
    MENTION: 1,
    DONOT: 2
};

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatOffer.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatLeave.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatChoice.LEAVE;
    var reqController = ctrl.eat;
    var changeController = ctrl.eatLeave;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You don't really know how to [i]console[/i] him,
                            so you settle for thanking the man for the food.
                            You feel better now.
                            A [b]lot[/b] better.
                            You're certain his wife is proud of him, wherever she may be.
                        [/p]
                        [p]
                            The man sighs.
                            "[color=ppink]Aye, aye.
                            Ah tried me hardest.
                            'Ave yeh finished yer meal?[/color]"
                            You nod.
                            "[color=ppink]Ah hate tah be rude, but could yeh maybe see yerself out?
                            Ah think ah need a moment alone.
                            To mahself.[/color]"
                            You say you understand, but you obviously don't.
                        [/p]
                        [p]
                            Getting up off your seat, you solemnly walk out the building the way you came.
                            Closing the door behind you, you let out an exasperated sigh.
                            That poor man.
                            The outside air is as cold as your heart felt when walking out on him.
                            But there's nothing you can do to help.
                            You've got your own issues to worry about.
                            While you [b]wish[/b] you were some kind of [b]hero[/b] or a [b]knight[/b],
                            you simply don't have the time or the resources to aid everyone in Varanar.
                        [/p]
                        [p]
                            Swallowing deeply, you set aside your empathetic sadness.
                            To take your mind off of trying to appease dead relatives,
                            you decide to take a stroll down the grand avenue.
                            None of the stores were open last night, but this time around,
                            you're certain there'll be at least [b]one[/b] shop able to pull your mind away from gloomy thoughts.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEatLeave.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEat.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEat(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenServedChoice.EAT;
    var reqController = ctrl.serve;
    var subController = ctrl.eat;
    var changeController = ctrl.eat;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenEatLeave(ctrl);
    var secondNext = new VaranarSoupKitchenEatOffer(ctrl);

    var firstChoice = VaranarSoupKitchenEatChoice.LEAVE;
    var secondChoice = VaranarSoupKitchenEatChoice.OFFER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.ate = true;
        var toReturn = `[p]
                            You take one of the wooden spoons lying atop the table,
                            and stir the viscous broth in front of you.
                            [b]Yuck.[/b]
                            The texture is inconsistent, far thicker near the bottom of the plate.
                            You'd rather not eat the soup, but you're feeling [b]way[/b] too hungry to pass up an opportunity like this.
                            You [b]need[/b] something to eat, and it's not like you haven't had worse.
                        [/p]
                        [p]
                            Scooping up a mixture of thick and less-thick liquid, you bring your spoon to your mouth, and loudly [b]slurp[/b] down its contents.
                            Your face sours, like the caprine's visage did before.
                            This was [b]definitely[/b] tomato soup once upon a time,
                            but now it's a barely edible mixture of broken-down vegetable chunks floating amidst
                            separated layers of concentrated tomato juice and murky water.
                            Given that the soup is only a day old, you doubt the tomatoes were very [i]fresh[/i] when being put in the pot to begin with.
                        [/p]
                        [p]
                            The taste isn't [i]too[/i] terrible, but the texture and the consistency is [b]revolting[/b].
                            Like that one time you ate the innards of a deer carcass without [i]removing[/i] them first.
                            While unpleasant to wrangle down your throat, your stomach grumbles, [b]begging[/b] for more of the somewhat nutritious goop.
                            Reluctantly, you down spoon after spoon of old tomato soup, until your plate is empty, save for a small layer at the bottom.
                        [/p]
                        [p]
                            As you finish up, the fat sheep enters the room once more, wiping an angry look off his face.
                            "[color=ppink]Sorreh 'bout that.[/color]" he speaks, taking a seat opposite to you once more.
                            "[color=ppink]Farmers from the 'amlet deliver leftover foodstuffs to the alley out ba~ack,
                            and some [i]kuhbolds[/i] that are [b]unwelcome[/b] 'ere oft'n try tah steal their meal from there instead.
                            Too ba~ad for them, the shipment that came yesterday was the last one [b]ever[/b].[/color]"
                        [/p]
                        [p]
                            You can tell the man is upset by having [i]lost[/i] his profession.
                            You ask him if there's any particular reason why he can't pay rent anymore.
                            "[color=ppink]'Twas the king that used to let us live here for free for as long as we kept the streets clean of starvin' lizards.
                            Him and mah waif had uhh...[i]met[/i] in the past.[/color]"
                            You get the feeling they did [b]more[/b] than just [i]meet[/i].
                            "[color=ppink]But then the king went on his lil' [i]crusade[/i] fightin' 'longside the dragons,
                            and now the ba~aron's in charge of the town.
                            Alas the ol' king did'nay tell his [i]regent[/i] about our little [i]agreement[/i].[/color]"
                            Oh dear.
                        [/p]
                        [p]
                            "[color=ppink]Even after me waif died, ah spent every coin I had on rent, tah try and keep this place open, but it's no use.
                            Produce, the farmers give for free, but without a place tah cook and serve it in, it's useless.[/color]"
                            The caprine picks up the bag he put on the table before, and presses it to his chest.
                            "[color=ppink]I've failed ye, me precious Ewelyn.
                            Please fahrgive meh.[/color]"
                            The man snickers.
                            A single tear rolls down his face.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Leave</button>`;

        var tooltip = global.parser.parse(`This has gotten way more awkward than it should have been.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var hasItem = ctrl.misc.hasMisc(new CassidyHouseKey());
        var disabled = subController.has() || !hasItem ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Offer house</button>`;

        var tooltip = global.parser.parse(`Offer the man Cassidy's residence. She won't be needing it anymore. And he can take care of the kobolds.`);
        if (!hasItem) {
            tooltip = global.parser.parse(`You don't have a house to offer.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenEatChoice = {
    LEAVE: 1,
    OFFER: 2
};

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\eat\VaranarSoupKitchenEat.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenLeave.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenServedChoice.LEAVE;
    var reqController = ctrl.serve;
    var changeController = ctrl.leave;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You take one of the wooden spoons lying atop the table,
                            and stir the viscous broth in front of you.
                            [b]Yuck.[/b]
                            The texture is inconsistent, far thicker near the bottom of the plate.
                            You're not eating this.
                            You'd get [b]sick[/b] if you did.
                        [/p]
                        [p]
                            While you appreciate the sheep's hospitality,
                            you don't have the heart to tell him face-to-face that you'd rather not eat his [i]leftovers[/i].
                            After all, you made him get out of his bathtub and technically even [i]retirement[/i], just for you.
                            Instead of waiting for him to come back, you get up off your chair,
                            sneak towards the door you came in through, and quietly exit the building.
                        [/p]
                        [p]
                            Back onto the cold streets, you decide to go back to your [i]original[/i] plan.
                            You scrounge the town square, crawling through the dirt looking for anything left to eat.
                            Almost [b]everything[/b] has been picked clean already, probably by [i]other kobolds[/i].
                            Right as you were about to give up hope completely, you find a single half-eaten apple concealed underneath a dropped handkerchief.
                        [/p]
                        [p]
                            You pick up the day-old, half-eaten fruit.
                            No worms, no bird-pecking marks, a bit of grime, but you wipe most of it off using the handkerchief.
                            Better than nothing, and you've had [b]far[/b] worse to eat in the past.
                            You feel like you [b]need[/b] to eat something, or you'll pass out.
                            Here goes nothing.
                        [/p]
                        [p]
                            You take a first bite into the apple.
                            It's still quite [i]hard[/i], having retained much of its its firmness overnight due to the sub-zero temperatures out.
                            While the taste of [i]dirt[/i] is [b]very[/b] prevalent, underneath lies a satisfying, rather sweet treat.
                            Savoring the delightful flavor, you gobble down the rest of your unsanitary snack.
                            While not much, your midday meal gives you the energy boost you needed to keep on truckin'.
                        [/p]
                        [p]
                            Your hunger [i]somewhat[/i] sated, you decide to try your luck elsewhere.
                            Perhaps the grand avenue will hold some interesting sights to see.
                            Everything was already closed last night, but you're certain there'll be at least one store worth browsing.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenLeave.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenSteal.js

/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenSteal(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenServedChoice.STEAL;
    var reqController = ctrl.serve;
    var changeController = ctrl.steal;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.stole = true;
        var toReturn = `[p]
                            While you appreciate the sheep's hospitality,
                            he made a [b]very[/b] big made mistake.
                            He left what you presume to be one of his most valuable possessions in the same room as a kobold, without any supervision whatsoever.
                            What did he [b]think[/b] was going to happen?
                            That you were going to sit here and eat this old broth while being [b]tempted[/b] by the promise of riches and gold?
                            What an [b]idiot[/b].
                        [/p]
                        [p]
                            The caprine doesn't have any excuse.
                            He's been working with your kind for [b]years[/b].
                            He should have known what would happen if he left his wedding ring alone with you.
                            Heck, you're surprised the fat man has managed to hold onto it for this long.
                            It being stolen at one point or another was inevitable.
                            You're just helping the natural order of things along.
                        [/p]
                        [p]
                            Your decision rationalized, you reach out for the small bag.
                            Opening it up, you discover a shiny ${global.kobold.inventory.createItemWithTooltip(new GoldRing())} within.
                            It looks brand new, despite obviously being rather old.
                            The sheep must have kept it in good condition ever since his wife died.
                            This must be the only thing he has to remember her by, especially now that the soup kitchen has closed down.
                            Almost kind of sad, but you really [b]need[/b] the money.
                            Rather the caprine upset, than you [b]dead[/b].
                            Your loot in hand, you get up off your chair,
                            sneak towards the door you came in through, and quietly exit the building.
                        [/p]
                        [p]
                            Back onto the cold streets, you immediately [b]bolt[/b] towards the grand avenue,
                            to hide within the masses of people on the streets, should the fat man come looking for you after he figures out what you took.
                            Adrenaline somewhat suppresses your hunger, making you forget all about your rumbling stomach.
                            With a golden ring as your haul, you can buy [b]proper[/b] food later.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenSteal.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenServed.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenServed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.serveChoice;
    var subController = ctrl.serve;
    var changeController = ctrl.serve;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new VaranarSoupKitchenSteal(ctrl);
    var secondNext = new VaranarSoupKitchenLeave(ctrl);
    var thirdNext = new VaranarSoupKitchenEat(ctrl);

    var firstChoice = VaranarSoupKitchenServedChoice.STEAL;
    var secondChoice = VaranarSoupKitchenServedChoice.LEAVE;
    var thirdChoice = VaranarSoupKitchenServedChoice.EAT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.served = true;
        var toReturn = ``;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Steal</button>`;

        var tooltip = global.parser.parse(`Take the ring. You need it way more than he does.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Leave</button>`;

        var tooltip = global.parser.parse(`You're not eating this slop. Silently leave the way you came.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Eat</button>`;

        var tooltip = global.parser.parse(`It may not be very appetizing, but it's better than nothing.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 155px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var VaranarSoupKitchenServedChoice = {
    STEAL: 1,
    LEAVE: 2,
    EAT: 3
};

// END scenes\Varanar\DayThree\VaranarSoupKitchen\served\VaranarSoupKitchenServed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLieSucceed.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenLieSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You tell the man a lie.
                            The bag around your neck isn't filled with coins.
                            It's filled with trinkets passed down from generation to generation,
                            ultimately falling into your hands.
                            You [i]could[/i] pawn it off, but doing so would be a great insult to your ancestors,
                            and you'd rather not risk the wrath of ghosts trapped in the afterlife.
                            You have enough [i]living[/i] problems to worry about as-is.
                        [/p]
                        [p]
                            "[color=ppink]Hmph.
                            I've heard many a [i]kuhbold[/i] claim tah be more broke than they actually are.
                            [b]Lying.[/b]
                            That's one thing yer kind is good at, isn't it?
                            How do I know you're not tellin' meh a lie?
                            If that ba~ag you're carryin' really is filled with ancient ba~aubles,
                            then let's open'er up and 'ave a look![/color]"
                        [/p]
                        [p]
                            Uh-oh.
                            You didn't expect the caprine to be smarter than he looks.
                            But you aren't out of tricks yet.
                            You stare up at the sheep, an offended frown forming on your face.
                            You [b]angrily[/b] ask him how he even [b]dares[/b] suggest to open up a purse that hasn't been opened in over a hundred years.
                            Does he [b]hate[/b] kobold traditions, or is he just [b]trying[/b] to make you mad?!
                        [/p]
                        [p]
                            "[color=ppink]That ba~ag doesn't look a hundred years old to me, ${male ? `lad` : `lass`}.[/color]"
                            comes the man's retort.
                            Hmph.
                            Looks like you're going to have to bring out your best if you want to fool him.
                            Your family has kept the pouch in top condition for all these years,
                            only for some [b]mean sheep[/b] to [b]harass[/b] you about it.
                            A few fake tears well up in the corners of your eyes.
                            You let out a well-acted snicker.
                            If your mother was still alive to see you [b]begging[/b] for scraps,
                            she'd [b]cut off[/b] her own arm and feed it to you instead of having you reduced to [b]tears[/b] in return for a measily handout.
                        [/p]
                        [p]
                            "[color=ppink]Alright, alright.
                            Stop yer cryin'.[/color]"
                            the caprine responds.
                            "[color=ppink]I'll get yeh some soup, okay?
                            I'm sorry for doubtin' ye.
                            I've seen a lot of frauds in mah day.
                            And I can't feed [b]all[/b] of yeh, understand?[/color]"
                            Hah.
                            Got'em.
                            While continuing to pretend to be sad, you nod and meekly stammer out that it's okay.
                        [/p]
                        ${global.ui.condSucc(`Charisma greater than 6`)}
                        [p]
                            Patting you on the head, the fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            Wiping your crocodillian tears, you take a seat at the table nearest to you.
                            The sheep uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch of his own, similar to yours, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            This is my memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You enjoy yer meal, [i]kuhbold[/i].
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLieSucceed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLieFail.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenLieFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.lieFail;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.apple;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You tell the man a lie.
                            The bag around your neck isn't filled with coins.
                            It's filled with trinkets passed down from generation to generation,
                            ultimately falling into your hands.
                            You [i]could[/i] pawn it off, but doing so would be a great insult to your ancestors,
                            and you'd rather not risk the wrath of ghosts trapped in the afterlife.
                            You have enough [i]living[/i] problems to worry about as-is.
                        [/p]
                        [p]
                            "[color=ppink]Hmph.
                            I've heard many a [i]kuhbold[/i] claim tah be more broke than they actually are.
                            [b]Lying.[/b]
                            That's one thing yer kind is good at, isn't it?
                            How do I know you're not tellin' meh a lie?
                            If that ba~ag you're carryin' really is filled with ancient ba~aubles,
                            then let's open'er up and 'ave a look![/color]"
                        [/p]
                        ${global.ui.condFail(`Charisma below 7`)}
                        [p]
                            Uh-oh.
                            You didn't expect the caprine to be smarter than he looks.
                            Unable to comply to his request, you begin to stammer out a bunch of stalling gibberish.
                            A trick he instantly sees through.
                            "[color=ppink]Hah.
                            You're a baa~aad liar, [i]kuhbold[/i].
                            Come now, we don't serve liars here.
                            Git.
                            Out the door.
                            Or do I need tah [b]throw[/b] yeh out?[/color]"
                        [/p]
                        [p]
                            No.
                            [b]No![/b]
                            You're telling the truth!
                            You [b]swear[/b] you are!
                            You aren't lying.
                            Opening the bag would just be [b]really[/b] uhh...[i]offensive[/i] to your forefathers!
                            "[color=ppink]Yeah right.
                            And me wife, Armok rest'er soul, was a faithful woman, too?
                            Do ye expect me tah believe everythin' without questionin', lizard?
                            Yer a dirty, no-good liar.
                            Now get out of mah soup kitchen.
                            We're [b]closed[/b].
                            [b]Forever[/b].[/color]"
                        [/p]
                        [p]
                            That being said, the fat sheep points towards the door.
                            You wordlessly beg him to let you stay.
                            He looks like he's made his choice.
                            You try to come up with something, [b]anything[/b] to say, but it's hopeless.
                            Your lack of persuasion has cost you a valuable opportunity.
                            Hanging your head, you walk out the door, back towards the market square.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLieFail.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLie.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenLie(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenQuestionedChoice.LIE;
    var reqController = ctrl.questioned;

    var toFail = new VaranarSoupKitchenLieFail(ctrl);
    var toSuccess = new VaranarSoupKitchenLieSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.charisma() >= 7;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\lie\VaranarSoupKitchenLie.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruthSucceed.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenTruthSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var paid = global.kobold.history.shared.debtCollector.paid;
        var toReturn = `[p]
                            You tell the man the truth.
                            You're ${paid ? `heavily` : ``} indebted to the Three-Tailed Rat Clan, and are trying to save up some money to pay them off.
                            You [i]could[/i] use your gold to buy food for yourself,
                            but you don't [b]dare[/b] think of the consequences should the clan catch you empty-handed.
                            Worse yet, if one of them finds you spending coins that should belong to [b]them[/b], they'd probably [b]torture[/b] you to death for that.
                            So, here you are, hoping for some food that [i]won't[/i] lead to your slow and painful [b]death[/b].
                        [/p]
                        [p]
                            "[color=ppink]Hmph.
                            I've heard many a [i]kuhbold[/i] claim tah be hounded by this [i]gang[/i].
                            [b]Lying.[/b]
                            That's one thing yer kind is good at, isn't it?
                            How do I know you're not tellin' meh a lie?
                            If you're carryin' that gold around for, surely you know exactly [b]who[/b] it is you owe money to, right?
                            Well then, who is the leader of this so-called [i]Three-Tailed Rat Clan[/i]?[/color]"
                        [/p]
                        ${global.ui.condSucc(`Intelligence greater than 5`)}
                        [p]
                            That's easy enough.
                            The Three-Tailed Rat is the leader of the clan.
                            That's why it's called the [i]Three-Tailed Rat Clan[/i].
                            Because it's lead by the Three-Tailed Rat.
                            "[color=ppink]That's a pretty stupid name.
                            Dumb enough to have been thought up by a [i]kuhbold[/i] like you.[/color]"
                            Another pointless accusation.
                        [/p]
                        [p]
                            You say you think the Three-Tailed Rat is [b]actually[/b] a rat with three tails, which would explain the name, but you're not really sure.
                            Nobody knows his true identity, and he rarely ever shows his face.
                            Besides, outside of the leader, the gang [b]is[/b] completely comprised of kobolds such as yourself.
                            It's not unreasonable to assume that [i]they[/i] came up with the name.
                            "[color=ppink]Alright, alright.
                            Cease yer yappin'.
                            You've convinced me.
                            Truth be told, the less ah know about these [i]clans[/i], the better.
                            Wouldn't want to rub anyone the wrong way in this city.
                            Could end up [b]dead[/b] before ah even get evicted.
                            Anyway, lemme get ye somethin' tah eat.[/color]"
                        [/p]
                        [p]
                            Patting you on the head, the fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            You take a seat at the table nearest to you.
                            The sheep uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch, similar to your coin-purse, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            It's a memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You enjoy yer meal, [i]kuhbold[/i].
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruthSucceed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruthFail.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenTruthFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.truthFail;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.apple;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var paid = global.kobold.history.shared.debtCollector.paid;
        var toReturn = `[p]
                            You tell the man the truth.
                            You're ${paid ? `heavily` : ``} indebted to the Three-Tailed Rat Clan, and are trying to save up some money to pay them off.
                            You [i]could[/i] use your gold to buy food for yourself,
                            but you don't [b]dare[/b] think of the consequences should the clan catch you empty-handed.
                            Worse yet, if one of them finds you spending coins that should belong to [b]them[/b], they'd probably [b]torture[/b] you to death for that.
                            So, here you are, hoping for some food that [i]won't[/i] lead to your slow and painful [b]death[/b].
                        [/p]
                        [p]
                            "[color=ppink]Hmph.
                            I've heard many a [i]kuhbold[/i] claim tah be hounded by this [i]gang[/i].
                            [b]Lying.[/b]
                            That's one thing yer kind is good at, isn't it?
                            How do I know you're not tellin' meh a lie?
                            If you're carryin' that gold around for, surely you know exactly [b]who[/b] it is you owe money to, right?
                            Well then, who is the leader of this so-called [i]Three-Tailed Rat Clan[/i]?[/color]"
                        [/p]
                        ${global.ui.condFail(`Intelligence below 6`)}
                        [p]
                            Uh-oh.
                            That's a tough question.
                            The leader of the Three-Tailed Rat Clan?
                            Come on, ${name}, you know this one.
                            Uhhh, it starts with a [b]T[/b], you think.
                            Or maybe an [b]R[/b]?
                            You honestly can't remember.
                            What the hell was his name?!
                            Wait, do you even know his name?
                        [/p]
                        [p]
                            Unable to respond to the caprine's question, you begin to stammer out a bunch of stalling gibberish.
                            A trick he instantly sees through.
                            "[color=ppink]Hah.
                            You're a bad liar, [i]kuhbold[/i].
                            Come now, we don't serve liars here.
                            Git.
                            Out the door.
                            Or do I need tah [b]throw[/b] yeh out?[/color]"
                        [/p]
                        [p]
                            No.
                            [b]No![/b]
                            You're telling the truth!
                            You [b]swear[/b] you are!
                            You aren't lying, really!
                            "[color=ppink]Yeah right.
                            And me wife, Armok rest'er soul, was a faithful woman, too?
                            Do ye expect me tah believe everythin' without questionin', lizard?
                            Yer a dirty, no-good liar.
                            Now get out of mah soup kitchen.
                            We're [b]closed[/b].
                            [b]Forever[/b].[/color]"
                        [/p]
                        [p]
                            That being said, the fat sheep points towards the door.
                            You wordlessly beg him to let you stay.
                            He looks like he's made his choice.
                            You try to come up with something, [b]anything[/b] to say, but it's hopeless.
                            Your stupidity and your inability to remember a simple detail have cost you a valuable opportunity.
                            Hanging your head, you walk out the door, back towards the market square.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruthFail.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruth.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenTruth(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenQuestionedChoice.TRUTH;
    var reqController = ctrl.questioned;

    var toFail = new VaranarSoupKitchenTruthFail(ctrl);
    var toSuccess = new VaranarSoupKitchenTruthSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.intelligence() >= 6;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\truth\VaranarSoupKitchenTruth.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenInvitedServed.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenInvitedServed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You give the sheep a small nod.
                            You [i]had[/i] hoped for a [i]warm[/i] meal, but beggars can't be choosers.
                            "[color=ppink]Don't worry 'bout the baa~aath.
                            It'll still be there when you're done.
                            I prefer me water cold anyway.[/color]"
                            You can sense a hint of [i]sarcasm[/i] in his voice.
                            "[color=ppink]Anyway, lemme get ye somethin' tah eat.[/color]"
                        [/p]
                        [p]
                            Patting you on the head, the fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            You take a seat at the table nearest to you.
                            The sheep uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch, similar to your coin-purse, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            It's a memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You enjoy yer meal, [i]kuhbold[/i].
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenInvitedServed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenQuestioned.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenQuestioned(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.questioned;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenLie(ctrl);
    var secondNext = new VaranarSoupKitchenTruth(ctrl);

    var firstChoice = VaranarSoupKitchenQuestionedChoice.LIE;
    var secondChoice = VaranarSoupKitchenQuestionedChoice.TRUTH;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You give the sheep a small nod.
                            You [i]had[/i] hoped for a [i]warm[/i] meal, but beggars can't be choosers.
                            "[color=ppink]Don't worry 'bout the baa~aath.
                            It'll still be there when you're done.
                            I prefer me water cold anyway.[/color]"
                            You can sense a hint of [i]sarcasm[/i] in his voice.
                        [/p]
                        [p]
                            The jolly look on the caprine's face is suddenly replaced by an inquisitive stare as he notices the small bag hanging off your neck.
                            "[color=ppink]Now wait just a minute.
                            What dah we have 'ere?[/color]"
                            He taps one of his fat fingers against your coin pouch, making the gold pieces within clatter against one another.
                            "[color=ppink]Stingy rich'un, aren't ye?
                            Trying tah score a free meal while havin' more moneh than ah do?!
                            Ye get nothin', and yah can be happeh that ah don't kick yeh out mahself![/color]"
                        [/p]
                        ${global.ui.condFail(`Too much gold`)}
                        [p]
                            The burly man's accent seems to grow [i]heavier[/i] the more angry he gets.
                            You need to come up with something fast if you want to get a free meal still.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>A lie</button>`;

        var tooltip = global.parser.parse(`You won't get any food if you let on that your pouch is filled with gold.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>The truth</button>`;

        var tooltip = global.parser.parse(`This guy seems honest enough. You have no reason to lie.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You tell:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenQuestionedChoice = {
    LIE: 1,
    TRUTH: 2
};

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenQuestioned.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenQuestionedSelector.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenQuestionedSelector(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.invited;

    var toFail = new VaranarSoupKitchenInvitedServed(ctrl);
    var toSuccess = new VaranarSoupKitchenQuestioned(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.gold() >= 50;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenQuestionedSelector.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenInvited.js

/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenInvited(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.invited;
    var changeController = ctrl.invited;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new VaranarSoupKitchenQuestionedSelector(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Gathering your courage, you walk up to the door, and slowly push it open.
                            Despite taking little effort to move, it creaks loudly, alerting whoever may be inside to your presence.
                            Swallowing deeply, you step inside of the dilapidated building, and close the door behind you.
                        [/p]
                        [p]
                            You find yourself alone in a dusky room that has clearly seen better days.
                            Apart from the chairs and tables arrayed across the wooden floor, you'd say this almost looks like an abandoned [i]store[/i].
                            At least it's warm in here, so the soup kitchen can't be [i]completely[/i] deserted.
                            You figure the stove must be behind the mercantile countertop, but you're not tall enough to see.
                            To your left is a set of stairs which you figure must lead to the proprietor's [i]above-ground[/i] home.
                        [/p]
                        [p]
                            Suddenly, you hear movement above.
                            Footsteps.
                            No wait.
                            Clacking hooves?
                            "[color=ppink]Yeah, ah heard yah! I'ma comin'![/color]" a bass voice rings out from the second floor.
                        [/p]
                        [p]
                            Down the stairs comes storming a big, wet, outright [b]fat[/b] anthromorphic sheep,
                            his bloated, wool-covered belly jiggling with every step he takes,
                            soapy water dripping liberally from his fleece.
                            The man isn't wearing much besides a towel, tied snugly around his waist.
                            "[color=ppink]Can't a sheep take a fockin' baa~aath wifout a beggar wanderin' in?![/color]"
                            At least you don't have to ask why he's wet and half-naked.
                            "[color=ppink]Well then, what'd ye want, yah skinky lizard?![/color]"
                        [/p]
                        [p]
                            The caprine comes to a rest merely a foot away from you, the wool on his big gut almost pressing into your snout.
                            You can't help but stare at his massive belly,
                            as you stammer out the dumbest question your mind could think of while looking at someone big enough to [b]eat[/b] you.
                            You ask whether or not the man [i]cooks[/i] kobolds here.
                            He leans over you threateningly, a droplet of water dripping from his chin down ontop of your forehead.
                            Glaring at you, he responds to your question in a grim tone.
                            "[color=ppink]Aye, but only the ones that think they're funny.
                            Or the ones that [b]stare at mah belly[/b].[/color]"
                        [/p]
                        [p]
                            His words remind you that you [i]are[/i] still leering at his bulky lower body instead of looking the man in the eyes.
                            Correcting your mistake, you quickly stammer out a meek apology.
                            The sheep suddenly bursts out into laughter.
                            "[color=ppink]Hahahahaha!
                            Scared ye, didn't ah?
                            Only vegetarian meals here, [i]kuhbold[/i].
                            Us sheep, we cannae eat meat.[/color]"
                            You let out an uneasy chuckle, a disturbed smile forming on your face.
                            At least you won't be getting cut up and put into a stew today.
                        [/p]
                        [p]
                            You nervously ask the [i]chef[/i] if you could maybe, if at all possible, if it's not a bother, get something tiny to eat, perhaps?
                            You know you're interrupting his bath-time, but you're kind of [b]starving[/b].
                            "[color=ppink]'Fraid not.[/color]" the caprine responds, with a hint of sadness in his voice.
                            "[color=ppink]I closed down shop yesterday.
                            Not enough money to pay rent for this shitehole.
                            I was half expectin' yah tah be here tah [b]kick me out[/b].[/color]"
                            Even his [i]endearing[/i] accent fails to mask the man's distress.
                        [/p]
                        [p]
                            The chubby sheep lets out a sigh, eyeing you up and down.
                            "[color=ppink]Ye look like a scraggy one.
                            Tell yah what, for you, I'll make an exception.
                            I've got some leftovers from yesterday.
                            Won't be warm, but it's better than nothin', aye?[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\invited\VaranarSoupKitchenInvited.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\threaten\VaranarSoupKitchenThreaten.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenThreaten(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenAccusedChoice.THREATEN;
    var reqController = ctrl.accused;
    var subController = ctrl.preContinue;
    var changeController = ctrl.threaten;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.apple;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var toReturn = `[p]
                            You threaten him, boldly stating that he'd better go get you some soup and quick, [b]or else[/b].
                            ${weapon ? `You have a weapon, and you're not afraid to use it.` : `You may not have a weapon, but you can [b]rake[/b] him with your claws.`}
                            Unless the sheep is looking for [b]trouble[/b], he'd best get to serving you, and make it snappy.
                            He wouldn't want to get [b]killed[/b] the day after retirement, now would he?
                        [/p]
                        [p]
                            "[color=ppink]You?
                            Kill [b]me[/b]?
                            Don't make me [b]laugh[/b], [i]kuhbold[/i].[/color]"
                            You growl loudly, dropping into a combat stance to show the caprine how [b]serious[/b] you are.
                            Before you even have the chance to issue a final warning,
                            the palm of the fat sheep's hand [b]slams[/b] into your jaw,
                            the big man's slap strong enough to almost knock you off your feet.
                            You recoil, clutching your muzzle, on the verge of crying.
                            At first, you think he might have knocked out a tooth, but upon tongue-inspection, everything appears to be still in place.
                        [/p]
                        [p]
                            "[color=ppink]Do ye really think you're first lizard tah threaten meh?
                            I've dealt with far more imposin' [i]kuhbolds[/i] than you.
                            Smacked'em to hell and ba~ack, wrestled'em to the ground and made'em [b]beg[/b] for mercy.
                            What chance do [b]you[/b] stand against [b]me[/b]?
                            If ah shave the wool off mah body, arse to head, it'll form a pile bigger than you are!
                            Now, unless you want'ay get slapped again, get [b]out[/b] of mah soup kitchen.
                            We're [b]closed[/b].
                            [b]Forever[/b].[/color]"
                        [/p]
                        [p]
                            That being said, the fat sheep points towards the door.
                            You consider trying to fight him still, but he's right.
                            There's no point in getting the shit kicked out of you needlessly.
                            You simply aren't built to fight a man of his size.
                            Hanging your head, you walk out the door, back towards the market square.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\threaten\VaranarSoupKitchenThreaten.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluffSucceed.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenBluffSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You bluff, saying that you are a member of the Three-Tailed Rat Clan.
                            This explains why you're so well-dressed and a bit more [i]wealthy[/i] than the other kobolds around town.
                            Unless the sheep is looking for [b]trouble[/b], he'd best get to serving you, and make it snappy.
                            The clan can make life [b]very[/b] difficult for [i]uncooperative[/i] people.
                            Surely he doesn't want to get on their -- you mean [b]your[/b] -- bad side one day after [i]retirement[/i], right?
                        [/p]
                        ${global.ui.condSucc(`Strength greater than 5`)}
                        [p]
                            "[color=ppink]Alright, alright.
                            I knew ye were bad luck from the moment yah walked in here.
                            No [i]kuhbold[/i] flaunts their wealth about like that, apart from the ones that mean [b]trouble[/b].
                            I'm not lookin' for a fight.
                            I don't want any [b]trouble[/b].
                            Lemme get ye somethin' tah eat, okay?
                            And we'll forget this whole [i]misunderstanding[/i].[/color]"
                        [/p]
                        [p]
                            You tell the sheep to stop [b]yapping[/b] and get started already.
                            You're [b]hungry[/b].
                            The fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            You take a seat at the table nearest to you.
                            He uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch, similar to your coin-purse, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            It's a memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You stay here, [i]kuhbold[/i] of clan whatever.
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluffSucceed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluffFail.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenBluffFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.bluffFail;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.apple;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You bluff, saying that you are a member of the Three-Tailed Rat Clan.
                            This explains why you're so well-dressed and a bit more [i]wealthy[/i] than the other kobolds around town.
                            Unless the sheep is looking for [b]trouble[/b], he'd best get to serving you, and make it snappy.
                            The clan can make life [b]very[/b] difficult for [i]uncooperative[/i] people.
                            Surely he doesn't want to get on their -- you mean [b]your[/b] -- bad side one day after [i]retirement[/i], right?
                        [/p]
                        ${global.ui.condFail(`Strength below 6`)}
                        [p]
                            "[color=ppink]You?
                            A [b]gang member[/b]?
                            Don't make me [b]laugh[/b], [i]kuhbold[/i].
                            With [b]wimpy[/b] little arms like that, ye can be glad people don't mistake ye for an overgrown [b]grasshopper[/b].[/color]"
                            The man snorts, almost laughing at his own joke.
                            "[color=ppink]You're a bad liar, lizard.
                            Come now, we don't serve liars here.
                            Git.
                            Out the door.
                            Or do I need tah [b]throw[/b] yeh out?[/color]"
                        [/p]
                        [p]
                            No.
                            [b]No![/b]
                            Does he know what he's doing?!
                            You're part of a [b]crime syndicate[/b]!
                            You'll have him [b]killed[/b]!
                            "[color=ppink]Yeah right.
                            And me wife, Armok rest'er soul, was a faithful woman, too?
                            Do ye expect me tah believe everythin' without questionin', lizard?
                            Yer a dirty, no-good liar.
                            Now get out of mah soup kitchen.
                            We're [b]closed[/b].
                            [b]Forever[/b].[/color]"
                        [/p]
                        [p]
                            That being said, the fat sheep points towards the door.
                            You wordlessly continue you act, in a last ditch attempt to get him to let you stay.
                            He looks like he's made his choice.
                            You try to come up with something, [b]anything[/b] to say, but it's hopeless.
                            Your scrawny figure has cost you a valuable opportunity.
                            Hanging your head, you walk out the door, back towards the market square.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluffFail.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluff.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenBluff(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenAccusedChoice.BLUFF;
    var reqController = ctrl.accused;

    var toFail = new VaranarSoupKitchenBluffFail(ctrl);
    var toSuccess = new VaranarSoupKitchenBluffSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.strength() >= 6;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\bluff\VaranarSoupKitchenBluff.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenOverdressedServed.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenOverdressedServed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You give the sheep a small nod.
                            You [i]had[/i] hoped for a [i]warm[/i] meal, but beggars can't be choosers.
                            "[color=ppink]Don't worry 'bout the baa~aath.
                            It'll still be there when you're done.
                            I prefer me water cold anyway.[/color]"
                            You can sense a hint of [i]sarcasm[/i] in his voice.
                            "[color=ppink]Anyway, lemme get ye somethin' tah eat.[/color]"
                        [/p]
                        [p]
                            Patting you on the head, the fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            You take a seat at the table nearest to you.
                            The sheep uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch, similar to your coin-purse, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            It's a memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You enjoy yer meal, [i]kuhbold[/i].
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenOverdressedServed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenAccused.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenAccused(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.accused;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenBluff(ctrl);
    var secondNext = new VaranarSoupKitchenThreaten(ctrl);

    var firstChoice = VaranarSoupKitchenAccusedChoice.BLUFF;
    var secondChoice = VaranarSoupKitchenAccusedChoice.THREATEN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You give the sheep a small nod.
                            You [i]had[/i] hoped for a [i]warm[/i] meal, but beggars can't be choosers.
                            "[color=ppink]Don't worry 'bout the baa~aath.
                            It'll still be there when you're done.
                            I prefer me water cold anyway.[/color]"
                            You can sense a hint of [i]sarcasm[/i] in his voice.
                        [/p]
                        [p]
                            The jolly look on the caprine's face is suddenly replaced by an inquisitive stare as he notices the small bag hanging off your neck.
                            "[color=ppink]Now wait just a minute.
                            What dah we have 'ere?[/color]"
                            He taps one of his fat fingers against your coin pouch, making the gold pieces within clatter against one another.
                            "[color=ppink]Stingy rich'un, aren't yah?
                            Trying tah score a free meal while havin' more moneh than ah do?!
                            Ye get nothin', and yah can be happeh that ah don't kick yeh out mahself![/color]"
                        [/p]
                        ${global.ui.condFail(`Too much gold`)}
                        [p]
                            The burly man's accent seems to grow [i]heavier[/i] the more angry he gets.
                            You need to come up with something fast if you want to get a free meal still.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Bluff</button>`;

        var tooltip = global.parser.parse(`Claim to be part of the Three-Tailed Rat Clan. [i]Technically[/i], you are.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Threaten</button>`;

        var tooltip = global.parser.parse(`Who does this old man think he is? Tell him to get you some food, [b]or else[/b].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenAccusedChoice = {
    BLUFF: 1,
    THREATEN: 2
};

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenAccused.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenAccuseSelector.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenAccuseSelector(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.overdressed;

    var toFail = new VaranarSoupKitchenOverdressedServed(ctrl);
    var toSuccess = new VaranarSoupKitchenAccused(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.gold() >= 50;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenAccuseSelector.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenOverdressed.js

/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenOverdressed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.overdressed;
    var changeController = ctrl.overdressed;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new VaranarSoupKitchenAccuseSelector(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var clothes = ctrl.misc.bra() || ctrl.misc.shirt() || ctrl.misc.pants() || ctrl.misc.underwear();
        var toReturn = `[p]
                            Gathering your courage, you walk up to the door, and slowly push it open.
                            Despite taking little effort to move, it creaks loudly, alerting whoever may be inside to your presence.
                            Swallowing deeply, you step inside of the dilapidated building, and close the door behind you.
                        [/p]
                        [p]
                            You find yourself alone in a dusky room that has clearly seen better days.
                            Apart from the chairs and tables arrayed across the wooden floor, you'd say this almost looks like an abandoned [i]store[/i].
                            At least it's warm in here, so the soup kitchen can't be [i]completely[/i] deserted.
                            You figure the stove must be behind the mercantile countertop, but you're not tall enough to see.
                            To your left is a set of stairs which you figure must lead to the proprietor's [i]above-ground[/i] home.
                        [/p]
                        [p]
                            Suddenly, you hear movement above.
                            Footsteps.
                            No wait.
                            Clacking hooves?
                            "[color=ppink]Yeah, ah heard yah! I'ma comin'![/color]" a bass voice rings out from the second floor.
                        [/p]
                        [p]
                            Down the stairs comes storming a big, wet, outright [b]fat[/b] anthromorphic sheep,
                            his bloated, wool-covered belly jiggling with every step he takes,
                            soapy water dripping liberally from his fleece.
                            The man isn't wearing much besides a towel, tied snugly around his waist.
                            "[color=ppink]Can't a sheep take a fockin' bath wifout a beggar wanderin' in?![/color]"
                            At least you don't have to ask why he's wet and half-naked.
                            "[color=ppink]Well then, what'd ye want, yah skinky lizard?![/color]"
                        [/p]
                        [p]
                            The caprine comes to a rest merely a foot away from you, the wool on his big gut almost pressing into your snout.
                            You can't help but stare at his massive belly,
                            as you stammer out the dumbest question your mind could think of while looking at someone big enough to [b]eat[/b] you.
                            You ask whether or not the man [i]cooks[/i] kobolds here.
                            He leans over you threateningly, a droplet of water dripping from his chin down ontop of your forehead.
                            Glaring at you, he responds to your question in a grim tone.
                            "[color=ppink]Aye, but only the ones that think they're funny.
                            Or the ones that [b]stare at mah belly[/b].[/color]"
                        [/p]
                        [p]
                            His words remind you that you [i]are[/i] still leering at his bulky lower body instead of looking the man in the eyes.
                            Correcting your mistake, you quickly stammer out a meek apology.
                            The sheep suddenly bursts out into laughter.
                            "[color=ppink]Hahahahaha!
                            Scared ye, didn't ah?
                            Only vegetarian meals here, [i]kuhbold[/i].
                            Us sheep, we cannae eat meat.[/color]"
                            You let out an uneasy chuckle, a disturbed smile forming on your face.
                            At least you won't be getting cut up and put into a stew today.
                        [/p]
                        [p]
                            You nervously ask the [i]chef[/i] if you could maybe, if at all possible, if it's not a bother, get something tiny to eat, perhaps?
                            You know you're [i]interrupting[/i] his bath-time, but you're kind of [b]starving[/b].
                            "[color=ppink]'Fraid not.[/color]" the caprine responds, with a hint of sadness in his voice.
                            "[color=ppink]I closed down shop yesterday.
                            Not enough money to pay rent for this shitehole.
                            I was half expectin' yah tah be here tah [b]kick me out[/b].[/color]"
                            Even his [i]endearing[/i] accent fails to mask the man's distress.
                        [/p]
                        [p]
                            The chubby sheep lets out a sigh, eyeing you up and down.
                            "[color=ppink]Fancy ${clothes ? `clothing` : `weapon`}.
                            Who'd ye steal that from?
                            Tell yah what, for a well-${clothes ? `dressed` : `armed`} lizard like you, I'll make an exception.
                            I've got some leftovers from yesterday.
                            Won't be warm, but it's better than nothin', aye?[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\overdressed\VaranarSoupKitchenOverdressed.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\arrival\VaranarSoupKitchenEntrance.js

/**
 * Arrival section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.arrival;

    var toFail = new VaranarSoupKitchenInvited(ctrl);
    var toSuccess = new VaranarSoupKitchenOverdressed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.equipmentWorth() >= 35;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\arrival\VaranarSoupKitchenEntrance.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\arrival\VaranarSoupKitchenArrival.js

/**
 * Arrival section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new VaranarSoupKitchenEntrance(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var gold = ctrl.misc.gold();
        var paid = global.kobold.history.shared.debtCollector.paid;
        var toReturn = `[p]
                            Lingering around the market square, you can feel your stomach begin to grumble.
                            It's been a while since you've last had [i]anything[/i] to eat.
                            ${gold > 30 ? `You have plenty of gold to spare,
                            but you'd rather save it to pay off ${paid ? `the rest of` : ``}
                            your debt.` : `${gold > 10 ? `You have a few coins,
                            but you'd rather save them to pay off ${paid ? `the rest of` : ``}
                            your debt.` : `You have no money to buy food with, though.`}`}
                            While considering [b]scrounging[/b] the town square for any scraps of food leftover by yesterday's market,
                            your eye catches a peculiar sign hanging above the doorway to a rundown-looking structure at the edge of the plaza.
                        [/p]
                        [p]
                            [color=brown][big][b]KOBOLD SOUP KITCHEN[/b][/big][/color]
                        [/p]
                        [p]
                            That could mean two things.
                            Either you can get something to eat for free within the decrepit place,
                            or they [i]cook[/i] and [i]serve[/i] [b]kobolds[/b] as food.
                            You hope it's the former, and not the latter.
                            Judging by the state of the building, business must not be very good either way.
                            How does someone offering free stuff even make a living?
                            You're too hungry to properly pursue that train of thought.
                        [/p]
                        [p]
                            You remotely recall a few [i]rumors[/i] you heard about a year or two ago, about a place like this,
                            where tiny lizards down on their luck can take a break from scrounging and enjoy a hot meal for once.
                            You figured it was just hearsay, that they were [i]lies[/i], [b]fairytales[/b],
                            that it was your koboldic forest [i]friends[/i] playing a [b]trick[/b] on you,
                            or even the Three-Tailed Rat Clan attempting to lure you into town for whatever reason.
                            Maybe you were told the truth after all.
                            Or you could be walking into a death trap.
                        [/p]
                        [p]
                            Standing in front of the building itself, not to mention with an empty stomach,
                            you are more inclined to [i]believe[/i] the stories you've been told.
                            You decide you'll take a quick peek inside, and if anything seems fishy to you,
                            you'll immediately leave and it'll be like nothing happened.
                            At best, you'll get a free meal.
                            At worst, you'll be [i]turned into[/i] a meal.
                            Not like you've much meat on your bones anyway.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        global.ui.applyTheme("varanar_generic");
        ctrl.bgm.loop();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\arrival\VaranarSoupKitchenArrival.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\VaranarSoupKitchenController.js

/**
 * Controller for the Varanar, Noon Three scene.
 * @param {string} sceneId The id of the scene.
 */
function VaranarSoupKitchenController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = true;
    this.nextSceneName = "NoonThreeStore";
    this.nextFolderName = "Varanar/DayThree";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ContinueController(id, "arrival");

    this.invited = new ChangeController(id, "invited", function () {
        global.kobold.status.mental.decrease(2, "Caprine intimidation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Intimidated", "Sanity", -2)
        ]);
    });

    this.overdressed = new ChangeController(id, "overdressed", function () {
        global.kobold.status.mental.decrease(2, "Caprine intimidation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Intimidated", "Sanity", -2)
        ]);
    });

    this.questioned = new ChoiceController(id, "questioned");
    this.accused = new ChoiceController(id, "accused");

    this.serveChoice = new ContinueController(id, "serveChoice");

    this.serve = new ChangeController(id, "serve", function () {
        global.kobold.status.stamina.increase(5, "Taking a seat");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Temporary respite", "Stamina", +5)
        ]);
    });

    this.steal = new ChangeController(id, "steal", function () {
        global.kobold.status.physical.decrease(10, "Starvation");
        global.kobold.status.mental.decrease(5, "Stealing wedding ring");
        global.kobold.status.stamina.decrease(2, "Short sprint");
        global.kobold.inventory.addItem(new GoldRing());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Starvation", "Health", -10),
            new Change("Keepsake taken", "Sanity", -10),
            new Change("Valuable loot", "Sanity", +5),
            new Change("Short sprint", "Stamina", -2),
            new Change("Loot", global.kobold.inventory.createItemWithTooltip(new GoldRing(), true), +1)
        ]);
    });

    this.leave = new ChangeController(id, "leave", function () {
        global.kobold.status.physical.increase(3, "Eating half an apple");
        global.kobold.status.mental.decrease(2, "Eating scraps");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +5),
            new Change("Unsanitary", "Health", -2),
            new Change("Eating scraps", "Sanity", -2)
        ]);
    });

    this.eat = new ChangeController(id, "eat", function () {
        global.kobold.status.physical.increase(10, "Eating soup");
        global.kobold.status.mental.increase(10, "Eating soup");
        global.kobold.status.stamina.increase(10, "Eating soup");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +10),
            new Change("Decent meal", "Sanity", +10),
            new Change("Ate", "Stamina", +10)
        ]);
    });

    this.eatLeave = new ChangeController(id, "eatLeave", function () {
        global.kobold.status.mental.decrease(8, "Failure to help");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Can't help", "Sanity", -4),
            new Change("Sadness", "Sanity", -4)
        ]);
    });

    this.offer = new ChoiceController(id, "offer");

    this.mention = new ChangeController(id, "mention", function () {
        global.kobold.status.mental.increase(17, "Gave home to sheep");
        global.kobold.inventory.bag.removeMisc(new CassidyHouseKey());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped sheep", "Sanity", +6),
            new Change("Helped kobolds", "Sanity", +6),
            new Change("Conscience cleared", "Sanity", +6),
            new Change("Rudeness", "Sanity", -1)
        ]);
    });

    this.noMention = new ChangeController(id, "noMention", function () {
        global.kobold.status.mental.increase(10, "Gave home to sheep");
        global.kobold.inventory.bag.removeMisc(new CassidyHouseKey());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped sheep", "Sanity", +6),
            new Change("Helped kobolds", "Sanity", +6),
            new Change("Troubled conscience", "Sanity", -2)
        ]);
    });

    this.lieFail = new ChangeController(id, "lieFail", function () {
        global.kobold.status.mental.decrease(4, "Failing to lie");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Failed to lie", "Sanity", -4)
        ]);
    });

    this.bluffFail = new ChangeController(id, "bluffFail", function () {
        global.kobold.status.mental.decrease(4, "Failing to bluff");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Failed to bluff", "Sanity", -4)
        ]);
    });

    this.truthFail = new ChangeController(id, "truthFail", function () {
        global.kobold.status.mental.decrease(8, "Unbelieving sheep");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Truth not enough", "Sanity", -4),
            new Change("Frustration", "Sanity", -4)
        ]);
    });

    this.threaten = new ChangeController(id, "threaten", function () {
        global.kobold.status.physical.decrease(4, "Getting slapped");
        global.kobold.status.mental.decrease(4, "Failing to intimidate");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Heavily slapped", "Health", -4),
            new Change("Failed to intimidate", "Sanity", -4)
        ]);
    });

    this.preContinue = new ContinueController(id, "preContinue");

    this.halfApple = new ChangeController(id, "halfApple", function () {
        global.kobold.status.physical.increase(3, "Eating half an apple");
        global.kobold.status.mental.decrease(2, "Eating scraps");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +5),
            new Change("Unsanitary", "Health", -2),
            new Change("Eating scraps", "Sanity", -2)
        ]);
    });

    this.fragments = {};
    this.fragments.apple = new VaranarSoupKitchenHalfApple(this);
    this.fragments.serveChoices = new VaranarSoupKitchenServed(this);

    this.bgm = new AudioController(id, "res/audio/varanar/decline.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

// END scenes\Varanar\DayThree\VaranarSoupKitchen\VaranarSoupKitchenController.js

// scenes\Varanar\DayThree\VaranarSoupKitchen\VaranarSoupKitchen.js

/**
 * Noon three of Varanar.
 */
function VaranarSoupKitchen() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "VaranarSoupKitchen";
    var sceneName = "Varanar, Noon Three";
    var sceneSubfolder = "Varanar/DayThree";
    var ctrl = new VaranarSoupKitchenController(sceneId);
    var arrival = new VaranarSoupKitchenArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]Varanar[/t]`);
        tab += global.parser.parse(`[st]Noon three[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new VaranarSoupKitchen();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Varanar\DayThree\VaranarSoupKitchen\VaranarSoupKitchen.js



// END SCENE VaranarSoupKitchen

