

// SCENE NoonThreeStore

// scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreLeave.js

/**
 * End section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = false;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var noWhore = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.DECLINE;
        var toReturn = `[p]
                            Your purchases complete, you leave the store, heading back out into the cold streets.
                            "[color=yellow]${noWhore ? `See you around, prude!` : `See you around, whore!`}[/color]"
                            Rolande yells after you, before you manage to close the door behind you.
                            "[color=yellow]Bring some more gold next--[/color]"
                            You cut him off by slamming the door shut.
                        [/p]
                        [p]
                            Well, you've seen enough of the grand avenue for now.
                            The noon is long over, although it's far from night.
                            Where to go next?
                            You [i]did[/i] kind of [i]avoid[/i] the kobold district yesterday.
                            Perhaps you can explore that a little, while it's still light out.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreLeave.js

// scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreReturnLeave.js

/**
 * End section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreReturnLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = false;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var noWhore = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.DECLINE;
        var toReturn = `[p]
                            Your partial refund granted, you leave the store, heading back out into the cold streets.
                            "[color=yellow]${noWhore ? `See you around, prude!` : `See you around, whore!`}[/color]"
                            Rolande yells after you, before you manage to close the door behind you.
                            "[color=yellow]Bring some more gold next--[/color]"
                            You cut him off by slamming the door shut.
                        [/p]
                        [p]
                            Well, you've seen enough of the grand avenue for now.
                            The noon is long over, although it's far from night.
                            Where to go next?
                            You [i]did[/i] kind of [i]avoid[/i] the kobold district yesterday.
                            Perhaps you can explore that a little, while it's still light out.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreReturnLeave.js

// scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreReturn.js

/**
 * Return section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreReturn(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.return;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreReturnLeave(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var noWhore = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.DECLINE;
        var oldWeapon = ctrl.misc.weapon();
        var greatsword = ctrl.postShopMisc.weapon();
        var toReturn = `[p]
                            Your purchases complete, you head towards the store's entrance,
                            dragging your brand spanking new ${global.kobold.inventory.createItemWithTooltip(greatsword)} behind you.
                            This thing is [b]heavy[/b].
                            You can barely even [b]lift it[/b], let alone swing it around in battle.
                            You think you made a mistake buying this.
                            Trying your hardest to not let the sharpened steel trail along the wooden floor, you walk back towards the counter.
                        [/p]
                        [p]
                            "[color=yellow]What now, kobold?
                            Spit it out already.
                            An actual customer might walk in any second now and see me catering to [i]your[/i] kind.[/color]"
                            You say that you kind of didn't really think this whole zweihander thing through.
                            You really can't use this weapon.
                            You'd like a refund, if at all possible?
                        [/p]
                        [p]
                            "[color=yellow][b]Refund[/b]?!
                            Hah!
                            I don't deal in second hand goods.[/color]"
                            You mention that practically [b]everything[/b] in the corner you shopped from looked second hand, to some degree.
                            "[color=yellow]Ugh.
                            [b]Fine[/b].
                            I'll give you [b]fifty[/b] coins for it.[/color]"
                            Fifty?!
                            But that's [b]way[/b] less what you paid for it just five minutes ago!
                            "[color=yellow]Then don't take my offer, and drag your pretty new sword out the door.[/color]"
                        [/p]
                        [p]
                            You sigh loudly.
                            Bloody merchants, always squeezing money out of people whenever they can.
                            At least fifty coins is better than nothing.
                            You reluctantly accept the dragon's offer.
                            Handing over your oversized weapon, he returns a fraction of what you paid for it.
                            ${oldWeapon ? `"[color=yellow]Here.
                            As an added bonus, I even saved [b]this[/b] for you.
                            You dropped it earlier.[/color]"
                            To your surprise, Rolande hands you back your [b]previous[/b] weapon,
                            your good old trusty ${global.kobold.inventory.createItemWithTooltip(oldWeapon)}.
                            Perhaps he's not such a terrible person after all.` : ``}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreReturn.js

// scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreFinishSelector.js

/**
 * End section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreFinishSelector(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.store;

    var toFail = new NoonThreeStoreLeave(ctrl);
    var toSuccess = new NoonThreeStoreReturn(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        var weapon = ctrl.postShopMisc.weapon();
        return weapon && weapon.id === ItemEnum.GREATSWORD;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreFinishSelector.js

// scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreShop.js

/**
 * Shop section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreShop(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preStore;
    var subController = ctrl.store;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreFinishSelector(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Noticing you haven't left yet, the dragon rolls his eyes.
                            "[color=yellow]There's a bargain bin in the corner, filled with things even [i]you[/i] might be able to afford.[/color]"
                            The merchant points towards a rusty bucket filled with a bunch of junk and some less-than-incredible items.
                            "[color=yellow]Either buy something, or kindly [b]get out[/b].[/color]"
                        [/p]
                        [p][sneak]
                            You are in a safe zone.
                            You can use items from your inventory here.
                            You are in a store.
                            You can sell items from your inventory here.
                            You may buy items from the list below.
                            Keep in mind that all purchases are final.
                            Worn equipment can not be sold.
                            Buying equipment will discard your previous attire.
                        [/sneak][/p]`;
        toReturn += ctrl.store.getGenerator().build();
        toReturn += `[p][sneak]
                            Remember that you can not drink potions or eat food outside of safe zones.
                            You might want to use some of the items you've purchased before continuing.
                        [/sneak][/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            ctrl.store.getGenerator().disable();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
        ctrl.store.getGenerator().registerListeners();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\shop\NoonThreeStoreShop.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexEnd.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexEnd(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.sexDecline;
    var subController = ctrl.preStore;
    var changeController = ctrl.sexEnd;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.store;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var shirt = ctrl.misc.shirt();
        var bra = ctrl.misc.bra();
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? "seventy" : "fifty" : bjMoney ? "fifty" : "thirty";
        var toReturn = `[p]
                            The merchant doesn't seem to care about your agony.
                            Using a rag taken from the countertop, he wipes his cum-dribbling shaft clean of your spit.
                            Slowly recovering from the lack of air, you rise to your unsteady feet.
                            After wiping your snout clean,
                            ${shirt || bra ? `and tidying your clothes,` : ``}
                            you waddle over to the front of the counter.
                        [/p]
                        [p]
                            That was [b]not[/b] fun.
                            He could have [b]killed[/b] you.
                            "[color=yellow]And you [b]could have[/b] given me a [b]proper[/b] blowjob.
                            You should be thanking me, really.
                            Now you know what's expected of a lowly [b]whore[/b] like you when someone asks you to [b]suck their dick[/b].[/color]"
                            Ugh.
                            The [b]nerve[/b] of this guy.
                            You shamingly shake your head at him.
                            Anyway, enough arguing.
                            You didn't go through hell for nothing.
                            Time for the matter of your [b]payment[/b].
                        [/p]
                        [p]
                            "[color=yellow]Ah, right.
                            How much do I owe you again?
                            Ten? Fifteen coins?
                            ${hjEager && bjEager ? `Maybe twenty-five, given how well you behaved,
                            before I told you to lift your tail?` : hjEager || bjEager ? `Maybe [b]twenty[/b]?
                            You [i]were[/i] good with your ${hjEager ? `hands` : `mouth,
                            initially`}.` : `That's what your [b]lousy performance[/b] was worth, anyway.`}[/color]"
                            You [i]kindly[/i] remind Rolande that he owes you ${paid} pieces of gold, and not one less.
                            He rolls his eyes, and reaches for a nearby pouch.
                        [/p]
                        [p]
                            "[color=yellow]Fine, you undersized [b]extortionist[/b].[/color]"
                            He empties the bag on the counter, coins clattering atop the wooden countertop.
                            "[color=yellow]You're making me regret not choking you to [b]death[/b] on my cock.[/color]"
                            You ignore his overly dramatic statement, and instead focus on quickly collecting the money,
                            pocketing it in your own purse, which grows tangibly heavier.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexEnd.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexFinale.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexFinale(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.sexFinale;
    var subController = ctrl.preStore;
    var changeController = ctrl.sexFinale;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.store;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexEager = ctrl.sexAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var sexMoney = ctrl.sexMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? sexMoney ? "one hundred" : "seventy" : sexMoney ? "eighty" : "fifty" : bjMoney ? sexMoney ? "eighty" : "fifty" : sexMoney ? "sixty" : "thirty";
        var paidCaps = paid.charAt(0).toUpperCase() + paid.slice(1);
        var cunt = ctrl.misc.cunt();
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var cuntboy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var shirt = ctrl.misc.shirt();
        var shirtTooltip = global.kobold.inventory.createItemWithTooltip(shirt);
        var bra = ctrl.misc.bra();
        var braTooltip = global.kobold.inventory.createItemWithTooltip(bra);
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var underwear = ctrl.misc.underwear();
        var underwearTooltip = global.kobold.inventory.createItemWithTooltip(underwear);

        var toReturn = ``;

        if (sexEager) {
            toReturn += `
                        [p]
                            As his climax starts to fade, Rolande ends your mutual kissing once more,
                            leaving both of you heatedly panting, although his breath is [b]far[/b] warmer than yours.
                            He slowly lifts you off his cum-drooling member, his spunk oozing from your gaping ${cunt ? `folds` : `rear`},
                            and puts you down on the ground, on your unsteady feet.
                            You can barely even [b]stand[/b] after an intense fucking like that.
                        [/p]
                        [p]
                            That was [b]incredible[/b], but a little too short for your tastes.
                            You kind of [i]didn't[/i] get off.
                            Your ${cunt ? `cum-leaking cunt` : `fully erect cock`} [b]aches[/b] for more attention.
                            "[color=yellow]So?
                            I'm not the whore here.
                            You are.[/color]"
                            You thought he didn't kiss his whores?
                            "[color=yellow]And I thought vixens were the tightest pieces of ass around.[/color]"
                            Back to his old self, you see.
                        [/p]
                        [p]
                            While it was pleasuringly [b]hot[/b] at first,
                            now that it's starting to cool down, the shopkeeper's cum feels kind of [i]soothing[/i],
                            easing the light burns you sustained at the height of the heated fucking.
                            It didn't hurt too much, and what little pain there was only added to your pleasure,
                            but in retrospect, perhaps the romp ending when it did was for the better.
                            If it lasted any longer, your insides might have actually gotten [i]burned[/i].
                        [/p]
                        [p]
                            While reluctantly remaining unsatisfied is a bummer, this entire ordeal was [b]amazing[/b].
                            No wonder people think dragons are the most skilled lovers in all the world.
                            Fact is: they [b]are[/b].
                            And the best part about all of this?
                            You're getting [b]paid[/b] for it.
                            Imagine that.
                            Being paid for [b]having fun[/b].
                            Being a whore is [b]awesome[/b]!
                        [/p]
                        [p]
                            You wipe your ${cunt ? `loins` : `ass`} somewhat clean of spunk with your hand,
                            lick the viscous liquid off of your fingers,
                            ${bra && shirt ? `re-adjust your ${braTooltip}
                            and your ${shirtTooltip} to cover your chest once more,` : shirt ? `re-adjust your ${shirtTooltip},` : bra ? `re-adjust your ${braTooltip},` : ``}
                            ${pants && underwear ? `collect your ${pantsTooltip}
                            and your ${underwearTooltip},` : pants ? `collect your ${pantsTooltip},` : underwear ? `collect your ${underwearTooltip},` : ``}
                            and waddle over to the other side of the counter.
                            Time to collect your pay!
                        [/p]
                        [p]
                            "[color=yellow]I'm not going to lie.
                            That [b]was[/b] one of the [b]best[/b] fucks I've [b]ever[/b] had.
                            ${hjEager && bjEager ? `Your hands and mouth were pretty good, too.` : `Too bad about
                            ${bjEager ? `the handjob` : hjEager ? `the blowjob` : `everything before the actual sex, though.`}
                            Oh well.`}
                            ${hjEager && bjEager ? `Worth` : `Still worth`} every penny.${virgin ? ` Especially considering I got to pop your cherry.` : ``}[/color]"
                        [/p]
                        [p]
                            Rolande reaches for a nearby pouch.
                            He empties the bag, coins clattering atop the wooden countertop.
                            "[color=yellow]${paidCaps} coins, as we agreed on.[/color]"
                            You quickly collect the money,
                            pocketing it in your own purse, which grows tangibly heavier.
                            "[color=yellow]Don't go spending it all in one place, unless that place is [b]here[/b].[/color]"
                        [/p]`;
        } else {
            toReturn += `
                        [p]
                            You space out for a minute.
                            When you come back to your senses, you find yourself sitting in a small puddle of cold, draconic jizz,
                            no doubt having leaked from your ${cunt ? `still slightly gaping slit` : `sore tailhole`}. 
                            Rolande has already put his pants back on.
                            He picks up some of the non-broken things that fell off the counter, and returns them to their original position.
                            "[color=yellow]You're staining my floor, [b]whore[/b].[/color]" he addresses you, without even turning his head to face you.
                            "[color=yellow]Get back to the [b]plebeian[/b] side of the counter.[/color]"
                        [/p]
                        [p]
                            Groaning, you rise to your unsteady feet.
                            Rolande practically raped you, but there's no point in making a fuss.
                            The guards won't care, he won't care,
                            and you'd rather get [b]paid[/b] rather than pissing the merchant off by making a scene or asking for
                            ${hjMoney || bjMoney || sexMoney ? `more` : ``} money.
                        [/p]
                        [p]
                            Instead of complaining, you wipe your ${cunt ? `loins` : `ass`} somewhat clean of spunk with your hand,
                            shake the viscous liquid off of your fingers,
                            ${bra && shirt ? `re-adjust your ${braTooltip}
                            and your ${shirtTooltip} to cover your chest once more,` : shirt ? `re-adjust your ${shirtTooltip},` : bra ? `re-adjust your ${braTooltip},` : ``}
                            ${pants && underwear ? `collect your ${pantsTooltip}
                            and your ${underwearTooltip},` : pants ? `collect your ${pantsTooltip},` : underwear ? `collect your ${underwearTooltip},` : ``}
                            and waddle over to the other side of the counter.
                            You were used and abused like a piece of meat.
                            Like the kobold [b]whore[/b] that you've become.
                            But at least it's over now.
                            Time to get paid.
                        [/p]
                        [p]
                            "[color=yellow]Ah, right.
                            How much do I owe you again?
                            Ten? Fifteen coins?
                            ${hjEager && bjEager ? `Maybe twenty-five, given how well you behaved,
                            before I told you to lift your tail?` : hjEager || bjEager ? `Maybe [b]twenty[/b]?
                            You [i]were[/i] good with your ${hjEager ? `hands` : `mouth,
                            initially`}.` : `That's what your [b]lousy performance[/b] was worth, anyway.`}[/color]"
                            You [i]kindly[/i] remind Rolande that he owes you ${paid} pieces of gold, and not one less.
                            He rolls his eyes, and reaches for a nearby pouch.
                        [/p]
                        [p]
                            "[color=yellow]Fine. Your ${cunt ? `cunt` : `ass`} [b]was[/b] pretty tight,
                            even if you acted pretty annoyingly.${virgin ? ` And I got to pop your cherry.` : ``}[/color]"
                            He empties the bag, coins clattering atop the wooden countertop.
                            "[color=yellow]Next time I get a kobold whore, I'm fucking them to [b]death[/b] so I don't have to pay them.[/color]"
                            You ignore his overly dramatic statement, and instead focus on quickly collecting the money,
                            pocketing it in your own purse, which grows tangibly heavier.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexFinale.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexReluctant.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexReluctant(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var reqController = ctrl.sexAttitude;
    var subController = ctrl.sexFinale;
    var changeController = ctrl.sexReluctant;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.sexFinale;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexMoney = ctrl.sexMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? "seventy" : "fifty" : bjMoney ? "fifty" : "thirty";
        var wantPaid = hjMoney ? bjMoney ? "one hundred" : "eighty" : bjMoney ? "eighty" : "sixty";
        var wantPaidCaps = hjMoney ? bjMoney ? "A hundred" : "Eighty" : bjMoney ? "Eighty" : "Sixty";
        var cunt = ctrl.misc.cunt();
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var cuntboy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var underwear = ctrl.misc.underwear();
        var underwearTooltip = global.kobold.inventory.createItemWithTooltip(underwear);
        global.kobold.history.shared.varanar.dayThree.noon.fucked = true;
        var toReturn = `[p]
                            You got carried away, [i]teasing[/i] Rolande like that.
                            Coming back to your senses, you eye his needy, curved member up and down.
                            While you've no doubt you can fit inside of you fully, it's going to be a [b]tight squeeze[/b] to say the least.
                            Especially without proper preparation.
                        [/p]
                        [p]
                            The dragon watches impatiently as you slide one of your hands down your slender, scaly body, towards your ${cunt ? `groin` : `rear`}.
                            After ${cunt ? `rubbing one finger along the length of your slit` : `circling your tailhole with one of your fingers`} for a few seconds,
                            you slip the digit inside.
                            The shopkeeper restively taps his thigh with one of his hands, his masturbation growing slower and slower as his restraint is running thin.
                            "[color=yellow]Nice [i]show[/i], but can we get to fucking already?[/color]"
                            You tell him to wait a minute.
                            You're not ready yet.
                        [/p]
                        [p]
                            You pump your finger in and out of your ${cunt ? `loins` : `butthole`}, wriggling it around inside of your body to loosen yourself up a little.
                            Before you're even able to add a second digit, Rolande rises from his stool.
                            "[color=yellow]Time's up.[/color]" he states, grabbing you underneath your armpits and effortlessly lifting you off the ground,
                            your loosening finger yanked from your ${cunt ? `slit` : `butt`}.
                            You protest, wriggling around, trying but failing to escape the big dragon's grasp.
                            You need more time to prepare!
                            He'll get to fuck you in a bit!
                        [/p]
                        [p]
                            "[color=yellow]I'm not paying you to make me [b]wait[/b].
                            I'm paying you to [b]shut up[/b] and [b]spread your legs[/b].[/color]"
                            The merchant roughly throws you on top of the wooden countertop, pinning you down by placing a single hand on your back.
                            Your legs dangle off the side, unable to reach the floor, leaving you completely [b]bent over[/b].
                            Panicking, you pleadingly scream that you [b]can't[/b] take someone of his [i]size[/i]!
                            Not without [i]warming up[/i] first!
                            "[color=yellow]You should have thought about that [b]before[/b] offering your body.
                            I didn't stop you from getting ready while you were jerking me off or sucking my dick.[/color]"
                        [/p]
                        [p]
                            You wriggle and kick, in another failed attempt to free yourself.
                            Without being able to reach the floor, you can't put up much of a fight.
                            One of the claws of your feet lightly scratches Rolande's thigh, but he's too aroused to [i]care[/i].
                            With his free hand, he crudely [b]yanks[/b] your tail upwards,
                            simultaneously positioning himself behind you.
                            You let out a loud whine, which turns into a hiss halfway through.
                            He needs to [b]let you go[/b] already!
                            The joke's over!
                            It's [b]not[/b] funny!
                        [/p]
                        [p]
                            "[color=yellow]Who's joking?[/color]"
                            He inches forwards, pressing the tapered tip of his cock against your tender,
                            unprepared${virgin ? `, virginal` : ``} ${cunt ? `cunt` : `butthole`}.
                            You try to muster one final argument, but halfway through stumbling out your plea,
                            the dragon [b]thrusts[/b] his hips forwards, [b]ramming[/b] his member inside of your unlubed hole,
                            the small amount of precum and near-dried saliva slathered along his length doing little to ease the insertion.
                            ${virgin && cunt ? `A small trickle of blood signifies the loss of your virginity.` : ``}
                        [/p]
                        [p]
                            You [b]scream[/b] out in pain, Rolande muffling your shout by wrapping a hand around your muzzle,
                            holding your mouth closed as he pulls out once more, only to [b]force[/b] himself in even deeper,
                            your ${cunt ? `twat` : `ass`} stretched to its limits as the draconic man forces his curved shaft inside of you to the very base,
                            his cockslit coming to rest against your ${cunt ? `own folds` : `rear`}.
                            "[color=yellow]Quiet, [b]whore[/b].
                            I don't want the town to know I stooped so low as to bang a [b]kobold[/b].[/color]"
                        [/p]
                        [p]
                            You whine through your shut maw, tears flowing liberally from the corners of your eyes.
                            He's [b]too big[/b].
                            It [b]hurts[/b].
                            You feel full.
                            [b]Too[/b] full.
                            Your stomach bulges slightly, your body distorted with a faint outline of the draconic dick lodged firmly inside of you.
                            But Rolande doesn't care.
                            To him, you're an undersized fuck he paid good money for.
                            And he intends to make you worth every coin he's spending.
                        [/p]
                        [p]
                            "[color=yellow]You weren't lying when you said you weren't ready.
                            As usual, I have to do [b]all[/b] the work.[/color]"
                            After staying bottomed out inside of you for a few moments, the dragon pulls back ever so slightly,
                            keeping most of his member hilted, retracting only a little before rolling his hips forwards once more.
                            He turns this shallow, deep humping into a slow, steady rhythm,
                            breaking your overly tight ${cunt ? `slit` : `tailhole`}'s near vice-like grip on his shaft by
                            repeatedly forcing the thickest part of his length in and out of you,
                            loosening you up [i]the hard way[/i], in preparation of fucking you [b]properly[/b].
                        [/p]
                        [p]
                            You meekly squirm atop the counter,
                            a pathetic last-ditch attempt to try to slide off of the merchant's cock, which he barely even notices.
                            His thrusting gradually intensifies, in both speed and ferocity,
                            more and more of his manhood sliding in and out of your thoroughly loosened hole,
                            his scaly groin slapping against your bubbly butt every time he bottoms out.
                            While the oversized pounding is not pleasurable in the least, the initial pain of being [b]stretched[/b] somewhat fades,
                            giving way to the uncomfortable feeling of being repeatedly [b]overfilled[/b], stuffed to the brink.
                        [/p]
                        [p]
                            Rolande is panting loudly, his extremely [b]warm[/b] breath alone heating up the room, no doubt a remnant of his feral dragon ancestry.
                            His member, too, begins to [b]heat up[/b], growing fiery [b]hot[/b] inside of you,
                            warming your insides, to the point that you start to [b]sweat[/b].
                            Another draconic thing, probably.
                            You can see how people would like this, but to you it ends up making you feel more like a [b]toy[/b].
                            A piece of [b]meat[/b] being [b]used[/b] by a man greater than you in size and in stature.
                            A noble, pureblooded dragon sating his lust on a worthless, insignificant kobold.
                        [/p]
                        [p]
                            You hear the shopkeeper's toe-claws digging in to the wooden floor below,
                            as his rapid, near-rabid humping becomes more [i]unsteady[/i], more [b]animalistic[/b].
                            You think he's getting close.
                            Your ${hjEager ? `milking` : `lousy`} handjob and your ${bjEager ? `enthusiastic` : `dreadful`} blowjob must have aroused him.
                            Or maybe he was jerking off [b]long[/b] before you arrived.
                            Either way, your heated stay in [b]hell[/b] will soon be over.
                        [/p]
                        [p]
                            Grabbing your thigh with one of his hands, and crudely keeping you pinned with the other,
                            the merchant retracts his length from your ${cunt ? `folds` : `rear`}, until only his tip remains.
                            For a moment, you feel empty, your body and your mind both relaxing,
                            imagining the torment to be over, thinking he was done, that he'd finish himself off.
                            "[color=yellow]...breed you good.[/color]" Rolande mutters to himself.
                            Then, without warning, he [b]slams[/b] himself inside once more,
                            and begins to properly [b]fuck[/b] you, without holding back,
                            the entire counter rocking back and forth as he brutally pounds your ${cunt ? `cunt` : `tailhole`},
                            a low rumbling sound building up at the back of his throat.
                        [/p]
                        [p]
                            No longer muffled, you first [b]yelp[/b] out in surprise, and then [b]scream[/b] for help,
                            the dragon's overzealous rutting and his [b]scalding[/b] hot member making you feel like you're about to [b]break[/b].
                            Your screech for aid is overshadowed, however, by the loud noise of your scales slapping together,
                            the creaking of the counter, the shattering of various jars and potions as they slip off the shaking countertop and fall to the floor below,
                            and ultimately a raging [b]roar[/b] by Rolande himself, as he finally reaches his end.
                        [/p]
                        [p]
                            The merchant continues to mercilessly [b]ravish[/b] your ${cunt ? `twat` : `ass`} as wave after wave of his thick,
                            heady, [b]potent[/b], [b]scorching[/b] spunk floods your insides,
                            much of the stuff instantly forced out by his pistoning member,
                            ${cunt ? `which leaves little room for his inseminating goop` : `leaking from your gaping tailhole whenever he pulls back`}.
                            After a last few wet, semen-sloshing thrusts, Rolande finally pulls out, spilling the rest of his orgasm over your buttcheeks.
                        [/p]
                        [p]
                            The dragon lets go of you.
                            You limply fall to the ground, completely [b]spent[/b] and [b]out of it[/b].
                            The storekeeper takes the opportunity to wipe his messy cock on your face.
                            Now that it's starting to cool down, his cum actually feels kind of [i]soothing[/i],
                            easing the light burns you sustained at the height of the heated fucking.
                        [/p]`;

        if (ctrl.misc.oralVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer an oral virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }
        if (cunt && ctrl.misc.cuntVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer a virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }
        if (!cunt && ctrl.misc.analVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer a virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexReluctant.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexEager.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexEager(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;
    var reqController = ctrl.sexAttitude;
    var subController = ctrl.sexFinale;
    var changeController = ctrl.sexEager;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.sexFinale;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexMoney = ctrl.sexMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? "seventy" : "fifty" : bjMoney ? "fifty" : "thirty";
        var wantPaid = hjMoney ? bjMoney ? "one hundred" : "eighty" : bjMoney ? "eighty" : "sixty";
        var wantPaidCaps = hjMoney ? bjMoney ? "A hundred" : "Eighty" : bjMoney ? "Eighty" : "Sixty";
        var baseGender = ctrl.misc.baseGender();
        var cunt = ctrl.misc.cunt();
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var cuntboy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var underwear = ctrl.misc.underwear();
        var underwearTooltip = global.kobold.inventory.createItemWithTooltip(underwear);
        global.kobold.history.shared.varanar.dayThree.noon.fucked = true;
        global.kobold.history.shared.varanar.dayThree.noon.fuckedEager = true;
        var toReturn = `[p]
                            You [b]want[/b] this every bit as much as Rolande does.
                            Although, eyeing his curved member up and and down, while you've no doubt it can fit inside of you fully,
                            it's going to be a [b]tight squeeze[/b] to say the least.
                            Luckily, constantly inhaling his arousing cockscent has left your ${cunt ? `loins moist` : `body fully relaxed`}.
                            Still, a [i]little[/i] bit of preparation couldn't hurt.
                        [/p]
                        [p]
                            The dragon watches impatiently as you slide one of your hands down your slender, scaly body, towards your ${cunt ? `groin` : `rear`}.
                            After ${cunt ? `rubbing one finger along the length of your wet slit` : `circling your tailhole with one of your fingers`} for a few seconds,
                            you slip the digit inside.
                            The shopkeeper restively taps his thigh with one of his hands, his masturbation growing slower and slower as his restraint is running thin.
                            You pump your finger in and out of your ${cunt ? `folds` : `butthole`} a few times,
                            wriggling it around inside of your body to loosen yourself up a little.
                            "[color=yellow]Nice [i]show[/i], but can we get to fucking already?[/color]"
                            You couldn't agree more.
                        [/p]
                        [p]
                            Ceasing your light masturbation, you climb atop the seated merchant's lap,
                            ending up standing on his thighs, finally on equal height with Rolande,
                            his curved member mere inches below your eager ${cunt ? `twat` : `ass`}.
                            You exchange lustful glances with the storekeeper.
                            "[color=yellow]At this rate, [b]you[/b] should be the one paying [b]me[/b].[/color]"
                            You joke that you're not the one throbbing in anticipation.
                            The dragon blushes, something you haven't seen him do since you've met the guy.
                            "[color=yellow]Get on my dick already, you [b]slut[/b].[/color]"
                        [/p]
                        [p]
                            You eagerly oblige, squatting down,
                            dropping your lower half until your ${cunt ? `moist cunt` : `slackened ass`} presses against the tapered tip of his cock.
                            Throwing one final smirk your [i]client[/i]'s way, you slowly ease yourself onto his length,
                            spreading open your ${virgin ? `virginal` : ``} ${cunt ? `folds` : `tailhole`}.
                            ${virgin && cunt ? `A small trickle of blood signifies the loss of your virginity.` : ``}
                        [/p]
                        [p]
                            Rolande lets out a satisfied sigh as you continue to lower yourself onto his shaft.
                            An internal squirt of precum immediately rewards your efforts, slickening your insides,
                            allowing you to slide down a few inches more.
                            You don't quite manage to make it to the base of the dragon's length on your first go,
                            but still end up taking over half of it before your initial push comes to an end.
                            You can already feel the curvature of his dick, which allows the tapered tip to reach places your fingers never could.
                            It feels [b]incredible[/b].
                            And you've only getting started.
                        [/p]
                        [p]
                            Your performance so far seems to please the dragon.
                            Perhaps you've surprised him a little, taking most of his shaft in a single push.
                            He lustily licks his lips, looking down at you with [b]need[/b] in his eyes, signalling for you to start moving.
                            Not wanting to keep him -- or yourself -- waiting, you lift yourself back up,
                            until only the very tip of the merchant's cock remains inside of you.
                            Precum oozes from his member, some of it lubing up your tight hole,
                            the rest dribbling down his length, lubricating it as well.
                        [/p]
                        [p]
                            Your way paved in warm, slippery pre, you let yourself [b]fall[/b] down once more,
                            [b]impaling[/b] yourself on Rolande's girthy shaft.
                            To your surprise, the copious amount of precum, combined with ${cunt ? `your own feminine juices` : `completely relaxing your tailhole`},
                            allows you to slide all the way down to the very [b]base[/b] of his draconic cock, taking [b]all[/b] of it.
                            You [b]moan[/b] out in [b]ecstacy[/b], filled to the brim with thick dragon dick,
                            your ${cunt ? `cunt` : `ass`} stretched to its very limits,
                            ${cunt ? `your slit [b]dripping wet[/b] with arousal` : `your own member hardening, emerging from your cockslit`}.
                        [/p]
                        [p]
                            "[color=yellow]Enjoying yourself?[/color]" the merchant asks, but you pay him no mind.
                            Lost in pleasure, you grab onto his shoulders, and wantonly begin to [b]bounce[/b] up and down his length,
                            riding it like a ${baseGender === GenderEnum.MALE ? `man` : `woman`} possessed,
                            revelling in absolute [b]bliss[/b] atop an exotic dick of an undeniably [b]superior[/b] species.
                        [/p]
                        [p]
                            Driven by instinct, you press your lips against Rolande's pulling him in to a passionate kiss.
                            For a few seconds, he plays along, dominantly [b]probing[/b] your mouth with his tongue.
                            Then, he pulls from the kiss.
                            "[color=yellow]I don't usually kiss my [b]whores[/b].
                            Anyway, enough of your [b]clumsy[/b] fooling around.
                            Time for the [b]real[/b] fun to begin.[/color]"
                        [/p]
                        [p]
                            That being said, the dragon grabs hold of your sides, gripping your scaly body with both of his hands.
                            After lifting you up slightly, he [b]slams[/b] you down on his length, simultaneous [b]thrusting[/b] upwards,
                            [b]ramming[/b] his member half an inch deeper than before,
                            sending another spike of pure [b]exhilaration[/b] down your spine.
                        [/p]
                        [p]
                            Rolande begins to wantonly slide you up and down his shaft,
                            bucking his hips upwards every time you bottom out,
                            your bubbly butt slapping loudly against his scaly groin.
                            No longer in control, you surrender yourself to euphoria,
                            to the mind-clouding haze of pure [b]sex[/b].
                            You continuously moan like the cheap whore that you are,
                            ${cunt ? `your slit leaking feminine fluids, [b]drenching[/b] the merchant's groin,
                            the smell of your own excitement mixing with the storekeeper's honey-like fragrance` : `your erect,
                            flopping cock leaking pre all over the merchant's expensive, silk shirt.`}
                        [/p]
                        [p]
                            The dragon, too, is enjoying this.
                            He's panting loudly, his extremely [b]warm[/b] breath alone heating up the room, no doubt a remnant of his feral dragon ancestry.
                            His member, too, begins to [b]heat up[/b], growing fiery [b]hot[/b] inside of you,
                            warming your insides, to the point that you start to [b]sweat[/b].
                            Another draconic thing, probably.
                        [/p]
                        [p]
                            Whatever it is, you [b]love[/b] it.
                            And not just the warmth.
                            [b]Everything[/b] about this.
                            The way Rolande controls your body,
                            his exotically [b]curved[/b] length hitting [b]all[/b] the right places,
                            the rapid pace, his domineering attitude, the [b]marvellous[/b] scent,
                            it all combines into a single, almost otherwordly, absolutely [b]heavenly[/b] experience.
                            Your eyes roll into the back of your head, as sheer pleasure overwhelms your brain.
                        [/p]
                        [p]
                            Rolande grunts loudly, a low rumbling sound building up at the back of his throat.
                            His motions become more erratic, more [i]ferocious[/i], more [b]animalistic[/b].
                            You think he's getting close.
                            Your ${hjEager ? `milking` : `lousy`} handjob and your ${bjEager ? `enthusiastic` : `dreadful`} blowjob must have aroused him.
                            Or maybe he was jerking off [b]long[/b] before you arrived.
                            Either way, your heated stay in [b]heaven[/b] will soon be over.
                        [/p]
                        [p]
                            Reaching his end, the dragon lets out a loud [b]roar[/b], roughly [b]tugging[/b] you down to the base of his cock,
                            keeping himself hilted as the first wave of his thick, heady, [b]potent[/b], [b]scorching[/b] spunk floods your insides.
                            Halfway through his bestial shout, he presses his lips against yours once more, resuming the deep,
                            dominating kiss he broke away from earlier,
                            thoroughly [b]tonguekissing[/b] you while squirting rope after rope of draconic semen into your body.
                        [/p]
                        [p]
                            The merchant keeps you pinned on his cock, for the entire duration of his orgasm,
                            pumping his entire ${cunt ? `fertile` : ``} load inside of you while properly [b]exploring[/b] your mouth,
                            his warm breath heating up your gums as his hot cock warms up your ${cunt ? `loins` : `innards`}.
                            Not that you're going anywhere.
                            If you could, you would stay in his lap, basking in constant arousal, forever and then some.
                        [/p]`;

        if (ctrl.misc.oralVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer an oral virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }
        if (cunt && ctrl.misc.cuntVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer a virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }
        if (!cunt && ctrl.misc.analVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer a virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexEager.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexChoices.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexChoices(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.sexAttitude;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new NoonThreeStoreSexReluctant(ctrl);
    var secondNext = new NoonThreeStoreSexEager(ctrl);

    var firstChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var secondChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Reluctant</button>`;

        var tooltip = global.parser.parse(`You're starting to have second thoughts.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Eager</button>`;

        var tooltip = global.parser.parse(`You [b]want[/b] this. The money's just a bonus.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You are:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexChoices.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexMoreMoney.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexMoreMoney(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
    var reqController = ctrl.sexMoney;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.sexChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? "seventy" : "fifty" : bjMoney ? "fifty" : "thirty";
        var wantPaid = hjMoney ? bjMoney ? "one hundred" : "eighty" : bjMoney ? "eighty" : "sixty";
        var wantPaidCaps = hjMoney ? bjMoney ? "A hundred" : "Eighty" : bjMoney ? "Eighty" : "Sixty";
        var cunt = ctrl.misc.cunt();
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var cuntboy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var underwear = ctrl.misc.underwear();
        var underwearTooltip = global.kobold.inventory.createItemWithTooltip(underwear);
        var toReturn = `[p]
                            Have sex?
                            ${bjEager ? `You thought he'd never ask.
                            There's something he should know about you, though.
                            You're kind of still a [i]virgin[/i].` : `You're not too sure about this.
                            You [i]are[/i] still a virgin, after all.`}
                            But, there might be a deal to be made here.
                            You [b]do[/b] want to [i]lose[/i] your virginity to Rolande,
                            but you simply can't see yourself doing it for a measily ${paid} coins.
                            You may only be a kobold, but surely your virginity is worth more than that, right?
                            Let's say, maybe, ${wantPaid} gold instead?
                        [/p]
                        [p]
                            The dragon lifts a scaly eyebrow, clearly considering your offer.
                            He's far from fully persuaded yet, though.
                            "[color=yellow]${wantPaidCaps}?
                            I don't know.
                            I [b]do[/b] like my whores tight, and a virgin kobold is about as tight as they get.
                            But then again, you [i]are[/i] still a kobold, and no kobold is worth that amount of money.[/color]"
                        [/p]
                        [p]
                            Looks like you'll need to convince him otherwise.
                            You rise to your feet,
                            ${pants && underwear ? `lower your ${pantsTooltip} and your ${underwearTooltip}
                            to the ground,` : underwear ? `lower your ${underwearTooltip}
                            to the ground,` : pants ? `lower your ${pantsTooltip} to the ground,` : ``}
                            ${!cunt ? `turn around,` : ``}
                            and press your naked ${cunt ? `loins` : `butt`} against his warm, throbbing, spit-coated shaft, teasing the merchant.
                            He takes hold of his member, and eagerly rubs the tip against your virginal ${cunt ? `slit` : `tailhole`},
                            intent on slipping inside, but you pull away mere moments before he manages to put it in.
                            ${!cunt ? `You turn to face him once more, staring into his eyes,
                            seductively licking your lips.` : `You stare into his eyes, seductively licking your lips.`}
                            Thirty extra coins, and you'll be all his.
                        [/p]
                        [p]
                            You can feel the storekeeper growing more lusty with every passing second.
                            He slowly strokes his member while silently considering your demand.
                            "[color=yellow]${cuntboy ? ` I thought you were a boy. ` : ``}Fifteen.[/color]" comes his counteroffer.
                            No.
                            Your virginity's worth more than a loaf of bread.
                            Thirty.
                            Take it, or leave it.
                            Come on, Rolande.
                            He wants to fuck you.
                            You want to lose your virginity.
                            He has plenty of money.
                            Surely, he can spare thirty coins for one of the best fucks of his life, right?
                        [/p]
                        [p]
                            The dragon lets out a mix between a relenting sigh which turns into an eager growl about halfway through.
                            "[color=yellow]Fine.
                            Thirty extra.
                            But you'd better be every bit as tight as you claim to be.[/color]"
                            You assure him that you sometimes have trouble even fitting more than one [b]finger[/b] inside of yourself.
                            But you're certain that will change after he's done with you.
                            An approving harrumph is the only response you get.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexMoreMoney.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexAccept.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexAccept(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var reqController = ctrl.sexMoney;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.sexChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var paid = hjMoney ? bjMoney ? "seventy" : "fifty" : bjMoney ? "fifty" : "thirty";
        var wantPaid = hjMoney ? bjMoney ? "one hundred" : "eighty" : bjMoney ? "eighty" : "sixty";
        var wantPaidCaps = hjMoney ? bjMoney ? "A hundred" : "Eighty" : bjMoney ? "Eighty" : "Sixty";
        var cunt = ctrl.misc.cunt();
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var cuntboy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var pants = ctrl.misc.pants();
        var pantsTooltip = global.kobold.inventory.createItemWithTooltip(pants);
        var underwear = ctrl.misc.underwear();
        var underwearTooltip = global.kobold.inventory.createItemWithTooltip(underwear);
        var toReturn = `[p]
                            Have sex?
                            ${bjEager ? `You thought he'd never ask.
                            ${virgin ? `There's something he should know about you, though.
                            You're kind of still a [i]virgin[/i].` : ``}` : `You're not too sure about this.
                            ${virgin ? `You [i]are[/i] still a virgin, after all.` : ``}`}
                            ${virgin ? `Not that that's a dealbreaker or anything.` : ``}
                            The dragon grins lewdly.
                            "[color=yellow]Wise choice, kobold.
                            I'm sure you won't be disappointed.
                            And neither will I.[/color]"
                        [/p]
                        [p]
                            You rise to your feet,
                            ${pants && underwear ? `lower your${pantsTooltip} and your ${underwearTooltip}
                            to the ground,` : underwear ? `lower your ${underwearTooltip}
                            to the ground,` : pants ? `lower your ${pantsTooltip} to the ground,` : ``}
                            ${!cunt ? `turn around,` : ``}
                            and press your naked ${cunt ? `loins` : `butt`} against his warm, throbbing, spit-coated dick, teasing the merchant.
                            He takes hold of his member, and eagerly rubs the tip against your ${virgin ? `virginal` : ``} ${cunt ? `slit` : `tailhole`},
                            intent on slipping inside, but you pull away mere moments before he manages to put it in.
                            Not quite yet.
                        [/p]
                        [p]
                            The dragon slowly strokes his quivering shaft.
                            "[color=yellow]${cuntboy ? ` I thought you were a boy. ` : ``}Teasing little slut, aren't you?
                            Do you put out for every guy that offers you a few coins, or was I too handsome for you to resist?[/color]"
                            ${hjEager && bjEager ? `You confess that there's something that feels [b]natural[/b] about serving dragons.
                            Rolande seems pleased with your response.` : `You wouldn't call what he's paying you [i]a few coins[/i].
                            "[color=yellow]And I wouldn't call us fucking you [i]lending a hand[/i].[/color]"`}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexAccept.js

// scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexDecline.js

/**
 * Sex section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreSexDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var reqController = ctrl.sexMoney;
    var subController = ctrl.sexDecline;
    var changeController = ctrl.sexDecline;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreSexEnd(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = ctrl.blowjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var maleVirgin = ctrl.misc.cunt() || ctrl.misc.analVirgin();
        var femaleVirgin = !ctrl.misc.cunt() || ctrl.misc.cuntVirgin();
        var virgin = maleVirgin && femaleVirgin;
        var male = !ctrl.misc.cunt();

        var toReturn = ``;

        if (bjEager) {
            toReturn += `
                        [p]
                            No.
                            You're [b]already[/b] doing more than you initially agreed to.
                            You don't want to have sex with him.
                            "[color=yellow]Are you lying to me, or to yourself?[/color]"
                            You're not lying to [b]anyone[/b].
                            "[color=yellow]Bullshit.
                            I had to [b]pull[/b] you off my dick.
                            You know you want this.[/color]"
                            You really, really don't.
                            ${virgin ? `You're still a virgin, and you don't want your first time to be with him.` : ``}
                            "[color=yellow]How about I throw in like five extra coins?[/color]"
                            He's not listening.
                            You [b]don't[/b] want to have sex with him, not for all the money in the world.
                        [/p]`;
        } else {
            if (hjEager) {
                toReturn += `
                        [p]
                            No.
                            You're [b]already[/b] doing more than you initially agreed to.
                            You don't want to have sex with him.
                            "[color=yellow]You were so good with your hands,
                            but then you started [b]slacking[/b] when I [i]gracefully[/i] decided to let you use your mouth.
                            Were you disappointed?
                            Did you think I wasn't going to let you ride me?[/color]"
                            No!
                            You didn't want to suck him off, and you sure as hell don't want to let him fuck you.
                            "[color=yellow]How about I throw in like five extra coins?[/color]"
                            He's not listening.
                            You [b]don't[/b] want to have sex with him, not for all the money in the world.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            No.
                            You're [b]already[/b] doing more than you initially agreed to.
                            You don't want to have sex with him.
                            "[color=yellow]You've been doing a pretty poor job so far${hjMoney || bjMoney ? `, despite the extra money I'm paying` : ``}.[/color]"
                            You didn't ask for this job in the first place.
                            He can be happy you've played along for as long as you have.
                            Does he want you to [i]leave[/i]?
                            "[color=yellow]How about I throw in like five extra coins?[/color]"
                            He's not listening.
                            You [b]don't[/b] want to have sex with him, not for all the money in the world.
                        [/p]`;
            }
        }

        toReturn += `   [p]
                            Rolande is trying to take things one step too far.
                            And you don't much appreciate that.
                            Luckily, at least you seem to be getting through to him.
                            The expression on his face goes from suggestive and lewd to confused and angry.
                            Once more, you reiterate: you'll keep sucking his dick if you wants you to, but you're [b]not[/b] [i]sleeping[/i] with him.
                            The dragon looks down at you, clearly upset.
                            "[color=yellow][b]Fine[/b].
                            ${bjEager ? `Get back to stuffing your face with my cock, then.` : `Plug that rebellious muzzle of your with cock.`}
                            Like I care about not getting any disease-ridden kobold ${male ? `ass` : `cunt`}.[/color]"
                        [/p]
                        [p]
                            He obviously [b]does[/b] care.
                            But, whatever.
                            You let out a disappointed sigh, and lower your mouth back down onto Rolande's member,
                            resuming your ${bjEager ? `over-eager` : `half-hearted`} blowjob,
                            this time with a bit ${bjEager ? `less` : `more`} passion.
                            ${bjEager ? `Feeling [i]insulted[/i], you take a little less of his length,
                            and no longer vigorously use your tongue to please the dragon.` : `You use your tongue a little,
                            swirling it around the dragon's shaft, hoping he'll be pleased with your added effort.`}
                        [/p]
                        [p]
                            ${bjEager ? `Your lack of effort seems to irk the merchant further.` : `Even with your renewed vigour, the merchant still seems irked.`}
                            "[color=yellow]Have to do [b]everything[/b] myself.[/color]" you hear him mutter.
                            Suddenly, the dragon places both of his hands on the back of your head.
                            Before you can even react, he harshly [b]pushes[/b] you down onto his length,
                            [b]forcing[/b] you to take his cock [b]all[/b] the way, the tapered tip barreling down your throat,
                            cutting off your air intake long before your snout comes to rest against Rolande's scaly groin.
                        [/p]
                        [p]
                            Your throat spasms around the shopkeeper's intruding length, your gag reflex kicking in.
                            No longer able to breathe, you panic, wildly flailing your arms about, frantically tapping the dragon's leg to signify that you want [b]up[/b].
                            The merchant does not relent, firmly keeping you in place with his dick lodged down your esophagus, blocking your windpipe.
                            You slowly calm down, ceasing your struggles to preserve your air.
                            He doesn't want you dead.
                            If he did, he'd have chosen a less [i]dangerous[/i] way to do instead of choking you on his shaft.
                            He's just being an [b]asshole[/b].
                            Fighting back would be a one-way ticket to the nearest dungeon, if the guards don't beat you to death first.
                        [/p]
                        [p]
                            As your arms come to a supportive rest atop his thighs, you cast a wicked glare up at him,
                            wordlessly telling him exactly how much you feel like [b]biting down[/b] right now.
                            The merchant returns your leer with a toothy grin.
                            He knows your hands are figuratively tied.
                            "[color=yellow]If you're not going to let me fuck you, then I might as well get my money's worth out of this blowjob.
                            Take notes, [b]whore[/b].
                            I'm about to give you a [i]free[/i] lesson on how to please a man.[/color]"
                        [/p]
                        [p]
                            His words still ringing through your ears, Rolande pulls your head upwards,
                            letting you get nothing more than a single [b]gasp[/b] of fresh air before pushing you downwards once more,
                            all the way to the thick base of his shaft, your muzzle ending up pressing against his heavily fragrant cockslit,
                            your maw spread as wide as it'll go.
                            Instead of holding you bottomed out a second time, the dragon immediately lifts you up once more,
                            only to [b]slam[/b] you down again, marking the start of a fast-paced throat-fucking rhythm,
                            completely controlled by merchant himself.
                        [/p]
                        [p]
                            At first, you try to resist, to at least [i]slow down[/i] Rolande's [b]vicious[/b] pace,
                            which leaves [b]very[/b] little room for you to [b]breathe[/b].
                            You soon realize, however, that you neck muscles aren't [b]nearly[/b] strong enough to compete with not one,
                            but [b]two[/b] powerful draconic arms.
                        [/p]
                        [p]
                            Failing to fight back, you resort to trying to make the most out of the unpleasant, forceful deepthroating.
                            You time your attempts to inhale, you keep your muzzle open wide to spare your jaw-muscles,
                            and you relax your throat as best as you can, suppressing your instinctive gag-reflex.
                            Ultimately, what this all amounts to is that you simply [b]let[/b] the dragon use your mouth as a cheap, disposable fucktoy.
                            You let him abuse you like the [b]whore[/b] you are.
                        [/p]
                        [p]
                            While you [i]try[/i] to breathe in at the apex of Rolande's motions,
                            you simply can't suck in enough oxygen during the few split-seconds his girthy cock [b]isn't[/b] cutting off your windpipe.
                            Blackness envelops the corners of your eyes, the lack of air really starting to get to you.
                            Right as you thought you were about to pass out, the shopkeeper's pace drastically lowers,
                            granting you a bit more time to gasp in some much-needed air.
                        [/p]
                        [p]
                            In place of the rapid, suffocating rhythm comes a far slower, more intense throatfucking.
                            The dragon is breathing deeply.
                            He grunts loudly every time he forces your head downwards.
                            You think he's starting to get close.
                            At last, this [b]torture[/b] is almost over.
                        [/p]
                        [p]
                            Right as the thought crossed your mind, the storekeeper loudly [b]roars[/b] out in ecstacy.
                            He [b]slams[/b] your face into his groin while simultaneously [b]thrusting[/b] his hips forwards,
                            [b]ramming[/b] his cock just an [b]inch[/b] further than usual down your esophagus.
                            He holds you in place, choking you on his girth, while he squirts wave after wave of thick,
                            pearly dragon spunk directly down your throat, into your stomach.
                        [/p]
                        [p]
                            A second time, you feel like you are about to pass out, your gut heavy with large amounts of lukewarm semen.
                            Then finally, Rolande pulls you from his member fully, and lets go of your head.
                            You instantly break the strings of saliva connecting your aching jaw to his cock,
                            turning away and dropping to all fours on the ground.
                            You take a deep breath, cough up remnants of cum and pre sticking to the back of your throat, and then begin to gasp for air.
                        [/p]`;

        if (ctrl.misc.oralVirgin()) {
            toReturn += `
                        [p]
                            [c]
                                [b]
                                    You are no longer an oral virgin.
                                [/b]
                            [/c]
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\sex\NoonThreeStoreSexDecline.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEnd.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobEnd(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.blowjobDecline;
    var subController = ctrl.preStore;
    var changeController = ctrl.blowjobEnd;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.store;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var shirt = ctrl.misc.shirt();
        var bra = ctrl.misc.bra();
        var paid = ctrl.proposal.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY ? "fifty" : "thirty";
        var toReturn = `[p]
                            No longer being held down, you rise to your feet.
                            After wiping your face clean a bit more thoroughly,
                            ${shirt || bra ? `and tidying your clothes,` : ``}
                            you return to the front of the counter.
                            Now for the matter of your [b]payment[/b].
                        [/p]
                        [p]
                            "[color=yellow]Right, your reward.
                            How much did we settle for again?
                            Five coins? Ten?[/color]"
                            You glare at the merchant.
                            "[color=yellow]Fifteen?[/color]"
                            You clear your throat.
                            "[color=yellow]Fine, you get all [b]twenty[/b] coins I promised you.[/color]"
                            Growing annoyed, you remind the dragon that it is [b]${paid}[/b] coins that you are due.
                            He grumbles something underneath his breath, reaching for his coin pouch.
                        [/p]
                        [p]
                            "[color=yellow]There, ${paid} pieces of gold.[/color]"
                            Rolande empties the pouch on the counter.
                            "[color=yellow]Do you want my [b]blood[/b] too, you leech?[/color]"
                            You disregard his overly dramatic statement, instead focussing on quickly collect all of the coins.
                            You pocket them in your own purse, which grows tangibly heavier.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEnd.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEndChoices.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobEndChoices(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.sexMoney;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new NoonThreeStoreSexDecline(ctrl);
    var secondNext = new NoonThreeStoreSexAccept(ctrl);
    var thirdNext = new NoonThreeStoreSexMoreMoney(ctrl);

    var firstChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var secondChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var thirdChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`You're not putting out for some random dragon, store-owner or not.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`Might as well have some [i]fun[/i] while you're whoring yourself out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var maleFail = ctrl.misc.dick() && !ctrl.misc.analVirgin();
        var femaleFail = !ctrl.misc.dick() && !ctrl.misc.cuntVirgin();
        var failedCheck = maleFail || femaleFail;
        var disabled = subController.has() || failedCheck ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>More money</button>`;

        var tooltip = global.parser.parse(`He'll have to cough up if he wants to pop your cherry.`);
        if (failedCheck) {
            tooltip = `You aren't a virgin. You can't ask him for more to pop your cherry.`;
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_barn");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEndChoices.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobReluctant.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobReluctant(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var reqController = ctrl.blowjobAttitude;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.blowjobEndChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.sucked = true;
        var eager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var extraMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var tentaclePlantKnowledge = global.kobold.history.shared.deepwoods.tentaclePlant.sapKnowledge;
        var toReturn = `[p]
                            Okay.
                            You can do this.
                            Focus on ${eager ? `that lovely smell` : extraMoney ? `all the gold you'll be making` : `getting out of here as soon as possible`}.
                            "[color=yellow]Hurry up. I don't have all day.[/color]"
                            You glare upwards, and tell Rolande that he needs to settle down.
                            You're getting there.
                            He just needs to give you a minute.
                            "[color=yellow]Stop talking back to me and get to [b]sucking[/b] already.[/color]"
                            Asshole.
                        [/p]
                        [p]
                            Steeling your nerves, you creep way forwards, your snout slowly approaching the dragon's dick.
                            Lifting your head a little, you are left directly above the curved length.
                            The bauble of precum collected at the tip is actually kind of [i]inviting[/i].
                            You wonder if it tastes as well as his loins smell.
                            Only one way to find out.
                        [/p]
                        [p]
                            You part your lips, and lower your maw over Rolande's cock,
                            taking the first few inches into your mouth.
                            It's not girthy enough to [b]completely[/b] fill your muzzle, but it's not far off either.
                            Using your tongue, you lap at the tapered tip, not to pleasure the dragon, but to collect his pre, out of sheer curiousity.
                            The flavour is unlike anything you would have expected.
                            Instead of [b]salty[/b], it tastes [i]sweet[/i], like [i]honey[/i] or [i]nectar[/i].
                            ${tentaclePlantKnowledge ? `It almost reminds you of that tentacle plant you encountered in the forest.` : ``}
                            You wonder if this is a trait inherent to all dragons, or if Rolande's been sipping some of the potions he sells.
                        [/p]
                        [p]
                            "[color=yellow]Well? Are you going to start moving, or do you expect me to do all the work${eager ? `` : ` again`}?[/color]"
                            Growing upset, you pull off of the shopkeeper's shaft,
                            and crudely tell him that if he's not quiet, he can go look for someone else to suck him off.
                            You can see that he wants to retort, to scold you even, but he bites his tongue, instead grumbly mumbling something underbreath.
                        [/p]
                        [p]
                            With an angry look on your face, you lower yourself back down on his dick, taking in half an inch more than before.
                            Too annoyed to put much heart into your efforts, you shallowly begin to bob up and down the meagre amount of cock in your mouth.
                            You [i]could[/i] be trying [b]way[/b] harder, especially since a considerable amount of coins is on the line,
                            but you don't feel like this [b]jerk[/b] deserves you giving it your all.
                            Heck, you didn't even really [i]want[/i] to suck him off to begin with.
                        [/p]
                        [p]
                            Rolande lets out an [i]obviously faked[/i] moan.
                            He places one of his large, scaled hand on the back of your head, trying to push you further down on his curved length.
                            You cast an irritated frown at him, threateningly baring your teeth.
                            But you [i]did[/i] get the message, taking in a few inches more, trying a little bit hard to earn your pay.
                        [/p]
                        [p]
                            Your threats do not seem to faze the dragon.
                            His palm remains on top of your head, pushing you back down whenever you move up, somewhat controlling the pace of your reluctant blowjob.
                            He keeps trying to force you to take more of him in your mouth, but you resist, never allowing him the pleasure of violating your throat.
                            Your unwillingness to take things one step further seems to vex the shopkeeper in turn.
                        [/p]
                        [p]
                            After a few minutes of the unsatisfying, half-hearted dicksucking, Rolande removes his hand from your cranium once more.
                            You take this as a sign that you can take a [i]break[/i] for a little bit.
                            Pulling off his shaft completely, you let your jaw rest.
                        [/p]
                        [p]
                            "[color=yellow]You're not very good at this, are you?[/color]"
                            The urge to tell him you don't feel like bringing out your A-game for a sleazebag like him is great,
                            but instead you simply mutter out that he's right.
                            "[color=yellow]That's fine.[/color]" comes his unexpected reply.
                            You thought he'd be mad, but apparently he seems somewhat [i]understanding[/i].
                            You don't trust this.
                        [/p]
                        [p]
                            "[color=yellow]Instead of sucking me off, how about giving me some ass instead?[/color]"
                            And there it is.
                            You knew he didn't suddenly turn into a sympathetic guy.
                            All an act, to get you to lift your tail for him.
                            "[color=yellow]My dick can reach places you never even knew existed.[/color]"
                            As if that's supposed to tempt you.
                            "[color=yellow]So what do you say?
                            Want to have some [i]fun[/i] while earning your money,
                            or do you want to keep doing something you [b]clearly[/b] don't want to be doing?[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobReluctant.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEager.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobEager(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;
    var reqController = ctrl.blowjobAttitude;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.blowjobEndChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.sucked = true;
        global.kobold.history.shared.varanar.dayThree.noon.suckedEager = true;
        var breasts = ctrl.misc.boobs();
        var eager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var extraMoney = ctrl.blowjobMoney.get() === ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
        var tentaclePlantKnowledge = global.kobold.history.shared.deepwoods.tentaclePlant.sapKnowledge;
        var toReturn = `[p]
                            Finally, ${eager ? `you can get to the [i]fun[/i] part` : `you can do something more enjoyable than jerking off the jerk`}.
                            ${eager ? `You wonder if his cock tastes as good as it smells` : `The smell of his loins has been growing on you.
                            You wonder if the taste matches`}.
                            The freshly formed bauble of precum at the tapered tip is looking mighty alluring.
                            You find yourself staring at it while greedily huffing the mouth-watering scent.
                            "[color=yellow]Well?
                            It's not going to suck itself.[/color]"
                            Even if it could, you doubt it'd enjoy itself as much as you are about to.
                        [/p]
                        [p]
                            You creep forwards, deeply inhaling while slowly approaching the dragon's shaft.
                            Lifting your head a little, you raise yourself directly above the curved length.
                            You lick your lips in anticipation, before parting them.
                            Lowering your maw over Rolande's cock, you take the first few inches of it into your mouth.
                            It's not girthy enough to [b]completely[/b] fill your muzzle, but it's not far off either.
                        [/p]
                        [p]
                            Using your tongue, you lap at the tip, collecting the built-up precum.
                            The flavour is every bit as [i]exotic[/i] as Rolande's dick itself.
                            Instead of [b]salty[/b], it tastes [i]sweet[/i], like [i]honey[/i] or [i]nectar[/i].
                            ${tentaclePlantKnowledge ? `It almost reminds you of that tentacle plant you encountered in the forest.` : ``}
                            You wonder if this is a trait inherent to all dragons, or if Rolande's been sipping some of the potions he sells.
                            Either way, you want [b]more[/b] of it.
                        [/p]
                        [p]
                            One of your hands finds its way to your own chest, which you frantically grope in a failed attempt to recreate the dragon's touch.
                            The other, you wrap around the thick base of his member, holding it still as you dutifully begin to move your head up and down,
                            swirling your tongue around its girth in the process, using the slender appendage to further please Rolande's shaft.
                            A squirt of his delicious pre is all the encouragement you need to keep going.
                        [/p]
                        [p]
                            The shopkeeper lets out a satisfied groan.
                            But still, he wants more.
                            He places one of his large, scaled hand on the back of your head, and begins to push you further down on his curved cock.
                            You happily oblige, taking inch after inch until over half of his member is coated in spit,
                            the tapered tip prodding against the back of your back of your throat every time you bob down.
                            Whenever you lift yourself up, the dragon is quick to push you deeper onto his length once more,
                            somewhat controlling the pace of the blowjob.
                        [/p]
                        [p]
                            You [b]love[/b] the way he [i]directs[/i] you.
                            It really makes you feel like [b]he[/b] is the one in control, and [b]not[/b] you.
                            There's something that feels oh-so [b]right[/b] about serving a dragon.
                            Like a primal, almost instinctual urge to please.
                            All of your senses are telling you that this is the way things are supposed to be.
                            In a brief moment of clarity, you wonder whether dragons have this effect on everyone, only on kobolds, or only on [b]you[/b];
                            and if it's [b]all[/b] dragons that'll make you feel this way, or just Rolande.
                        [/p]
                        [p]
                            Sadly, right as you were planning to go even [b]deeper[/b] onto his shaft,
                            the merchant breaks your zealous rhythm by pulling your head off his cock.
                            Why'd he stop you?!
                            He was [b]clearly[/b] enjoying himself!
                            And so were you!
                        [/p]
                        [p]
                            "[color=yellow]You're good at that, aren't you?
                            ${eager ? `Your mouth is every bit as skilled as your hands are.` : `Better than you were at jerking me off, at least.`}[/color]"
                            Swallowing a few bits of precum scrounged from your snout,
                            you coyly reply that you're a natural at [i]worshipping[/i] dragons.
                            Rolande chuckles.
                            "[color=yellow]Well, my little dragon-pleaser, what say we take this to the next level?
                            How about you lift that cute little tail of yours, and we'll have ourselves some [b]real[/b] [i]fun[/i]?[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobEager.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobChoices.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobChoices(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.blowjobAttitude;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new NoonThreeStoreBlowjobReluctant(ctrl);
    var secondNext = new NoonThreeStoreBlowjobEager(ctrl);

    var firstChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var secondChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Reluctant</button>`;

        var tooltip = global.parser.parse(`Do you [i]really[/i] have to do this?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Eager</button>`;

        var tooltip = global.parser.parse(`You can't wait to see how the dragon [b]tastes[/b].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You are:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobChoices.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobMoreMoney.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobMoreMoney(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
    var reqController = ctrl.blowjobMoney;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.blowjobChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var toReturn = `[p]
                            He wants you to suck him off, now does he?
                            You can do that, but it'll cost him.
                            Twenty coins extra.
                            His pleasure is your business, after all.
                            He already got to rub your chest for free.
                            And a mouth like yours doesn't come cheap.
                            To accentuate your statement, you let your long, thin tongue loll out of your mouth.
                            Surely, that alone is worth a measily twenty coins, right?
                        [/p]
                        [p]
                            "[color=yellow][b]More[/b] gold?
                            You're squeezing the coin out of my pockets instead of the cum from my balls.
                            Like I said: natural born whores, you kobolds.
                            For this kind of money, I [i]could[/i] be getting some one-on-one private time with a dragoness.
                            And I can assure you that [b]my[/b] kind is [b]much[/b] better at pleasuring partners than [b]you[/b] are.[/color]"
                        [/p]
                        [p]
                            He drives a hard bargain, but you're the one holding all of the chips here.
                            With your tongue still extended, you drop to your knees, hovering your open mouth mere inches away from his length.
                            You don't see any dragonesses walking around his store.
                            What a shame.
                            Guess he'll have to settle for you.
                            Or you could just use your hands and nothing more, like he asked of you in the first place.
                        [/p]
                        [p]
                            A loud, annoyed sigh.
                            "[color=yellow]Fine.
                            Twenty more.
                            But you better be every bit as good at sucking dick as you claim to be.[/color]"
                            ${hjEager ? `Sounds like a challenge` : `Crude words, for a noble dragon`}.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobMoreMoney.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobAccept.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobAccept(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var reqController = ctrl.blowjobMoney;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.blowjobChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var baseGender = ctrl.misc.baseGender();
        var gender = baseGender === GenderEnum.MALE ? `boy` : `girl`;
        var toReturn = `[p]
                            Fine, but only because ${hjEager ? `he did that thing with his hand` : `you were [i]kind of[/i] rude to him before`}.
                            You're not doing this because you [b]like it[/b] or anything.
                            ${hjEager ? `That's a lie, and you both know it.` : `Far from it, in fact.`}
                        [/p]
                        [p]
                            You drop down to your knees, getting an up-close look at Rolande's [i]exotic[/i] member.
                            More of his ${hjEager ? `arousing` : `not-unpleasant`} scent floods your nostrils.
                            ${hjEager ? `You eagerly sniff the heady air,
                            taking in as much of it as you possibly can` : `You try to turn your head to face away and get some fresh air,
                            but the merchant keeps you in place`}.
                            "[color=yellow]That's a good ${gender}.
                            ${hjEager ? `I knew you couldn't resist` : `Let's not tarry now, you have something to make up for`}.[/color]"
                            ${hjEager ? `From where you're kneeling, it looks like he's the one who can't resist you` : `Douchebag`}.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobAccept.js

// scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobDecline.js

/**
 * Blowjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreBlowjobDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var reqController = ctrl.blowjobMoney;
    var subController = ctrl.blowjobDecline;
    var changeController = ctrl.blowjobDecline;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreBlowjobEnd(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var hjEager = ctrl.handjobAttitude.get() === ctrl.NoonThreeStoreAttitudeChoice.EAGER;
        var toReturn = `[p]
                            Not so fast.
                            Your deal was to lend him a [b]hand[/b], not a [i]mouth[/i].
                            You just want to get the job done, get paid, browse his wares a bit, and then be on your merry way.
                            "[color=yellow]Come on, ${hjEager ? `where did all that eagerness go` : `don't you want to make up for how rude you were`}?[/color]"
                            ${hjEager ? `This is purely [i]business[/i].
                            That doesn't prevent you from being a little enthusiastic about your work,
                            though.` : `You were [i]rude[/i] because he wanted more than he paid for.
                            Perhaps, if he hadn't acted like a [i]prick[/i], you might have been more willing to part your lips.`}
                            "[color=yellow]Not even a few measily licks?[/color]"
                            No, you're afraid you've made your choice.
                            He'll get what he paid for, and nothing more.
                        [/p]
                        [p]
                            Rolande grumbles, his mood soured by your unwillingness to take things a step further.
                            "[color=yellow]Fine, you [b]stupid[/b] kobold.[/color]"
                            The dragon places both of his hands on your shoulders, and roughly [b]forces[/b] you to your knees,
                            your snout mere inches away from his length.
                            You complain, telling him to [b]let go[/b], stating once more that you're [b]not[/b] going to suck him off!
                            "[color=yellow]Who said anything about [i]sucking[/i]?
                            You don't need to be standing to jerk me off.
                            Now get back to it.[/color]"
                        [/p]
                        [p]
                            You defiantly glare up at the dragon.
                            You briefly consider [i]biting[/i] his dick,
                            but he could very well tear out your throat before going down himself.
                            And if he doesn't, the guards sure will.
                            ${hjEager ? `Oh well,
                            at least you get to bask in more of his arousing scent` : `At least his loins smell somewhat [i]good[/i], even up-close`}.
                            Resigning to your fate, you begin to rub Rolande's member once more.
                        [/p]
                        [p]
                            "[color=yellow]That's right, you lowly [b]whore[/b].
                            Know your place: in between my legs.[/color]"
                            You don't give his rambling any attention.
                            He's just trying to get a rise out of you, so he has an [b]excuse[/b] to force his length into your mouth still.
                            But you refuse to give him that satisfaction.
                        [/p]
                        [p]
                            Still, he's not content.
                            The dragon lets out an angry sigh, taking hold of your stroking hand.
                            Much like before, he guides your motions,
                            only instead of slowing you down, this time, he [b]speeds up[/b] your pace,
                            reinforcing your grip, ensuring you're properly [b]pumping[/b] his curved length.
                            "[color=yellow]Why do I always have to do [b]everything[/b] myself if I want it done right?[/color]"
                            You don't humor him with an answer to his rhethorical question.
                        [/p]
                        [p]
                            Rolande lets out an annoyed, yet remotely [i]pleasured[/i] grunt.
                            "[color=yellow]Paint your scales white.[/color]" he mumbles to himself,
                            speeding up your hand, thoroughly jerking himself off using your small, soft palm.
                            His climax is nearing.
                            You can feel his length starting to [b]throb[/b] and [b]pulse[/b].
                            You try to move out of the way, but the shopkeeper holds you in place using his free hand.
                            Then, after a few more full-length strokes, the dragon reaches his end.
                        [/p]
                        [p]
                            You barely manage to close your eyes in time as a first rope of thick, warm draconic spunk splatters across your face.
                            It is quickly followed by a second, a third and even a fourt squirt, your entire visage coated in steamy, heady semen.
                            You catch yourself plotting to open your mouth to [i]taste[/i] the intoxicating, heavily scented mess,
                            but you manage to refrain from giving in to your base desires.
                        [/p]
                        [p]
                            As Rolande's orgasm comes to an end, you wipe some of the goopy mess off of your face, enough for you to open your eyes once more.
                            With his climax, all of his [i]frustration[/i] seems to have faded.
                            He's gloating down at you, staring at you with a shit-eating grin only a man truly [b]full of himself[/b] could produce.
                            "[color=yellow]You looked better with my jizz covering your face.[/color]"
                            Bastard.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\blowjob\NoonThreeStoreBlowjobDecline.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobEndChoices.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobEndChoices(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.blowjobMoney;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new NoonThreeStoreBlowjobDecline(ctrl);
    var secondNext = new NoonThreeStoreBlowjobAccept(ctrl);
    var thirdNext = new NoonThreeStoreBlowjobMoreMoney(ctrl);

    var firstChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var secondChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var thirdChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`You're not degrading yourself further.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`You sense a lucrative opportunity coming up if you play along.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var failedCheck = ctrl.misc.intelligence() < 6 || ctrl.misc.charisma() < 6;
        var disabled = subController.has() || failedCheck ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>More money</button>`;

        var tooltip = global.parser.parse(`For another twenty coins, perhaps?`);
        if (failedCheck) {
            tooltip = ctrl.misc.intelligence() < 6 && ctrl.misc.charisma() < 6 ?
                    `You're not smart or charismatic enough to ask for more money.` : `You're not smart enough to ask for more money.`;
            tooltip = ctrl.misc.charisma() < 6 ?
                    `You're not charismatic enough to ask for more money.` : tooltip;
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_barn");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobEndChoices.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobReluctant.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobReluctant(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var reqController = ctrl.handjobAttitude;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.handjobEndChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.jerked = true;
        var baseGender = ctrl.misc.baseGender();
        var gender = baseGender === GenderEnum.MALE ? `boy` : `girl`;
        var cuntBoy = ctrl.misc.gender() === GenderEnum.CUNTBOY;
        var breasts = ctrl.misc.boobs();
        var shirt = ctrl.misc.shirt();
        var shirtTooltip = global.kobold.inventory.createItemWithTooltip(shirt);
        var bra = ctrl.misc.bra();
        var braTooltip = global.kobold.inventory.createItemWithTooltip(bra);
        var toReturn = `[p]
                            You're in too deep to back out now.
                            Keeping your mind on the money, you reach out for the dragon's cock, and tentatively take it in your hand.
                            It feels [b]warm[/b] against the smooth scales of your palm,
                            his shaft already slick from the lukewarm pre he slathered along his length during his own masturbation.
                            The shopkeeper lets out a relaxed sigh.
                            "[color=yellow]That's a good ${gender}.
                            Now start stroking if you want to earn your pay.[/color]"
                        [/p]
                        [p]
                            Well, you [b]did[/b] sign up for this.
                            Unwillingness plastered all across your face,
                            you slowly begin to move your hand up and down Rolande's member.
                            The meagre stimulation suffices to coax another wave of precum from his internal balls,
                            weighing down the dangling strand of pre enough to make it drop to the ground.
                            As the goopy liquid splatters apart on the wooden floor, the hefty scent of the dragon's sex reaches your nose.
                            You shamefully admit to yourself that it smells better than you imagined it would.
                            No wonder dragons are universally considered attractive creatures, regardless of their gender.
                        [/p]
                        [p]
                            Trying your hardest [i]not[/i] to think of what you're doing, you begin to look around the store.
                            After inspecting a few nick-nacks arrayed on the shelves, your eyes land on the door you walked in through.
                            Then it hits you.
                            The door is still [b]open[/b].
                            Someone could walk in at [b]any[/b] time, to find you whoring yourself out behind the counter.
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            Noticing your lack of attention, Rolande places one of his big hands atop your head,
                            rotating your cranium back towards him, tilting your visage upwards until your eyes meet his.
                            "[color=yellow]Focus, kobold.
                            I'll dock your pay if you do a half-assed job.[/color]"
                            You give him a small, uneasy nod.
                            The moment the merchant lets go of your head,
                            you only barely manage to refrain from glancing at the front door once more,
                            the near-instinctual urge to somewhat preserve your dignity almost too strong to resist.
                        [/p]
                        [p]
                            If you can't keep a lookout for people walking in on you, then that leaves only one option.
                            You need to finish this -- you need to finish [b]him[/b] -- and quick.
                            You reinforce your grasp on the dragon's dick, and up the speed of your stroking, properly [b]milking[/b] his cock with your palm.
                            Rolande lets out a surprised, but pleased grunt.
                            But still, he is not [i]satisfied[/i].
                        [/p]
                        [p]
                            
                            "[color=yellow]Woah, there.
                            Not so fast.
                            For the amount I'm paying you, you can spare a few extra minutes.[/color]"
                            The shopkeeper halts your rapid motions by taking hold of your hand and moving it up and down more [i]gently[/i] a few times.
                            "[color=yellow]Like this.
                            Think you can manage that?[/color]"
                            You let out annoyed whimper, your plan to minimize the chances of you getting seen mid-prostitution ruined.
                            Reluctantly, you match the instructed pace.
                            "[color=yellow]That's better.[/color]"
                            Pompous prick.
                        [/p]`;

        if (shirt || bra) {
            if (breasts) {
                toReturn += `
                        [p]
                            Suddenly, the dragon reaches out for your body,
                            ${shirt && bra ? `opening up your ${shirtTooltip} and pushing your ${braTooltip} below your breasts,
                            exposing them` : shirt ? `opening your ${shirtTooltip}, exposing your breasts` : `pushing your ${braTooltip} below your breasts, exposing them`}.
                            He casually places his palm atop one of your tits.
                            Without even having the [b]decency[/b] to ask, he begins to erotically rub your chest,
                            squeezing and even pinching your mammaries to his heart's desire.
                            Growing distressed, you defiantly tell Rolande that he could have at least [b]asked[/b] you first.
                            "[color=yellow]The vixens at the brothel let me grope, suckle on and even [b]fuck[/b] their rack without a fuss.[/color]"
                            You aren't a vixen, and you don't work at a whorehouse.
                            "[color=yellow][b]I know[/b]. If you were, you wouldn't be [b]complaining[/b].[/color]"
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            Suddenly, the dragon reaches out for your body,
                            ${shirt && bra ? `opening up your ${shirtTooltip} and pushing your ${braTooltip} downwards,
                            exposing your flat chest` : shirt ? `opening your ${shirtTooltip}, exposing your flat chest` : `pushing
                            your ${braTooltip} downwards, exposing more of your flat chest`}.
                            He casually places his palm atop your torso.
                            Without even having the [b]decency[/b] to ask, he begins to erotically rub your body,
                            squeezing your sides and dangerously trailing his sharp claws along your bare, tender belly.
                            Growing distressed, you defiantly tell Rolande that he could have at least [b]asked[/b] you first.
                            "[color=yellow]The vixens at the brothel let me grope, suckle on and even [b]fuck[/b] their tits without a fuss.[/color]"
                            You aren't a vixen, and you don't work at a whorehouse.
                            "[color=yellow][b]I know[/b]. If you were, you wouldn't be [b]complaining[/b].[/color]"
                        [/p]`;
            }
        } else {
            if (breasts) {
                toReturn += `
                        [p]
                            Suddenly, the dragon reaches out for your body, and casually places his palm atop one of your breasts.
                            Without even bothering to ask, he begins to erotically rub your chest,
                            squeezing and even pinching your tits to his heart's desire.
                            Growing distressed, you defiantly tell Rolande that he could have at least [b]asked[/b] you first.
                            "[color=yellow]The vixens at the brothel let me grope, suckle on and even [b]fuck[/b] their rack without a fuss.[/color]"
                            You aren't a vixen, and you don't work at a whorehouse.
                            "[color=yellow][b]I know[/b]. If you were, you wouldn't be [b]complaining[/b].[/color]"
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            Suddenly, the dragon reaches out for your body, and casually places his palm atop your flat chest.
                            Without even bothering to ask, he begins to erotically rub your torso,
                            squeezing your sides and dangerously trailing his sharp claws along your bare, tender belly.
                            Growing distressed, you defiantly tell Rolande that he could have at least [b]asked[/b] you first.
                            "[color=yellow]The vixens at the brothel let me grope, suckle on and even [b]fuck[/b] their tits without a fuss.[/color]"
                            You aren't a vixen, and you don't work at a whorehouse.
                            "[color=yellow][b]I know[/b]. If you were, you wouldn't be [b]complaining[/b].[/color]"
                        [/p]`;
            }
        }

        toReturn += `   [p]
                            You are [b]not[/b] okay with this.
                            You flat-out tell Rolande to [b]stop[/b].
                            He rolls his eyes, retracting his hand after a few more inappropriate touches.
                            "[color=yellow]Have it your way, prude.
                            But cover up your chest again, and I'm not paying you a single coin.[/color]"
                            You let out an angry harrumph, which ends up sounding a lot more [i]cute[/i] than you would have liked.
                        [/p]
                        [p]
                            For a minute or so, you stroke the dragon's dick in silence, both him and you somewhat upset.
                            Breaking the silence comes a disappointed groan from your [i]client[/i].
                            "[color=yellow]Alright, I'm sorry.
                            I should have asked first.
                            But you have to realize that a [b]mediocre[/b] handjob like this isn't nearly enough to [b]get me off[/b].
                            Not after [b]years[/b] of being [i]spoiled[/i] by the ladies at the Golden Fur.
                            I need something [b]more[/b].
                            Something [b]better[/b].[/color]"
                        [/p]
                        [p]
                            Rolande snaps his fingers, seemingly coming up with a good idea.
                            "[color=yellow]Oh, I know!
                            How about you try using your mouth a little?
                            If you're even [b]half[/b] as good at [b]sucking dick[/b] as you are at complaining, I'll reach my end in no time.[/color]"
                            Ugh.
                            You can't stand this guy.
                            Even mid-apology, he somehow finds a way to insult you.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobReluctant.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobEager.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobEager(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;
    var reqController = ctrl.handjobAttitude;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.handjobEndChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.jerked = true;
        global.kobold.history.shared.varanar.dayThree.noon.jerkedEager = true;
        var baseGender = ctrl.misc.baseGender();
        var gender = baseGender === GenderEnum.MALE ? `boy` : `girl`;
        var breasts = ctrl.misc.boobs();
        var shirt = ctrl.misc.shirt();
        var shirtTooltip = global.kobold.inventory.createItemWithTooltip(shirt);
        var bra = ctrl.misc.bra();
        var braTooltip = global.kobold.inventory.createItemWithTooltip(bra);
        var toReturn = `[p]
                            Returning his lustful gaze with a lecherous look of your own,
                            you reach out for the dragon's cock, and firmly grasp it.
                            It feels [b]warm[/b] against the smooth scales of your palm,
                            his shaft already slick from the lukewarm pre he slathered along his length during his own masturbation.
                            The shopkeeper lets out a relaxed sigh.
                            "[color=yellow]That's a good ${gender}.
                            Now start stroking if you want to earn your pay.[/color]"
                        [/p]
                        [p]
                            He doesn't have to ask you twice.
                            Eagerness visible on your face,
                            you begin to move your hand up and down Rolande's member.
                            The stimulation suffices to coax another wave of precum from his internal balls,
                            weighing down the dangling strand of pre enough to make it drop to the ground.
                            As the goopy liquid splatters apart on the wooden floor, the hefty scent of the dragon's sex reaches your nose.
                            It smells even better than you imagined it would.
                            No wonder dragons are universally considered attractive creatures, regardless of their gender.
                        [/p]
                        [p]
                            Audibly sniffing the air to take in more of the wonderful scent, you take a moment to look around the store.
                            Your eyes land on the door you walked in through.
                            Then it hits you.
                            The door is still [b]open[/b].
                            Someone could walk in at [b]any[/b] time, to find you whoring yourself out behind the counter.
                            How [b]exciting[/b]!
                        [/p]
                        [p]
                            The thought of getting [i]caught[/i] arouses you greatly.
                            Turning your attention back towards Rolande, you redouble your efforts,
                            reinforcing your grip on the dragon's dick and speeding up your stroking, properly [b]milking[/b] his cock with your palm.
                            Rolande lets out a surprised, but pleased grunt.
                            But still, he is not [i]satisfied[/i].
                        [/p]
                        [p]
                            
                            "[color=yellow]Woah, there.
                            I like the enthusiasm, but not so fast.
                            For the amount I'm paying you, you can spare a few extra minutes.[/color]"
                            The shopkeeper halts your rapid motions by taking hold of your hand and moving it up and down more [i]gently[/i] a few times.
                            "[color=yellow]Like this.
                            Think you can manage that?[/color]"
                            You let out a begging whine, like an over-eager dog being scolded.
                            Reluctantly, you match the instructed pace.
                            "[color=yellow]That's better.[/color]"
                        [/p]
                        [p]
                            You find something irresistable about the way Rolande [b]controls[/b] you.
                            It feels [b]natural[/b] for you, a kobold, to be ordered around by [b]him[/b], a dragon.
                            Or maybe you're just a little [b]slut[/b] that enjoys getting bossed around by a rather handsome man.
                            Either way, you can feel your own arousal starting to build.
                        [/p]`;

        if (shirt || bra) {
            if (breasts) {
                toReturn += `
                        [p]
                            "[color=yellow]Let's see some more of those pretty scales of yours.[/color]"
                            The dragon reaches out for your body,
                            ${shirt && bra ? `opening up your ${shirtTooltip} and pushing your ${braTooltip} below your breasts,
                            exposing them` : shirt ? `opening your ${shirtTooltip}, exposing your breasts` : `pushing your ${braTooltip} below your breasts, exposing them`}.
                            He casually places his palm atop one of your tits.
                            Without even asking, he begins to erotically rub your chest,
                            squeezing and pinching your mammaries to his heart's desire.
                            You let out a small, heated huff, his caressing the perfect mixture between arousing and exhilarating to push [b]all[/b] of your buttons.
                            "[color=yellow]You like that, don't you?[/color]"
                            You manage a small nod in return.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=yellow]Let's see some more of those pretty scales of yours.[/color]"
                            The dragon reaches out for your body,
                            ${shirt && bra ? `opening up your ${shirtTooltip} and pushing your ${braTooltip} downwards,
                            exposing your flat chest` : shirt ? `opening your ${shirtTooltip}, exposing your flat chest` : `pushing
                            your ${braTooltip} downwards, exposing more of your flat chest`}.
                            He casually places his palm atop your torso.
                            Without even asking, he begins to erotically rub your body,
                            squeezing your sides and dangerously trailing his sharp claws along your bare, tender belly.
                            You let out a small, heated huff, his caressing the perfect mixture between arousing and exhilarating to push [b]all[/b] of your buttons.
                            "[color=yellow]You like that, don't you?[/color]"
                            You manage a small nod in return.
                        [/p]`;
            }
        } else {
            if (breasts) {
                toReturn += `
                        [p]
                            The dragon reaches out for your body, and casually places his palm atop one of your breasts.
                            Without even asking, he begins to erotically rub your chest,
                            squeezing and pinching your tits to his heart's desire.
                            You let out a small, heated huff, his caressing the perfect mixture between arousing and exhilarating to push [b]all[/b] of your buttons.
                            "[color=yellow]You like that, don't you?[/color]"
                            You manage a small nod in return.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            The dragon reaches out for your body, and casually places his palm atop your flat chest.
                            Without even asking, he begins to erotically rub your torso,
                            squeezing your sides and dangerously trailing his sharp claws along your bare, tender belly.
                            You let out a small, heated huff, his caressing the perfect mixture between arousing and exhilarating to push [b]all[/b] of your buttons.
                            "[color=yellow]You like that, don't you?[/color]"
                            You manage a small nod in return.
                        [/p]`;
            }
        }

        toReturn += `   [p]
                            After another minute or so of wantonly exploring your body,
                            the shopkeeper retracts his hand once more.
                            You look up at him, wordlessly begging him for [b]more[/b] of his tender touching.
                            He shoots you a coy smile.
                            "[color=yellow]How about you try using your mouth a little?
                            If your tongue is half as good as your fingers are,
                            then you'll be walking out of here with your payment in no time at all.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobEager.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobChoices.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobChoices(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.handjobAttitude;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new NoonThreeStoreHandjobReluctant(ctrl);
    var secondNext = new NoonThreeStoreHandjobEager(ctrl);

    var firstChoice = ctrl.NoonThreeStoreAttitudeChoice.RELUCTANT;
    var secondChoice = ctrl.NoonThreeStoreAttitudeChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Reluctant</button>`;

        var tooltip = global.parser.parse(`Ugh. Stuck up dragon. Let's just get this over with.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 183px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Eager</button>`;

        var tooltip = global.parser.parse(`Put some heart into your efforts. The dragon [i]is[/i] paying you, after all.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You are:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobChoices.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobMoreMoney.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobMoreMoney(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;
    var reqController = ctrl.proposal;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.handjobChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            While you dislike the dragon's demeaning attitude,
                            you won't deny that you [b]could[/b] use some extra coin.
                            Thirty isn't nearly enough, though.
                            What does Rolande expect, you to sell your dignity for the less than the price of a decent weapon?
                            Fifty.
                            If he wants you to rub his dick, then you want [b]fifty[/b] coins.
                        [/p]
                        [p]
                            The dragon rolls his eyes, as though weary from half a day of haggling with customers.
                            "[color=yellow]Fiiiiine.
                            [b]Fifty[/b] coins.
                            Just get your ass behind the counter already.[/color]"
                            Wait, really?
                            He [b]accepts[/b] your offer?
                            You'd imagined he'd barter you down to [b]thirty-five[/b], maybe [b]forty[/b] if you were lucky.
                            The shopkeeper must [b]really[/b] want this.
                            Your profit almost doubled, you comply with his order, stepping behind the counter.
                        [/p]
                        [p]
                            As you expected, the dragon was jerking himself off, his decent-sized member fully erect, his pants on the ground at his feet.
                            A considerable amount of precum oozes from the merchant-side of the counter,
                            a thick string of the stuff dangling off the tapered tip of Rolande's cock still.
                            His dick [i]kind of[/i] resembles ${dick ? `your own cock,
                            ${dick > SizeEnum.LARGE ? `only a little [i]smaller[/i]` : dick > SizeEnum.SMALL ? `in size and
                            in shape` : `but a bit bigger in size`}` : `the cocks of males of your own kind, only bigger`}.
                            It differs both in color and in shape.
                            It's grey, a slightly lighter tone than the dragon's scales, and it has an exotic-looking [i]curve[/i] to it, like a [b]sabre[/b] compared to 
                            ${dick ? `your ${dick > SizeEnum.LARGE ? `[b]zweihander[/b]` : dick > SizeEnum.SMALL ? `broadsword` : `[i]dagger[/i]`}` : `the
                            shortswords of kobolds`}.
                        [/p]
                        [p]
                            You've heard that dragon dicks vary wildly from person to person,
                            but standing in front of the aroused shopkeeper, you're [i]hesitant[/i] to ask.
                            He isn't paying you to [i]chat[/i].
                            As you get closer to him, the merchant rotates on his large wooden stool,
                            coming to face you proper, eager anticipation clear in his eyes, a smug grin on his face.
                            "[color=yellow]You've made a wise choice, kobold.
                            Deep down inside, [b]all[/b] of you are prostitutes.
                            Whether I pay you a lot, or a little, makes no difference.
                            There's no shame in it, that's just what you are.
                            Us dragons are natural-born patricians and aristocrats,
                            you little ones are [b]vagrants[/b] and [b]whores[/b].[/color]"
                        [/p]
                        [p]
                            You bite your tongue and bear Rolande's insults.
                            In a way, he isn't [i]wrong[/i], but it still hurts to hear.
                            It's almost as though he's [b]enjoying[/b] putting you down.
                            His draconic member twitches in excitement, the hefty rope of precum that's dangling from the tip visibly growing a little bit longer.
                            That thing is [b]long[/b] overdue for a one-way trip to the floor.
                            "[color=yellow]Come now, my little [b]whore[/b].
                            Don't keep me waiting.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobMoreMoney.js

// scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobAccept.js

/**
 * Handjob section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreHandjobAccept(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var reqController = ctrl.proposal;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.handjobChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            While you dislike the dragon's demeaning attitude,
                            you won't deny that you [b]could[/b] use some extra coin.
                            You sigh, roll your eyes, mumble something about kobolds [b]not[/b] being [i]whores[/i],
                            and then immediately prove yourself a hypocrite by silently stepping behind the counter, wordlessly agreeing to the storekeeper's offer.
                        [/p]
                        [p]
                            As you expected, the dragon was jerking himself off, his decent-sized member fully erect, his pants on the ground at his feet.
                            A considerable amount of precum oozes from the merchant-side of the counter,
                            a thick string of the stuff dangling off the tapered tip of Rolande's cock still.
                            His dick [i]kind of[/i] resembles ${dick ? `your own cock,
                            ${dick > SizeEnum.LARGE ? `only a little [i]smaller[/i]` : dick > SizeEnum.SMALL ? `in size and
                            in shape` : `but a bit bigger in size`}` : `the cocks of males of your own kind, only bigger`}.
                            It differs both in color and in shape.
                            It's grey, a slightly lighter tone than the dragon's scales, and it has an exotic-looking [i]curve[/i] to it, like a [b]sabre[/b] compared to 
                            ${dick ? `your ${dick > SizeEnum.LARGE ? `[b]zweihander[/b]` : dick > SizeEnum.SMALL ? `broadsword` : `[i]dagger[/i]`}` : `the
                            shortswords of kobolds`}.
                        [/p]
                        [p]
                            You've heard that dragon dicks vary wildly from person to person,
                            but standing in front of the aroused shopkeeper, you're [i]hesitant[/i] to ask.
                            He isn't paying you to [i]chat[/i].
                            As you get closer to him, the merchant rotates on his large wooden stool,
                            coming to face you proper, eager anticipation clear in his eyes, a smug grin on his face.
                            "[color=yellow]You've made a wise choice, kobold.
                            Deep down inside, [b]all[/b] of you are prostitutes.
                            There's no shame in it, that's just what you are.
                            Us dragons are natural-born patricians and aristocrats,
                            you little ones are [b]vagrants[/b] and [b]whores[/b].[/color]"
                        [/p]
                        [p]
                            You bite your tongue and bear Rolande's insults.
                            In a way, he isn't [i]wrong[/i], but it still hurts to hear.
                            It's almost as though he's [b]enjoying[/b] putting you down.
                            His draconic member twitches in excitement, the hefty rope of precum that's dangling from the tip visibly growing a little bit longer.
                            That thing is [b]long[/b] overdue for a one-way trip to the floor.
                            "[color=yellow]Come now, my little [b]whore[/b].
                            Don't keep me waiting.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\handjob\NoonThreeStoreHandjobAccept.js

// scenes\Varanar\DayThree\NoonThreeStore\decline\NoonThreeStoreDecline.js

/**
 * Arrival section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var reqController = ctrl.proposal;
    var subController = ctrl.preStore;
    var changeController = ctrl.decline;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.store;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            This pompous jerk really thinks he can persuade you to jerk him off by offering you a few coins in return?
                            No way.
                            You don't want any part of this.
                            The brothel district isn't too far away.
                            If he really wants a handjob, he can always make his way over there.
                        [/p]
                        [p]
                            "[color=yellow]Out of all the kobolds in the world, the one that [b]isn't[/b] a total [b]slut[/b] had to walk into my store.[/color]"
                            The dragon sighs.
                            "[color=yellow]Fine.
                            Suit yourself, you prude.
                            But don't think I'm going to stop doing what I was doing just because you're here now.
                            If you don't like it, then you take your lousy business elsewhere.[/color]"
                            Those harsh words said, Rolande openly resumes his masturbation, eyeing you lustfully,
                            clearly picturing you in all kinds of perverse situations.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\decline\NoonThreeStoreDecline.js

// scenes\Varanar\DayThree\NoonThreeStore\arrival\NoonThreeStoreProposal.js

/**
 * Serve section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreProposal(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.arrival;
    var subController = ctrl.proposal;
    var changeController = ctrl.proposal;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new NoonThreeStoreDecline(ctrl);
    var secondNext = new NoonThreeStoreHandjobAccept(ctrl);
    var thirdNext = new NoonThreeStoreHandjobMoreMoney(ctrl);

    var firstChoice = ctrl.NoonThreeStoreMoneyChoice.DECLINE;
    var secondChoice = ctrl.NoonThreeStoreMoneyChoice.ACCEPT;
    var thirdChoice = ctrl.NoonThreeStoreMoneyChoice.MOREMONEY;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var sekiMet = global.kobold.history.shared.seki.knowsDying;
        var naked = ctrl.misc.importantNude();
        var crossdressing = ctrl.misc.crossdressing();
        var oppositeGender = ctrl.misc.baseGender() === GenderEnum.MALE ? `girly` : `boyish`;
        oppositeGender = ctrl.misc.gender() === GenderEnum.CUNTBOY ? `boyish` : oppositeGender;
        var toReturn = `[p]
                            You've never really [i]been[/i] in a [i]real[/i] store before.
                            Your few visits to your ${sekiMet ? `` : `fatherly friend and fence`} Seki's ${sekiMet ? `` : `alchemical`} workshop,
                            to pawn off your meagre thieving pickings, don't count.
                            It's kind of [b]exciting[/b] to finally get to see the insides of a Varanarian shop.
                            Although you don't quite know what to expect, you push open the door, and step inside.
                        [/p]
                        [p]
                            You enter a rather large room, filled to the brim with a wide variety of goods.
                            Various tables, racks, display cases and opened chests showcase the store's wares.
                            At the opposite end of the room, behind a wide counter, there sits a grey-scaled anthromorphic dragon.
                            At least you [i]think[/i] he's sitting, unless he's as tiny as you are somehow.
                            You presume that's [i]Rolande[/i].
                            Besides him, the shop appears to be empty.
                        [/p]
                        [p]
                            At first, the dragon doesn't even [b]notice[/b] you.
                            He's leaning back on his stool, his eyes closed,
                            one of his arms disappearing underneath the counter,
                            slightly moving up and down in a slow, rhythmical fashion.
                            You believe you've walked in on a shopkeeper jerking off on the job.
                        [/p]
                        [p]
                            Starting to feel [b]very[/b] awkward, you consider turning around and [b]leaving[/b] before the masturbating man notices you.
                            Then again, you're not at fault here.
                            He's running a store, which is currently open for business.
                            He shouldn't be rubbing one out without at least locking the door first!
                            If anything, [b]you[/b] should feel outraged that he has the [b]audacity[/b] to openly stroke himself in the middle of the day!
                            But, being a kobold, you don't [i]get[/i] to complain about things like these.
                            You should be happy you're allowed to enter stores in the first place.
                        [/p]
                        [p]
                            In order to grab the merchant's attention, you loudly slam the door shut behind you.
                            The dragon's eyes shoot open, he lets out a surprised sigh, and his jerking hand shoots upwards from his lap onto the counter.
                            "[color=yellow]Ah, a customer![/color]" he greets you warmly, wiping his palm on a nearby rag.
                            Only [b]now[/b] actually [i]looking[/i] at you, the initial enthusiasm fades from his voice.
                            "[color=yellow]Oh.
                            A [b]kobold[/b].
                            What do [i]you[/i] want?[/color]"
                        [/p]
                        [p]
                            Walking up to the counter, you explain that you're here to [i]buy[/i] things.
                            He [i]is[/i] running a [b]store[/b], right?
                            "[color=yellow]I don't think someone of [i]your[/i] kind has the [i]means[/i] to purchase wares from my [i]establishment[/i].[/color]"
                            The shopkeep eyes you up and down.
                            "[color=yellow]${naked ? `Your lack of clothing isn't` : `Those rags you call [i]clothing[/i] aren't`} helping your case.[/color]"
                            ${crossdressing ? `And what's that ${oppositeGender} thing you're wearing?` : ``}
                        [/p]
                        [p]
                            You struggle to form a counterargument while the dragon continues to eye you up and down.
                            He lustily licks his lips, one of his hands slinking underneath the counter once more.
                            "[color=yellow]But now that you [i]are[/i] here, I might as well make you an [i]offer[/i].[/color]"
                            His arm begins to move up and down once more, the man clearly jerking off right in front of you.
                            "[color=yellow]As you might have noticed, I have a little [i]problem[/i].
                            Help me out with it, and I'll make it worth your while.[/color]"
                        [/p]
                        [p]
                            His intentions revealed, the draconian merchant no longer attempts to hide his masturbation,
                            his hand audibly sliding up and down his length.
                            "[color=yellow]So, what'll it be, kobold?
                            Just a [i]hand[/i], that's all I ask for.
                            Thirty coins, enough to buy at least [b]one[/b] item from my store.
                            Plus I'll throw in a little [i]discount[/i].
                            Far more than a little [b]whore[/b] like you is worth, don't you think?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`Hell no. You just want to browse his wares. He can continue doing whatever it is he was doing afterwards.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`You [i]could[/i] use the money. What's the worst that could happen?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var failedCheck = ctrl.misc.intelligence() < 6 && ctrl.misc.charisma() < 6;
        var disabled = subController.has() || failedCheck ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>More money</button>`;

        var tooltip = global.parser.parse(`It's not enough. Maybe if the dragon adds another twenty coins, you'll consider [i]touching[/i] him.`);
        if (failedCheck) {
            tooltip = global.parser.parse(`You're not smart or charismatic enough to ask for more money.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 240px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_barn");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\arrival\NoonThreeStoreProposal.js

// scenes\Varanar\DayThree\NoonThreeStore\arrival\NoonThreeStoreArrival.js

/**
 * Arrival section of Varanar, Noon Three.
 * @param {NoonThreeStoreController} controller The Varanar, Noon Three controller.
 */
function NoonThreeStoreArrival(controller) {
// PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;
    var autoContinue = false;
    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NoonThreeStoreProposal(ctrl);
    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        // Log to prevent early overwriting
        ctrl.misc.oralVirgin();
        ctrl.misc.analVirgin();
        ctrl.misc.cuntVirgin();
        ctrl.misc.weapon();
        
        var stole = global.kobold.history.shared.varanar.dayThree.noon.stole;
        var gaveHouse = global.kobold.history.shared.varanar.dayThree.noon.gaveHouse;
        var comforted = global.kobold.history.shared.varanar.dayThree.noon.comforted;
        var donated = global.kobold.history.shared.varanar.dayThree.noon.donated;

        var toReturn = ``;
        if (stole) {
            toReturn += `[p]
                            For the better part of an hour, you conceal yourself within the droves of people crowding the grand avenue,
                            blending in as best you can, trying to look like an [i]ordinary[/i] window-shopping kobold and [b]not[/b] a thief on the run.
                            As time goes by, your deceit slowly turns to reality, your wariness about being [i]caught[/i] fading,
                            replaced by a genuine curiosity in the stores you're admiring.
                        [/p]`;
        } else {
            toReturn += `[p]`;
            if (gaveHouse || donated) {
                toReturn += `A good deed done, you head for the grand avenue.`;
            } else if (comforted) {
                toReturn += `With the sheep [i]comforted[/i], you head for the grand avenue.`;
            } else {
                toReturn += `Your [i]dinner[/i] eaten, you head for the grand avenue.`;
            }
            toReturn += `   While the droves of people crowding the streets make navigating a bit hard for someone of your [i]size[/i],
                            you manage to avoid getting [i]trampled[/i] by sticking close to the edges of the road, away from most of the bustling traffic.
                        [/p]`;
        }

        toReturn += `   [p]
                            Bakeries with pastries, sweet tarts and more bread than you've ever [b]seen[/b] assembled in one place.
                            Butcher shops with more meat on display than you have on your bones.
                            Weapon stores stalling swords and axes and maces taller than you are.
                            Armor smithies displaying full sets of plate that could fit you twice and more.
                        [/p]
                        [p]
                            Beautiful, imposing, alluring sights, to say the least.
                            Alas, most of the things you see are [i]out of reach[/i].
                            You have no way of being able to actually [i]afford[/i] a lot of this stuff.
                            Aside from [i]stealing[/i] or being [i]awarded[/i] a set, you'll [b]never[/b] know what it feels like to own plate armor.
                            And good luck trying to steal something that weighs more than you do.
                            Besides, you doubt kobold-sized suits of armor even [i]exist[/i].
                        [/p]
                        [p]
                            After browsing the various shops for a good bit,
                            you come to a halt in front of a place that looks a bit more [i]affordable[/i].
                            A general store, by the name of [b]Rolande's Wares and Tears[/b],
                            according to a small sign hanging off a wooden beam above the door.
                            From what you can see through the window, this place appears to stock a large array of things,
                            from daily necessities to travelling gear and even a wide selection of potions!
                            ${ctrl.misc.gold() ? `Surely, you'll be able to at least afford a string of rope
                            or something` : `Even [i]if[/i] you have no money, there's no harm in taking a look inside`}, right?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;
    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        global.ui.applyTheme("varanar_generic");
        ctrl.bgm.loop();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();
        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Varanar\DayThree\NoonThreeStore\arrival\NoonThreeStoreArrival.js

// scenes\Varanar\DayThree\NoonThreeStore\NoonThreeStoreController.js

/**
 * Controller for the Varanar, Noon Three scene.
 * @param {string} sceneId The id of the scene.
 */
function NoonThreeStoreController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Controller for the store.
     * @param {string} key The key to use for the store.
     */
    function BuyController(key) {
        var that = this;
        ContinueController.call(this, id, key);

        var shopItemKey = key + "Items";
        var shopGoldKey = key + "Gold";
        var initialShopItems = [
            new ItemAmount(1, new HalfScythe()),
            new ItemAmount(1, new Mace()),
            new ItemAmount(1, new ShortSword()),
            new ItemAmount(1, new GreatSword()),
            new ItemAmount(1, new LinenShirt()),
            new ItemAmount(1, new LinenPants()),
            new ItemAmount(1, new HatScarf()),
            new ItemAmount(1, new KoboldSocks()),
            new ItemAmount(1, new WoodenSandals()),
            new ItemAmount(1, new Rope()),
            new ItemAmount(1, new SmallMirror()),
            new ItemAmount(2, new Lockpick()),
            new ItemAmount(2, new BeefUp()),
            new ItemAmount(2, new LiquidLuck()),
            new ItemAmount(2, new MassRedu()),
            new ItemAmount(2, new EnduGain()),
            new ItemAmount(2, new CouragePotion()),
            new ItemAmount(1, new IntelligencePotion()),
            new ItemAmount(1, new FemPlus()),
            new ItemAmount(1, new mPlus()),
            new ItemAmount(1, new mTo()),
            new ItemAmount(1, new FemTo()),
            new ItemAmount(2, new Plum()),
            new ItemAmount(3, new Carrot()),
            new ItemAmount(1, new Fish()),
            new ItemAmount(1, new Apple())
        ];

        var sellModKey = key + "SellMod";
        var initialSellMod = 0.4;
        var buyModKey = key + "BuyMod";
        var initialBuyMod = 1.2;

        /**
         * Gets the current sell mod from history.
         * @returns {number} The sell mod.
         */
        function getSellMod() {
            global.kobold.history.setIfNotSet(id, sellModKey, initialSellMod);
            return global.kobold.history.getKey(id, sellModKey);
        }

        /**
         * Alters the sell mod.
         * @param {number} amount The amount to increase or decrease the sellmod with.
         */
        this.alterSellMod = function (amount) {
            var currentSellMod = getSellMod();
            currentSellMod += amount;
            global.kobold.history.setKey(id, sellModKey, currentSellMod);
        };

        /**
         * Gets the current buy mod from history.
         * @returns {number} The buy mod.
         */
        function getBuyMod() {
            global.kobold.history.setIfNotSet(id, buyModKey, initialBuyMod);
            return global.kobold.history.getKey(id, buyModKey);
        }

        /**
         * Alters the buy mod.
         * @param {number} amount The amount to increase or decrease the buymod with.
         */
        this.alterBuyMod = function (amount) {
            var currentBuyMod = getBuyMod();
            currentBuyMod += amount;
            global.kobold.history.setKey(id, buyModKey, currentBuyMod);
        };

        function sellListener(item) {
            var itemAmounts = that.shopItems();
            var added = false;
            for (var i = 0; i < itemAmounts.length && !added; i++) {
                if (itemAmounts[i].item.id === item.id) {
                    itemAmounts[i].amount++;
                    added = true;
                }
            }
            if (!added) {
                itemAmounts.push(new ItemAmount(1, item));
            }
            that.updateCoins();
            that.updateShopItems(itemAmounts);
        }

        function buyListener(location) {
            var oldCoins = that.coins();
            that.updateCoins();
            var newCoins = that.coins();
            var itemAmounts = that.shopItems();
            itemAmounts[location].amount--;
            that.updateShopItems(itemAmounts);
            global.kobold.history.shared.varanar.dayThree.noon.moneySpent += oldCoins - newCoins;
        }

        this.getGenerator = function () {
            return new MerchantInventoryGenerator("RolandeStore", that.shopItems(), that.coins(), getSellMod(), getBuyMod(), that.continued(), sellListener, buyListener);
        };
        this.coins = function () {
            global.kobold.history.setIfNotSet(id, shopGoldKey, global.kobold.inventory.coins);
            return global.kobold.history.getKey(id, shopGoldKey);
        };
        this.updateCoins = function () {
            global.kobold.history.setKey(id, shopGoldKey, global.kobold.inventory.coins);
        };
        this.shopItems = function () {
            global.kobold.history.setIfNotSet(id, shopItemKey, initialShopItems);
            var jsonItems = global.kobold.history.getKey(id, shopItemKey);
            var items = global.kobold.inventory.constructItemAmountListFromMemory(jsonItems);
            return items;
        };
        this.updateShopItems = function (newItems) {
            global.kobold.history.setKey(id, shopItemKey, newItems);
        };
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = true;
    this.nextSceneName = "AfternoonThree";
    this.nextFolderName = "Varanar/DayThree";

    this.misc = new MiscController(id, "misc");
    this.postShopMisc = new MiscController(id, "postShopMisc");

    this.arrival = new ContinueController(id, "arrival");

    this.proposal = new ChangeController(id, "proposal", function () {
        global.kobold.status.mental.decrease(5, "Indecent proposal");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Indecent proposal", "Sanity", -5)
        ]);
    });

    this.decline = new ChangeController(id, "decline", function () {
        global.kobold.status.mental.increase(8, "Moral highground");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Moral highground", "Sanity", +8)
        ]);
    });

    this.handjobAttitude = new ChoiceController(id, "handjobAttitude");
    this.blowjobMoney = new ChoiceController(id, "blowjobMoney");
    this.blowjobAttitude = new ChoiceController(id, "blowjobAttitude");

    this.blowjobDecline = new ChangeController(id, "blowjobDecline", function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        global.kobold.status.mental.decrease(5, "Prostitution");
        if (hjEager) {
            global.kobold.status.mental.increase(2, "Enjoyable handjob");
        } else {
            global.kobold.status.mental.decrease(2, "Frustrating handjob");
        }
        global.kobold.status.mental.decrease(5, "Degrading facial");
        global.kobold.status.stamina.decrease(4, "Handjob");
        global.kobold.status.exertion.increase(5, "Handjob");
        global.kobold.status.exertion.increase(4, "Forced facial");
    }, function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var changes = [
            new Change("Prostitution", "Sanity", -5)
        ];
        if (hjEager) {
            changes.push(new Change("Enjoyable handjob", "Sanity", +2));
        } else {
            changes.push(new Change("Frustrating handjob", "Sanity", -2));
        }
        changes.push(new Change("Degrading facial", "Sanity", -5));
        changes.push(new Change("Handjob", "Stamina", -4));
        changes.push(new Change("Handjob", "Sexual exhaustion", +5, true));
        changes.push(new Change("Forced facial", "Sexual exhaustion", +4, true));
        return global.ui.change.buildNotification(changes);
    });

    this.blowjobEnd = new ChangeController(id, "blowjobEnd", function () {
        var paid = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY ? 50 : 30;
        var eager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        if (eager) {
            that.store.alterBuyMod(-0.1);
            that.store.alterSellMod(+0.1);
        } else {
            that.store.alterBuyMod(-0.05);
            that.store.alterSellMod(+0.05);
        }
        global.kobold.inventory.coins += paid;
        global.kobold.history.shared.varanar.dayThree.noon.moneyReceived = paid;
        global.kobold.status.mental.increase(10, "Prostitution payment");
    }, function () {
        var paid = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY ? 50 : 30;
        return global.ui.change.buildNotification([
            new Change("Payday", "Sanity", +10),
            new Change("Paid", "Coins", +paid)
        ]);
    });

    this.sexMoney = new ChoiceController(id, "sexMoney");
    this.sexAttitude = new ChoiceController(id, "sexAttitude");

    this.sexDecline = new ChangeController(id, "sexDecline", function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        global.kobold.status.physical.decrease(4, "Suffocation");
        global.kobold.status.mental.decrease(5, "Prostitution");
        if (hjEager) {
            global.kobold.status.mental.increase(2, "Enjoyable handjob");
        } else {
            global.kobold.status.mental.decrease(2, "Frustrating handjob");
        }
        if (bjEager) {
            global.kobold.status.mental.increase(2, "Arousing blowjob");
        } else {
            global.kobold.status.mental.decrease(2, "Reluctant blowjob");
        }
        global.kobold.status.mental.decrease(5, "Suffocating deepthroating");
        global.kobold.status.stamina.decrease(4, "Handjob");
        global.kobold.status.stamina.decrease(6, "Blowjob");
        global.kobold.status.stamina.decrease(4, "Suffocation");
        global.kobold.status.exertion.increase(5, "Handjob");
        global.kobold.status.exertion.increase(10, "Blowjob");
        global.kobold.status.exertion.increase(5, "Suffocating deepthroating");
        global.kobold.body.oralVirgin = false;
    }, function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var changes = [
            new Change("Suffocation", "Health", -4),
            new Change("Prostitution", "Sanity", -5)
        ];
        if (hjEager) {
            changes.push(new Change("Enjoyable handjob", "Sanity", +2));
        } else {
            changes.push(new Change("Frustrating handjob", "Sanity", -2));
        }
        if (bjEager) {
            changes.push(new Change("Arousing blowjob", "Sanity", +2));
        } else {
            changes.push(new Change("Reluctant blowjob", "Sanity", -2));
        }
        changes.push(new Change("Suffocating deepthroating", "Sanity", -5));
        changes.push(new Change("Handjob", "Stamina", -4));
        changes.push(new Change("Blowjob", "Stamina", -6));
        changes.push(new Change("Suffocation", "Stamina", -4));
        changes.push(new Change("Handjob", "Sexual exhaustion", +5, true));
        changes.push(new Change("Blowjob", "Sexual exhaustion", +10, true));
        changes.push(new Change("Suffocating deepthroating", "Sexual exhaustion", +5, true));
        return global.ui.change.buildNotification(changes);
    });

    this.sexEnd = new ChangeController(id, "sexEnd", function () {
        var paid = 30;
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = that.blowjobMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        if (hjMoney) {
            paid += 20;
        }
        if (bjMoney) {
            paid += 20;
        }
        if (hjEager && bjEager) {
            that.store.alterBuyMod(-0.15);
            that.store.alterSellMod(+0.15);
        } else if (hjEager || bjEager) {
            that.store.alterBuyMod(-0.1);
            that.store.alterSellMod(+0.1);
        } else {
            that.store.alterBuyMod(-0.05);
            that.store.alterSellMod(+0.05);
        }
        global.kobold.inventory.coins += paid;
        global.kobold.history.shared.varanar.dayThree.noon.moneyReceived = paid;
        global.kobold.status.mental.increase(10, "Prostitution payment");
    }, function () {
        var paid = 30;
        var hjMoney = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjMoney = that.blowjobMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        if (hjMoney) {
            paid += 20;
        }
        if (bjMoney) {
            paid += 20;
        }
        return global.ui.change.buildNotification([
            new Change("Payday", "Sanity", +10),
            new Change("Paid", "Coins", +paid)
        ]);
    });

    this.sexReluctant = new ChangeController(id, "sexReluctant", function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        global.kobold.status.physical.decrease(6, "Stretched and scorched");
        global.kobold.status.mental.decrease(5, "Prostitution");
        if (hjEager) {
            global.kobold.status.mental.increase(2, "Enjoyable handjob");
        } else {
            global.kobold.status.mental.decrease(2, "Frustrating handjob");
        }
        if (bjEager) {
            global.kobold.status.mental.increase(2, "Arousing blowjob");
        } else {
            global.kobold.status.mental.decrease(2, "Reluctant blowjob");
        }
        global.kobold.status.mental.decrease(10, "Unwilling sex");
        global.kobold.status.stamina.decrease(4, "Handjob");
        global.kobold.status.stamina.decrease(6, "Blowjob");
        global.kobold.status.stamina.decrease(5, "Screaming for help");
        global.kobold.status.exertion.increase(5, "Handjob");
        global.kobold.status.exertion.increase(10, "Blowjob");
        global.kobold.status.exertion.increase(20, "Unwilling sex");
        global.kobold.body.oralVirgin = false;
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.analVirgin = false;
        }
    }, function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var changes = [
            new Change("Stretched", "Health", -3),
            new Change("Scorched", "Health", -3),
            new Change("Prostitution", "Sanity", -5)
        ];
        if (hjEager) {
            changes.push(new Change("Enjoyable handjob", "Sanity", +2));
        } else {
            changes.push(new Change("Frustrating handjob", "Sanity", -2));
        }
        if (bjEager) {
            changes.push(new Change("Arousing blowjob", "Sanity", +2));
        } else {
            changes.push(new Change("Reluctant blowjob", "Sanity", -2));
        }
        changes.push(new Change("Unwilling sex", "Sanity", -10));
        changes.push(new Change("Handjob", "Stamina", -4));
        changes.push(new Change("Blowjob", "Stamina", -6));
        changes.push(new Change("Screaming for help", "Stamina", -5));
        changes.push(new Change("Handjob", "Sexual exhaustion", +5, true));
        changes.push(new Change("Blowjob", "Sexual exhaustion", +10, true));
        changes.push(new Change("Unwilling sex", "Sexual exhaustion", +20, true));
        return global.ui.change.buildNotification(changes);
    });

    this.sexEager = new ChangeController(id, "sexEager", function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        global.kobold.status.physical.decrease(6, "Stretched and scorched");
        global.kobold.status.mental.decrease(5, "Prostitution");
        if (hjEager) {
            global.kobold.status.mental.increase(2, "Enjoyable handjob");
        } else {
            global.kobold.status.mental.decrease(2, "Frustrating handjob");
        }
        if (bjEager) {
            global.kobold.status.mental.increase(2, "Arousing blowjob");
        } else {
            global.kobold.status.mental.decrease(2, "Reluctant blowjob");
        }
        global.kobold.status.mental.increase(15, "Heavenly fucking");
        global.kobold.status.stamina.decrease(4, "Handjob");
        global.kobold.status.stamina.decrease(6, "Blowjob");
        global.kobold.status.stamina.decrease(3, "Riding cock");
        global.kobold.status.stamina.decrease(2, "Screaming for more");
        global.kobold.status.exertion.increase(5, "Handjob");
        global.kobold.status.exertion.increase(10, "Blowjob");
        global.kobold.status.exertion.increase(20, "Incredible sex");
        global.kobold.body.oralVirgin = false;
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.analVirgin = false;
        }
    }, function () {
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var changes = [
            new Change("Stretched", "Health", -3),
            new Change("Scorched", "Health", -3),
            new Change("Prostitution", "Sanity", -5)
        ];
        if (hjEager) {
            changes.push(new Change("Enjoyable handjob", "Sanity", +2));
        } else {
            changes.push(new Change("Frustrating handjob", "Sanity", -2));
        }
        if (bjEager) {
            changes.push(new Change("Arousing blowjob", "Sanity", +2));
        } else {
            changes.push(new Change("Reluctant blowjob", "Sanity", -2));
        }
        changes.push(new Change("Heavenly fucking", "Sanity", +15));
        changes.push(new Change("Handjob", "Stamina", -4));
        changes.push(new Change("Blowjob", "Stamina", -6));
        changes.push(new Change("Riding cock", "Stamina", -3));
        changes.push(new Change("Screaming for more", "Stamina", -2));
        changes.push(new Change("Handjob", "Sexual exhaustion", +5, true));
        changes.push(new Change("Blowjob", "Sexual exhaustion", +10, true));
        changes.push(new Change("Incredible sex", "Sexual exhaustion", +20, true));
        return global.ui.change.buildNotification(changes);
    });

    this.sexFinale = new ChangeController(id, "sexFinale", function () {
        var paid = 30;
        var hjEager = that.handjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var hjMoney = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjEager = that.blowjobAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var bjMoney = that.blowjobMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexEager = that.sexAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        var sexMoney = that.sexMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        if (hjMoney) {
            paid += 20;
        }
        if (bjMoney) {
            paid += 20;
        }
        if (sexMoney) {
            paid += 30;
        }
        if (hjEager) {
            that.store.alterBuyMod(-0.05);
            that.store.alterSellMod(+0.05);
        }
        if (bjEager) {
            that.store.alterBuyMod(-0.05);
            that.store.alterSellMod(+0.05);
        }
        if (sexEager) {
            that.store.alterBuyMod(-0.05);
            that.store.alterSellMod(+0.05);
        }
        that.store.alterBuyMod(-0.05);
        that.store.alterSellMod(+0.05);
        global.kobold.inventory.coins += paid;
        global.kobold.history.shared.varanar.dayThree.noon.moneyReceived = paid;
        global.kobold.status.physical.increase(2, "Soothing spunk");
        if (sexEager) {
            global.kobold.status.mental.decrease(4, "Didn't get to cum");
        }
        global.kobold.status.mental.increase(10, "Prostitution payment");
    }, function () {
        var paid = 30;
        var hjMoney = that.proposal.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var bjMoney = that.blowjobMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexMoney = that.sexMoney.get() === that.NoonThreeStoreMoneyChoice.MOREMONEY;
        var sexEager = that.sexAttitude.get() === that.NoonThreeStoreAttitudeChoice.EAGER;
        if (hjMoney) {
            paid += 20;
        }
        if (bjMoney) {
            paid += 20;
        }
        if (sexMoney) {
            paid += 30;
        }
        if (sexEager) {
            return global.ui.change.buildNotification([
                new Change("Soothing spunk", "Health", +2),
                new Change("Didn't get to cum", "Sanity", -4),
                new Change("Payday", "Sanity", +10),
                new Change("Paid", "Coins", +paid)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Soothing spunk", "Health", +2),
                new Change("Payday", "Sanity", +10),
                new Change("Paid", "Coins", +paid)
            ]);
        }
    });

    this.return = new ChangeController(id, "return", function () {
        global.kobold.inventory.coins += 50;
        var weapon = that.misc.weapon();
        if (weapon) {
            global.kobold.inventory.addItem(weapon);
        } else {
            global.kobold.inventory.equipment.strip(SlotEnum.WEAPON);
            global.kobold.status.mental.decrease(5, "Half refunded weapon");
        }
    }, function () {
        var weapon = that.misc.weapon();
        var greatsword = that.postShopMisc.weapon();
        if (weapon) {
            return global.ui.change.buildNotification([
                new Change("Refund", "Coins", +50),
                new Change("Returned weapon", global.kobold.inventory.createItemWithTooltip(greatsword, true), -1),
                new Change("Old weapon", global.kobold.inventory.createItemWithTooltip(weapon, true), +1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Peeved", "Sanity", -5),
                new Change("Refund", "Coins", +50),
                new Change("Returned weapon", global.kobold.inventory.createItemWithTooltip(greatsword, true), -1)
            ]);
        }

    });

    this.preStore = new ContinueController(id, "preStore");
    this.store = new BuyController("store");
    this.preContinue = new ContinueController(id, "preContinue");


    this.NoonThreeStoreMoneyChoice = {
        DECLINE: 1,
        ACCEPT: 2,
        MOREMONEY: 3
    };

    this.NoonThreeStoreAttitudeChoice = {
        RELUCTANT: 1,
        EAGER: 2
    };


    this.fragments = {};
    this.fragments.store = new NoonThreeStoreShop(this);
    this.fragments.sexFinale = new NoonThreeStoreSexFinale(this);
    this.fragments.sexChoices = new NoonThreeStoreSexChoices(this);
    this.fragments.blowjobEndChoices = new NoonThreeStoreBlowjobEndChoices(this);
    this.fragments.blowjobChoices = new NoonThreeStoreBlowjobChoices(this);
    this.fragments.handjobEndChoices = new NoonThreeStoreHandjobEndChoices(this);
    this.fragments.handjobChoices = new NoonThreeStoreHandjobChoices(this);

    this.bgm = new AudioController(id, "res/audio/varanar/noonthreestore.mp3", 100);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

// END scenes\Varanar\DayThree\NoonThreeStore\NoonThreeStoreController.js

// scenes\Varanar\DayThree\NoonThreeStore\NoonThreeStore.js

/**
 * Noon three of Varanar.
 */
function NoonThreeStore() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "NoonThreeStore";
    var sceneName = "Varanar, Noon Three (Store)";
    var sceneSubfolder = "Varanar/DayThree";
    var ctrl = new NoonThreeStoreController(sceneId);
    var arrival = new NoonThreeStoreArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]Varanar[/t]`);
        tab += global.parser.parse(`[st]Noon three[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new NoonThreeStore();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Varanar\DayThree\NoonThreeStore\NoonThreeStore.js



// END SCENE NoonThreeStore

